/*M///////////////////////////////////////////////////////////////////////////////////////
 //
 //  IMPORTANT: READ BEFORE DOWNLOADING, COPYING, INSTALLING OR USING.
 //
 //  By downloading, copying, installing or using the software you agree to this license.
 //  If you do not agree to this license, do not download, install,
 //  copy or use the software.
 //
 //
 //                           License Agreement
 //                For Open Source Computer Vision Library
 //
 // Copyright (C) 2013, OpenCV Foundation, all rights reserved.
 // Third party copyrights are property of their respective owners.
 //
 // Redistribution and use in source and binary forms, with or without modification,
 // are permitted provided that the following conditions are met:
 //
 //   * Redistribution's of source code must retain the above copyright notice,
 //     this list of conditions and the following disclaimer.
 //
 //   * Redistribution's in binary form must reproduce the above copyright notice,
 //     this list of conditions and the following disclaimer in the documentation
 //     and/or other materials provided with the distribution.
 //
 //   * The name of the copyright holders may not be used to endorse or promote products
 //     derived from this software without specific prior written permission.
 //
 // This software is provided by the copyright holders and contributors "as is" and
 // any express or implied warranties, including, but not limited to, the implied
 // warranties of merchantability and fitness for a particular purpose are disclaimed.
 // In no event shall the Intel Corporation or contributors be liable for any direct,
 // indirect, incidental, special, exemplary, or consequential damages
 // (including, but not limited to, procurement of substitute goods or services;
 // loss of use, data, or profits; or business interruption) however caused
 // and on any theory of liability, whether in contract, strict liability,
 // or tort (including negligence or otherwise) arising in any way out of
 // the use of this software, even if advised of the possibility of such damage.
 //
 //M*/

#include "precomp.hpp"
#include "opencv2/video/tracking.hpp"
#include "opencv2/imgproc.hpp"
#include <algorithm>
#include <limits.h>
#include "TLD.hpp"

using namespace cv;

namespace cv {namespace tld
{
int TLDEnsembleClassifier::getGridSize(){
    return 15;
}
int TLDEnsembleClassifier::getMaxOrdinal(){
    return 242;
}
void TLDEnsembleClassifier::preinit(int ordinal){
    CV_Assert(ordinal>0 && ordinal<=getMaxOrdinal());
    switch(ordinal){
        case 1:
            x1[0]=5; x2[0]=5; y1[0]=12; y2[0]=11;
            x1[1]=5; x2[1]=5; y1[1]=12; y2[1]=4;
            x1[2]=8; x2[2]=7; y1[2]=3; y2[2]=3;
            x1[3]=14; x2[3]=14; y1[3]=13; y2[3]=1;
            x1[4]=11; x2[4]=11; y1[4]=10; y2[4]=0;
            x1[5]=2; x2[5]=2; y1[5]=7; y2[5]=3;
            x1[6]=3; x2[6]=3; y1[6]=9; y2[6]=2;
            x1[7]=9; x2[7]=7; y1[7]=13; y2[7]=13;
            x1[8]=0; x2[8]=0; y1[8]=13; y2[8]=4;
            x1[9]=9; x2[9]=3; y1[9]=11; y2[9]=11;
            x1[10]=13; x2[10]=3; y1[10]=5; y2[10]=5;
            x1[11]=14; x2[11]=3; y1[11]=4; y2[11]=4;
            x1[12]=12; x2[12]=9; y1[12]=1; y2[12]=1;
        break;
        case 2:
            x1[0]=13; x2[0]=11; y1[0]=7; y2[0]=7;
            x1[1]=7; x2[1]=6; y1[1]=8; y2[1]=8;
            x1[2]=9; x2[2]=8; y1[2]=9; y2[2]=9;
            x1[3]=6; x2[3]=6; y1[3]=13; y2[3]=0;
            x1[4]=5; x2[4]=5; y1[4]=12; y2[4]=6;
            x1[5]=4; x2[5]=0; y1[5]=3; y2[5]=3;
            x1[6]=6; x2[6]=1; y1[6]=14; y2[6]=14;
            x1[7]=10; x2[7]=7; y1[7]=7; y2[7]=7;
            x1[8]=5; x2[8]=2; y1[8]=13; y2[8]=13;
            x1[9]=2; x2[9]=2; y1[9]=1; y2[9]=0;
            x1[10]=11; x2[10]=11; y1[10]=3; y2[10]=1;
            x1[11]=12; x2[11]=1; y1[11]=5; y2[11]=5;
            x1[12]=9; x2[12]=9; y1[12]=10; y2[12]=1;
        break;
        case 3:
            x1[0]=14; x2[0]=14; y1[0]=14; y2[0]=9;
            x1[1]=3; x2[1]=0; y1[1]=8; y2[1]=8;
            x1[2]=11; x2[2]=10; y1[2]=4; y2[2]=4;
            x1[3]=14; x2[3]=14; y1[3]=9; y2[3]=3;
            x1[4]=13; x2[4]=8; y1[4]=12; y2[4]=12;
            x1[5]=4; x2[5]=4; y1[5]=9; y2[5]=0;
            x1[6]=11; x2[6]=6; y1[6]=2; y2[6]=2;
            x1[7]=12; x2[7]=11; y1[7]=10; y2[7]=10;
            x1[8]=14; x2[8]=14; y1[8]=14; y2[8]=0;
            x1[9]=0; x2[9]=0; y1[9]=11; y2[9]=2;
            x1[10]=3; x2[10]=1; y1[10]=3; y2[10]=3;
            x1[11]=3; x2[11]=1; y1[11]=6; y2[11]=6;
            x1[12]=11; x2[12]=1; y1[12]=14; y2[12]=14;
        break;
        case 4:
            x1[0]=1; x2[0]=1; y1[0]=8; y2[0]=7;
            x1[1]=0; x2[1]=0; y1[1]=8; y2[1]=5;
            x1[2]=3; x2[2]=3; y1[2]=7; y2[2]=0;
            x1[3]=14; x2[3]=9; y1[3]=14; y2[3]=14;
            x1[4]=7; x2[4]=7; y1[4]=12; y2[4]=11;
            x1[5]=14; x2[5]=10; y1[5]=8; y2[5]=8;
            x1[6]=14; x2[6]=14; y1[6]=14; y2[6]=7;
            x1[7]=0; x2[7]=0; y1[7]=10; y2[7]=8;
            x1[8]=3; x2[8]=3; y1[8]=13; y2[8]=6;
            x1[9]=12; x2[9]=11; y1[9]=7; y2[9]=7;
            x1[10]=1; x2[10]=1; y1[10]=8; y2[10]=2;
            x1[11]=6; x2[11]=6; y1[11]=3; y2[11]=1;
            x1[12]=7; x2[12]=4; y1[12]=6; y2[12]=6;
        break;
        case 5:
            x1[0]=10; x2[0]=10; y1[0]=14; y2[0]=2;
            x1[1]=7; x2[1]=7; y1[1]=12; y2[1]=5;
            x1[2]=13; x2[2]=12; y1[2]=1; y2[2]=1;
            x1[3]=0; x2[3]=0; y1[3]=14; y2[3]=10;
            x1[4]=6; x2[4]=6; y1[4]=11; y2[4]=8;
            x1[5]=13; x2[5]=12; y1[5]=6; y2[5]=6;
            x1[6]=13; x2[6]=2; y1[6]=11; y2[6]=11;
            x1[7]=10; x2[7]=2; y1[7]=14; y2[7]=14;
            x1[8]=13; x2[8]=10; y1[8]=1; y2[8]=1;
            x1[9]=13; x2[9]=11; y1[9]=1; y2[9]=1;
            x1[10]=12; x2[10]=4; y1[10]=0; y2[10]=0;
            x1[11]=1; x2[11]=1; y1[11]=14; y2[11]=8;
            x1[12]=9; x2[12]=9; y1[12]=12; y2[12]=9;
        break;
        case 6:
            x1[0]=3; x2[0]=3; y1[0]=11; y2[0]=0;
            x1[1]=9; x2[1]=7; y1[1]=3; y2[1]=3;
            x1[2]=6; x2[2]=1; y1[2]=0; y2[2]=0;
            x1[3]=7; x2[3]=7; y1[3]=9; y2[3]=2;
            x1[4]=8; x2[4]=8; y1[4]=10; y2[4]=2;
            x1[5]=5; x2[5]=2; y1[5]=0; y2[5]=0;
            x1[6]=12; x2[6]=9; y1[6]=3; y2[6]=3;
            x1[7]=3; x2[7]=3; y1[7]=9; y2[7]=4;
            x1[8]=13; x2[8]=5; y1[8]=7; y2[8]=7;
            x1[9]=12; x2[9]=12; y1[9]=14; y2[9]=3;
            x1[10]=2; x2[10]=2; y1[10]=4; y2[10]=1;
            x1[11]=2; x2[11]=2; y1[11]=11; y2[11]=6;
            x1[12]=2; x2[12]=1; y1[12]=9; y2[12]=9;
        break;
        case 7:
            x1[0]=7; x2[0]=1; y1[0]=1; y2[0]=1;
            x1[1]=6; x2[1]=6; y1[1]=7; y2[1]=6;
            x1[2]=12; x2[2]=5; y1[2]=5; y2[2]=5;
            x1[3]=6; x2[3]=6; y1[3]=4; y2[3]=0;
            x1[4]=5; x2[4]=5; y1[4]=13; y2[4]=8;
            x1[5]=14; x2[5]=13; y1[5]=12; y2[5]=12;
            x1[6]=12; x2[6]=10; y1[6]=13; y2[6]=13;
            x1[7]=0; x2[7]=0; y1[7]=7; y2[7]=1;
            x1[8]=14; x2[8]=14; y1[8]=11; y2[8]=4;
            x1[9]=14; x2[9]=14; y1[9]=6; y2[9]=4;
            x1[10]=13; x2[10]=4; y1[10]=10; y2[10]=10;
            x1[11]=13; x2[11]=13; y1[11]=5; y2[11]=4;
            x1[12]=10; x2[12]=7; y1[12]=10; y2[12]=10;
        break;
        case 8:
            x1[0]=14; x2[0]=7; y1[0]=7; y2[0]=7;
            x1[1]=12; x2[1]=12; y1[1]=12; y2[1]=4;
            x1[2]=6; x2[2]=1; y1[2]=7; y2[2]=7;
            x1[3]=12; x2[3]=11; y1[3]=8; y2[3]=8;
            x1[4]=12; x2[4]=1; y1[4]=2; y2[4]=2;
            x1[5]=14; x2[5]=11; y1[5]=9; y2[5]=9;
            x1[6]=13; x2[6]=11; y1[6]=10; y2[6]=10;
            x1[7]=12; x2[7]=12; y1[7]=11; y2[7]=0;
            x1[8]=4; x2[8]=4; y1[8]=8; y2[8]=6;
            x1[9]=2; x2[9]=2; y1[9]=11; y2[9]=3;
            x1[10]=7; x2[10]=4; y1[10]=10; y2[10]=10;
            x1[11]=12; x2[11]=2; y1[11]=14; y2[11]=14;
            x1[12]=14; x2[12]=0; y1[12]=4; y2[12]=4;
        break;
        case 9:
            x1[0]=9; x2[0]=9; y1[0]=12; y2[0]=11;
            x1[1]=14; x2[1]=7; y1[1]=14; y2[1]=14;
            x1[2]=9; x2[2]=1; y1[2]=9; y2[2]=9;
            x1[3]=8; x2[3]=1; y1[3]=8; y2[3]=8;
            x1[4]=3; x2[4]=3; y1[4]=3; y2[4]=1;
            x1[5]=5; x2[5]=4; y1[5]=8; y2[5]=8;
            x1[6]=9; x2[6]=9; y1[6]=9; y2[6]=8;
            x1[7]=0; x2[7]=0; y1[7]=7; y2[7]=3;
            x1[8]=8; x2[8]=2; y1[8]=0; y2[8]=0;
            x1[9]=2; x2[9]=2; y1[9]=9; y2[9]=7;
            x1[10]=0; x2[10]=0; y1[10]=14; y2[10]=4;
            x1[11]=8; x2[11]=5; y1[11]=0; y2[11]=0;
            x1[12]=5; x2[12]=5; y1[12]=12; y2[12]=9;
        break;
        case 10:
            x1[0]=8; x2[0]=0; y1[0]=3; y2[0]=3;
            x1[1]=7; x2[1]=4; y1[1]=11; y2[1]=11;
            x1[2]=5; x2[2]=5; y1[2]=7; y2[2]=2;
            x1[3]=3; x2[3]=3; y1[3]=8; y2[3]=5;
            x1[4]=6; x2[4]=6; y1[4]=9; y2[4]=8;
            x1[5]=4; x2[5]=2; y1[5]=7; y2[5]=7;
            x1[6]=13; x2[6]=6; y1[6]=3; y2[6]=3;
            x1[7]=12; x2[7]=12; y1[7]=11; y2[7]=3;
            x1[8]=7; x2[8]=7; y1[8]=12; y2[8]=1;
            x1[9]=6; x2[9]=6; y1[9]=14; y2[9]=3;
            x1[10]=2; x2[10]=2; y1[10]=14; y2[10]=5;
            x1[11]=14; x2[11]=14; y1[11]=7; y2[11]=4;
            x1[12]=5; x2[12]=1; y1[12]=12; y2[12]=12;
        break;
        case 11:
            x1[0]=10; x2[0]=10; y1[0]=4; y2[0]=0;
            x1[1]=3; x2[1]=3; y1[1]=12; y2[1]=10;
            x1[2]=13; x2[2]=8; y1[2]=9; y2[2]=9;
            x1[3]=12; x2[3]=12; y1[3]=9; y2[3]=5;
            x1[4]=14; x2[4]=14; y1[4]=7; y2[4]=0;
            x1[5]=5; x2[5]=5; y1[5]=14; y2[5]=4;
            x1[6]=4; x2[6]=4; y1[6]=13; y2[6]=3;
            x1[7]=6; x2[7]=6; y1[7]=12; y2[7]=1;
            x1[8]=10; x2[8]=10; y1[8]=5; y2[8]=1;
            x1[9]=9; x2[9]=9; y1[9]=3; y2[9]=1;
            x1[10]=9; x2[10]=4; y1[10]=14; y2[10]=14;
            x1[11]=12; x2[11]=3; y1[11]=14; y2[11]=14;
            x1[12]=6; x2[12]=2; y1[12]=13; y2[12]=13;
        break;
        case 12:
            x1[0]=12; x2[0]=3; y1[0]=3; y2[0]=3;
            x1[1]=12; x2[1]=9; y1[1]=8; y2[1]=8;
            x1[2]=2; x2[2]=2; y1[2]=9; y2[2]=1;
            x1[3]=4; x2[3]=4; y1[3]=10; y2[3]=9;
            x1[4]=12; x2[4]=9; y1[4]=5; y2[4]=5;
            x1[5]=14; x2[5]=8; y1[5]=12; y2[5]=12;
            x1[6]=9; x2[6]=9; y1[6]=12; y2[6]=7;
            x1[7]=11; x2[7]=3; y1[7]=6; y2[7]=6;
            x1[8]=8; x2[8]=2; y1[8]=12; y2[8]=12;
            x1[9]=10; x2[9]=1; y1[9]=12; y2[9]=12;
            x1[10]=2; x2[10]=2; y1[10]=11; y2[10]=1;
            x1[11]=11; x2[11]=4; y1[11]=13; y2[11]=13;
            x1[12]=13; x2[12]=2; y1[12]=0; y2[12]=0;
        break;
        case 13:
            x1[0]=4; x2[0]=4; y1[0]=14; y2[0]=8;
            x1[1]=10; x2[1]=10; y1[1]=11; y2[1]=5;
            x1[2]=7; x2[2]=7; y1[2]=8; y2[2]=3;
            x1[3]=0; x2[3]=0; y1[3]=9; y2[3]=3;
            x1[4]=8; x2[4]=8; y1[4]=9; y2[4]=7;
            x1[5]=12; x2[5]=1; y1[5]=0; y2[5]=0;
            x1[6]=14; x2[6]=5; y1[6]=8; y2[6]=8;
            x1[7]=12; x2[7]=12; y1[7]=13; y2[7]=2;
            x1[8]=9; x2[8]=6; y1[8]=6; y2[8]=6;
            x1[9]=11; x2[9]=2; y1[9]=3; y2[9]=3;
            x1[10]=1; x2[10]=1; y1[10]=8; y2[10]=5;
            x1[11]=3; x2[11]=3; y1[11]=12; y2[11]=4;
            x1[12]=1; x2[12]=1; y1[12]=14; y2[12]=11;
        break;
        case 14:
            x1[0]=12; x2[0]=7; y1[0]=13; y2[0]=13;
            x1[1]=10; x2[1]=10; y1[1]=7; y2[1]=5;
            x1[2]=11; x2[2]=2; y1[2]=10; y2[2]=10;
            x1[3]=11; x2[3]=11; y1[3]=2; y2[3]=0;
            x1[4]=9; x2[4]=9; y1[4]=8; y2[4]=7;
            x1[5]=8; x2[5]=8; y1[5]=14; y2[5]=5;
            x1[6]=13; x2[6]=13; y1[6]=7; y2[6]=6;
            x1[7]=11; x2[7]=11; y1[7]=14; y2[7]=11;
            x1[8]=8; x2[8]=8; y1[8]=13; y2[8]=11;
            x1[9]=10; x2[9]=10; y1[9]=12; y2[9]=5;
            x1[10]=1; x2[10]=1; y1[10]=13; y2[10]=8;
            x1[11]=13; x2[11]=13; y1[11]=14; y2[11]=13;
            x1[12]=7; x2[12]=6; y1[12]=14; y2[12]=14;
        break;
        case 15:
            x1[0]=1; x2[0]=1; y1[0]=12; y2[0]=2;
            x1[1]=12; x2[1]=12; y1[1]=3; y2[1]=1;
            x1[2]=10; x2[2]=5; y1[2]=8; y2[2]=8;
            x1[3]=9; x2[3]=2; y1[3]=6; y2[3]=6;
            x1[4]=11; x2[4]=5; y1[4]=0; y2[4]=0;
            x1[5]=10; x2[5]=7; y1[5]=4; y2[5]=4;
            x1[6]=4; x2[6]=3; y1[6]=14; y2[6]=14;
            x1[7]=1; x2[7]=1; y1[7]=8; y2[7]=3;
            x1[8]=8; x2[8]=8; y1[8]=12; y2[8]=2;
            x1[9]=7; x2[9]=0; y1[9]=2; y2[9]=2;
            x1[10]=1; x2[10]=0; y1[10]=14; y2[10]=14;
            x1[11]=11; x2[11]=11; y1[11]=12; y2[11]=6;
            x1[12]=9; x2[12]=5; y1[12]=7; y2[12]=7;
        break;
        case 16:
            x1[0]=8; x2[0]=4; y1[0]=10; y2[0]=10;
            x1[1]=0; x2[1]=0; y1[1]=8; y2[1]=7;
            x1[2]=3; x2[2]=3; y1[2]=9; y2[2]=1;
            x1[3]=6; x2[3]=2; y1[3]=3; y2[3]=3;
            x1[4]=10; x2[4]=10; y1[4]=8; y2[4]=5;
            x1[5]=8; x2[5]=2; y1[5]=4; y2[5]=4;
            x1[6]=9; x2[6]=9; y1[6]=14; y2[6]=11;
            x1[7]=0; x2[7]=0; y1[7]=8; y2[7]=2;
            x1[8]=11; x2[8]=3; y1[8]=13; y2[8]=13;
            x1[9]=7; x2[9]=4; y1[9]=13; y2[9]=13;
            x1[10]=14; x2[10]=2; y1[10]=3; y2[10]=3;
            x1[11]=8; x2[11]=8; y1[11]=13; y2[11]=4;
            x1[12]=7; x2[12]=7; y1[12]=7; y2[12]=0;
        break;
        case 17:
            x1[0]=14; x2[0]=8; y1[0]=3; y2[0]=3;
            x1[1]=9; x2[1]=9; y1[1]=1; y2[1]=0;
            x1[2]=14; x2[2]=14; y1[2]=3; y2[2]=2;
            x1[3]=5; x2[3]=5; y1[3]=12; y2[3]=10;
            x1[4]=8; x2[4]=8; y1[4]=12; y2[4]=4;
            x1[5]=8; x2[5]=6; y1[5]=1; y2[5]=1;
            x1[6]=5; x2[6]=5; y1[6]=6; y2[6]=4;
            x1[7]=2; x2[7]=2; y1[7]=8; y2[7]=1;
            x1[8]=14; x2[8]=5; y1[8]=1; y2[8]=1;
            x1[9]=7; x2[9]=1; y1[9]=0; y2[9]=0;
            x1[10]=5; x2[10]=5; y1[10]=7; y2[10]=1;
            x1[11]=9; x2[11]=9; y1[11]=6; y2[11]=3;
            x1[12]=13; x2[12]=0; y1[12]=11; y2[12]=11;
        break;
        case 18:
            x1[0]=12; x2[0]=1; y1[0]=6; y2[0]=6;
            x1[1]=4; x2[1]=4; y1[1]=12; y2[1]=8;
            x1[2]=9; x2[2]=5; y1[2]=0; y2[2]=0;
            x1[3]=8; x2[3]=4; y1[3]=11; y2[3]=11;
            x1[4]=13; x2[4]=3; y1[4]=7; y2[4]=7;
            x1[5]=10; x2[5]=10; y1[5]=12; y2[5]=4;
            x1[6]=13; x2[6]=13; y1[6]=14; y2[6]=6;
            x1[7]=0; x2[7]=0; y1[7]=9; y2[7]=2;
            x1[8]=2; x2[8]=2; y1[8]=14; y2[8]=2;
            x1[9]=7; x2[9]=3; y1[9]=10; y2[9]=10;
            x1[10]=9; x2[10]=4; y1[10]=1; y2[10]=1;
            x1[11]=10; x2[11]=10; y1[11]=10; y2[11]=2;
            x1[12]=4; x2[12]=4; y1[12]=11; y2[12]=3;
        break;
        case 19:
            x1[0]=4; x2[0]=4; y1[0]=5; y2[0]=1;
            x1[1]=9; x2[1]=9; y1[1]=13; y2[1]=1;
            x1[2]=5; x2[2]=0; y1[2]=3; y2[2]=3;
            x1[3]=8; x2[3]=0; y1[3]=2; y2[3]=2;
            x1[4]=9; x2[4]=9; y1[4]=8; y2[4]=0;
            x1[5]=3; x2[5]=3; y1[5]=12; y2[5]=1;
            x1[6]=6; x2[6]=0; y1[6]=2; y2[6]=2;
            x1[7]=8; x2[7]=7; y1[7]=14; y2[7]=14;
            x1[8]=10; x2[8]=1; y1[8]=14; y2[8]=14;
            x1[9]=2; x2[9]=2; y1[9]=7; y2[9]=1;
            x1[10]=10; x2[10]=0; y1[10]=2; y2[10]=2;
            x1[11]=8; x2[11]=8; y1[11]=6; y2[11]=5;
            x1[12]=13; x2[12]=13; y1[12]=11; y2[12]=9;
        break;
        case 20:
            x1[0]=9; x2[0]=0; y1[0]=5; y2[0]=5;
            x1[1]=13; x2[1]=12; y1[1]=14; y2[1]=14;
            x1[2]=9; x2[2]=9; y1[2]=13; y2[2]=2;
            x1[3]=12; x2[3]=8; y1[3]=9; y2[3]=9;
            x1[4]=7; x2[4]=6; y1[4]=4; y2[4]=4;
            x1[5]=11; x2[5]=9; y1[5]=3; y2[5]=3;
            x1[6]=4; x2[6]=2; y1[6]=4; y2[6]=4;
            x1[7]=13; x2[7]=7; y1[7]=13; y2[7]=13;
            x1[8]=12; x2[8]=11; y1[8]=5; y2[8]=5;
            x1[9]=4; x2[9]=1; y1[9]=7; y2[9]=7;
            x1[10]=9; x2[10]=7; y1[10]=2; y2[10]=2;
            x1[11]=11; x2[11]=11; y1[11]=13; y2[11]=6;
            x1[12]=6; x2[12]=6; y1[12]=5; y2[12]=3;
        break;
        case 21:
            x1[0]=14; x2[0]=9; y1[0]=10; y2[0]=10;
            x1[1]=8; x2[1]=2; y1[1]=14; y2[1]=14;
            x1[2]=14; x2[2]=14; y1[2]=9; y2[2]=1;
            x1[3]=8; x2[3]=8; y1[3]=2; y2[3]=0;
            x1[4]=10; x2[4]=1; y1[4]=6; y2[4]=6;
            x1[5]=7; x2[5]=2; y1[5]=3; y2[5]=3;
            x1[6]=12; x2[6]=12; y1[6]=7; y2[6]=4;
            x1[7]=12; x2[7]=6; y1[7]=7; y2[7]=7;
            x1[8]=8; x2[8]=8; y1[8]=4; y2[8]=0;
            x1[9]=9; x2[9]=9; y1[9]=10; y2[9]=6;
            x1[10]=6; x2[10]=6; y1[10]=9; y2[10]=1;
            x1[11]=10; x2[11]=2; y1[11]=0; y2[11]=0;
            x1[12]=1; x2[12]=1; y1[12]=13; y2[12]=2;
        break;
        case 22:
            x1[0]=14; x2[0]=12; y1[0]=4; y2[0]=4;
            x1[1]=13; x2[1]=1; y1[1]=14; y2[1]=14;
            x1[2]=7; x2[2]=7; y1[2]=10; y2[2]=9;
            x1[3]=6; x2[3]=1; y1[3]=12; y2[3]=12;
            x1[4]=11; x2[4]=11; y1[4]=13; y2[4]=9;
            x1[5]=5; x2[5]=4; y1[5]=1; y2[5]=1;
            x1[6]=11; x2[6]=11; y1[6]=11; y2[6]=2;
            x1[7]=3; x2[7]=0; y1[7]=5; y2[7]=5;
            x1[8]=13; x2[8]=13; y1[8]=13; y2[8]=10;
            x1[9]=12; x2[9]=12; y1[9]=14; y2[9]=0;
            x1[10]=10; x2[10]=3; y1[10]=4; y2[10]=4;
            x1[11]=10; x2[11]=8; y1[11]=1; y2[11]=1;
            x1[12]=5; x2[12]=5; y1[12]=11; y2[12]=5;
        break;
        case 23:
            x1[0]=8; x2[0]=8; y1[0]=11; y2[0]=4;
            x1[1]=14; x2[1]=14; y1[1]=13; y2[1]=8;
            x1[2]=13; x2[2]=13; y1[2]=13; y2[2]=8;
            x1[3]=10; x2[3]=8; y1[3]=5; y2[3]=5;
            x1[4]=14; x2[4]=14; y1[4]=12; y2[4]=7;
            x1[5]=10; x2[5]=8; y1[5]=0; y2[5]=0;
            x1[6]=9; x2[6]=2; y1[6]=4; y2[6]=4;
            x1[7]=14; x2[7]=14; y1[7]=6; y2[7]=3;
            x1[8]=5; x2[8]=5; y1[8]=9; y2[8]=1;
            x1[9]=10; x2[9]=4; y1[9]=8; y2[9]=8;
            x1[10]=5; x2[10]=5; y1[10]=4; y2[10]=2;
            x1[11]=8; x2[11]=2; y1[11]=10; y2[11]=10;
            x1[12]=4; x2[12]=4; y1[12]=12; y2[12]=6;
        break;
        case 24:
            x1[0]=14; x2[0]=3; y1[0]=0; y2[0]=0;
            x1[1]=6; x2[1]=4; y1[1]=13; y2[1]=13;
            x1[2]=11; x2[2]=6; y1[2]=10; y2[2]=10;
            x1[3]=2; x2[3]=2; y1[3]=13; y2[3]=10;
            x1[4]=9; x2[4]=9; y1[4]=10; y2[4]=4;
            x1[5]=6; x2[5]=6; y1[5]=14; y2[5]=6;
            x1[6]=13; x2[6]=8; y1[6]=5; y2[6]=5;
            x1[7]=0; x2[7]=0; y1[7]=12; y2[7]=10;
            x1[8]=13; x2[8]=8; y1[8]=0; y2[8]=0;
            x1[9]=9; x2[9]=9; y1[9]=13; y2[9]=7;
            x1[10]=14; x2[10]=3; y1[10]=9; y2[10]=9;
            x1[11]=6; x2[11]=6; y1[11]=6; y2[11]=5;
            x1[12]=10; x2[12]=1; y1[12]=2; y2[12]=2;
        break;
        case 25:
            x1[0]=13; x2[0]=10; y1[0]=14; y2[0]=14;
            x1[1]=7; x2[1]=7; y1[1]=13; y2[1]=9;
            x1[2]=12; x2[2]=10; y1[2]=10; y2[2]=10;
            x1[3]=7; x2[3]=7; y1[3]=8; y2[3]=2;
            x1[4]=12; x2[4]=1; y1[4]=7; y2[4]=7;
            x1[5]=14; x2[5]=5; y1[5]=12; y2[5]=12;
            x1[6]=8; x2[6]=8; y1[6]=9; y2[6]=3;
            x1[7]=2; x2[7]=1; y1[7]=11; y2[7]=11;
            x1[8]=12; x2[8]=2; y1[8]=9; y2[8]=9;
            x1[9]=12; x2[9]=3; y1[9]=0; y2[9]=0;
            x1[10]=6; x2[10]=1; y1[10]=2; y2[10]=2;
            x1[11]=6; x2[11]=6; y1[11]=8; y2[11]=3;
            x1[12]=7; x2[12]=7; y1[12]=8; y2[12]=6;
        break;
        case 26:
            x1[0]=13; x2[0]=13; y1[0]=5; y2[0]=0;
            x1[1]=13; x2[1]=10; y1[1]=7; y2[1]=7;
            x1[2]=14; x2[2]=14; y1[2]=7; y2[2]=5;
            x1[3]=9; x2[3]=9; y1[3]=13; y2[3]=5;
            x1[4]=13; x2[4]=7; y1[4]=1; y2[4]=1;
            x1[5]=10; x2[5]=8; y1[5]=3; y2[5]=3;
            x1[6]=1; x2[6]=1; y1[6]=6; y2[6]=4;
            x1[7]=6; x2[7]=6; y1[7]=6; y2[7]=1;
            x1[8]=14; x2[8]=14; y1[8]=7; y2[8]=3;
            x1[9]=14; x2[9]=10; y1[9]=0; y2[9]=0;
            x1[10]=14; x2[10]=9; y1[10]=1; y2[10]=1;
            x1[11]=3; x2[11]=3; y1[11]=13; y2[11]=1;
            x1[12]=12; x2[12]=5; y1[12]=8; y2[12]=8;
        break;
        case 27:
            x1[0]=10; x2[0]=3; y1[0]=6; y2[0]=6;
            x1[1]=10; x2[1]=4; y1[1]=12; y2[1]=12;
            x1[2]=13; x2[2]=13; y1[2]=8; y2[2]=6;
            x1[3]=14; x2[3]=14; y1[3]=14; y2[3]=13;
            x1[4]=13; x2[4]=1; y1[4]=1; y2[4]=1;
            x1[5]=10; x2[5]=10; y1[5]=13; y2[5]=4;
            x1[6]=13; x2[6]=8; y1[6]=13; y2[6]=13;
            x1[7]=5; x2[7]=5; y1[7]=11; y2[7]=0;
            x1[8]=14; x2[8]=14; y1[8]=10; y2[8]=8;
            x1[9]=9; x2[9]=4; y1[9]=10; y2[9]=10;
            x1[10]=13; x2[10]=10; y1[10]=6; y2[10]=6;
            x1[11]=9; x2[11]=9; y1[11]=8; y2[11]=4;
            x1[12]=5; x2[12]=1; y1[12]=11; y2[12]=11;
        break;
        case 28:
            x1[0]=12; x2[0]=12; y1[0]=12; y2[0]=9;
            x1[1]=6; x2[1]=2; y1[1]=11; y2[1]=11;
            x1[2]=12; x2[2]=12; y1[2]=6; y2[2]=1;
            x1[3]=9; x2[3]=7; y1[3]=14; y2[3]=14;
            x1[4]=14; x2[4]=14; y1[4]=11; y2[4]=0;
            x1[5]=5; x2[5]=3; y1[5]=13; y2[5]=13;
            x1[6]=0; x2[6]=0; y1[6]=6; y2[6]=5;
            x1[7]=11; x2[7]=9; y1[7]=14; y2[7]=14;
            x1[8]=12; x2[8]=5; y1[8]=14; y2[8]=14;
            x1[9]=0; x2[9]=0; y1[9]=4; y2[9]=3;
            x1[10]=12; x2[10]=3; y1[10]=13; y2[10]=13;
            x1[11]=5; x2[11]=4; y1[11]=6; y2[11]=6;
            x1[12]=6; x2[12]=3; y1[12]=8; y2[12]=8;
        break;
        case 29:
            x1[0]=8; x2[0]=7; y1[0]=9; y2[0]=9;
            x1[1]=8; x2[1]=8; y1[1]=14; y2[1]=2;
            x1[2]=11; x2[2]=11; y1[2]=12; y2[2]=1;
            x1[3]=13; x2[3]=5; y1[3]=13; y2[3]=13;
            x1[4]=1; x2[4]=1; y1[4]=10; y2[4]=0;
            x1[5]=13; x2[5]=12; y1[5]=3; y2[5]=3;
            x1[6]=7; x2[6]=7; y1[6]=13; y2[6]=1;
            x1[7]=3; x2[7]=3; y1[7]=7; y2[7]=4;
            x1[8]=11; x2[8]=3; y1[8]=11; y2[8]=11;
            x1[9]=9; x2[9]=8; y1[9]=13; y2[9]=13;
            x1[10]=7; x2[10]=7; y1[10]=12; y2[10]=8;
            x1[11]=8; x2[11]=8; y1[11]=14; y2[11]=8;
            x1[12]=3; x2[12]=1; y1[12]=4; y2[12]=4;
        break;
        case 30:
            x1[0]=2; x2[0]=2; y1[0]=10; y2[0]=4;
            x1[1]=11; x2[1]=6; y1[1]=13; y2[1]=13;
            x1[2]=12; x2[2]=8; y1[2]=11; y2[2]=11;
            x1[3]=14; x2[3]=14; y1[3]=13; y2[3]=11;
            x1[4]=6; x2[4]=6; y1[4]=7; y2[4]=4;
            x1[5]=7; x2[5]=4; y1[5]=14; y2[5]=14;
            x1[6]=9; x2[6]=5; y1[6]=9; y2[6]=9;
            x1[7]=6; x2[7]=0; y1[7]=4; y2[7]=4;
            x1[8]=1; x2[8]=1; y1[8]=10; y2[8]=5;
            x1[9]=9; x2[9]=1; y1[9]=2; y2[9]=2;
            x1[10]=13; x2[10]=7; y1[10]=0; y2[10]=0;
            x1[11]=8; x2[11]=8; y1[11]=12; y2[11]=10;
            x1[12]=8; x2[12]=3; y1[12]=12; y2[12]=12;
        break;
        case 31:
            x1[0]=2; x2[0]=2; y1[0]=13; y2[0]=2;
            x1[1]=0; x2[1]=0; y1[1]=4; y2[1]=2;
            x1[2]=9; x2[2]=9; y1[2]=6; y2[2]=5;
            x1[3]=1; x2[3]=0; y1[3]=11; y2[3]=11;
            x1[4]=4; x2[4]=4; y1[4]=7; y2[4]=3;
            x1[5]=4; x2[5]=4; y1[5]=7; y2[5]=4;
            x1[6]=1; x2[6]=1; y1[6]=7; y2[6]=0;
            x1[7]=8; x2[7]=4; y1[7]=4; y2[7]=4;
            x1[8]=12; x2[8]=12; y1[8]=10; y2[8]=5;
            x1[9]=4; x2[9]=2; y1[9]=12; y2[9]=12;
            x1[10]=12; x2[10]=3; y1[10]=8; y2[10]=8;
            x1[11]=4; x2[11]=4; y1[11]=14; y2[11]=0;
            x1[12]=7; x2[12]=6; y1[12]=0; y2[12]=0;
        break;
        case 32:
            x1[0]=7; x2[0]=7; y1[0]=10; y2[0]=1;
            x1[1]=11; x2[1]=5; y1[1]=10; y2[1]=10;
            x1[2]=14; x2[2]=7; y1[2]=4; y2[2]=4;
            x1[3]=8; x2[3]=8; y1[3]=10; y2[3]=6;
            x1[4]=4; x2[4]=4; y1[4]=6; y2[4]=5;
            x1[5]=10; x2[5]=10; y1[5]=1; y2[5]=0;
            x1[6]=11; x2[6]=2; y1[6]=9; y2[6]=9;
            x1[7]=12; x2[7]=12; y1[7]=4; y2[7]=3;
            x1[8]=3; x2[8]=2; y1[8]=13; y2[8]=13;
            x1[9]=11; x2[9]=11; y1[9]=14; y2[9]=8;
            x1[10]=5; x2[10]=1; y1[10]=5; y2[10]=5;
            x1[11]=10; x2[11]=10; y1[11]=14; y2[11]=7;
            x1[12]=1; x2[12]=1; y1[12]=11; y2[12]=8;
        break;
        case 33:
            x1[0]=11; x2[0]=11; y1[0]=12; y2[0]=5;
            x1[1]=6; x2[1]=2; y1[1]=14; y2[1]=14;
            x1[2]=9; x2[2]=9; y1[2]=7; y2[2]=2;
            x1[3]=2; x2[3]=2; y1[3]=12; y2[3]=1;
            x1[4]=11; x2[4]=11; y1[4]=13; y2[4]=5;
            x1[5]=11; x2[5]=2; y1[5]=11; y2[5]=11;
            x1[6]=3; x2[6]=0; y1[6]=11; y2[6]=11;
            x1[7]=7; x2[7]=6; y1[7]=10; y2[7]=10;
            x1[8]=5; x2[8]=0; y1[8]=11; y2[8]=11;
            x1[9]=5; x2[9]=5; y1[9]=8; y2[9]=5;
            x1[10]=13; x2[10]=11; y1[10]=13; y2[10]=13;
            x1[11]=0; x2[11]=0; y1[11]=10; y2[11]=3;
            x1[12]=5; x2[12]=5; y1[12]=11; y2[12]=10;
        break;
        case 34:
            x1[0]=7; x2[0]=6; y1[0]=6; y2[0]=6;
            x1[1]=6; x2[1]=6; y1[1]=13; y2[1]=12;
            x1[2]=11; x2[2]=2; y1[2]=2; y2[2]=2;
            x1[3]=1; x2[3]=1; y1[3]=9; y2[3]=6;
            x1[4]=7; x2[4]=7; y1[4]=11; y2[4]=3;
            x1[5]=2; x2[5]=2; y1[5]=12; y2[5]=0;
            x1[6]=6; x2[6]=6; y1[6]=7; y2[6]=5;
            x1[7]=11; x2[7]=9; y1[7]=6; y2[7]=6;
            x1[8]=14; x2[8]=5; y1[8]=10; y2[8]=10;
            x1[9]=8; x2[9]=3; y1[9]=2; y2[9]=2;
            x1[10]=14; x2[10]=9; y1[10]=6; y2[10]=6;
            x1[11]=13; x2[11]=8; y1[11]=6; y2[11]=6;
            x1[12]=13; x2[12]=13; y1[12]=1; y2[12]=0;
        break;
        case 35:
            x1[0]=2; x2[0]=2; y1[0]=8; y2[0]=7;
            x1[1]=8; x2[1]=8; y1[1]=6; y2[1]=2;
            x1[2]=2; x2[2]=2; y1[2]=2; y2[2]=0;
            x1[3]=8; x2[3]=0; y1[3]=14; y2[3]=14;
            x1[4]=14; x2[4]=14; y1[4]=4; y2[4]=3;
            x1[5]=11; x2[5]=2; y1[5]=1; y2[5]=1;
            x1[6]=14; x2[6]=9; y1[6]=2; y2[6]=2;
            x1[7]=13; x2[7]=13; y1[7]=9; y2[7]=2;
            x1[8]=9; x2[8]=8; y1[8]=2; y2[8]=2;
            x1[9]=7; x2[9]=3; y1[9]=14; y2[9]=14;
            x1[10]=13; x2[10]=13; y1[10]=8; y2[10]=7;
            x1[11]=11; x2[11]=11; y1[11]=10; y2[11]=4;
            x1[12]=13; x2[12]=12; y1[12]=7; y2[12]=7;
        break;
        case 36:
            x1[0]=8; x2[0]=6; y1[0]=4; y2[0]=4;
            x1[1]=12; x2[1]=3; y1[1]=4; y2[1]=4;
            x1[2]=5; x2[2]=5; y1[2]=9; y2[2]=8;
            x1[3]=3; x2[3]=3; y1[3]=10; y2[3]=2;
            x1[4]=11; x2[4]=11; y1[4]=9; y2[4]=5;
            x1[5]=9; x2[5]=9; y1[5]=13; y2[5]=0;
            x1[6]=4; x2[6]=0; y1[6]=11; y2[6]=11;
            x1[7]=9; x2[7]=0; y1[7]=9; y2[7]=9;
            x1[8]=7; x2[8]=7; y1[8]=4; y2[8]=3;
            x1[9]=7; x2[9]=4; y1[9]=5; y2[9]=5;
            x1[10]=12; x2[10]=12; y1[10]=11; y2[10]=8;
            x1[11]=9; x2[11]=1; y1[11]=11; y2[11]=11;
            x1[12]=8; x2[12]=1; y1[12]=11; y2[12]=11;
        break;
        case 37:
            x1[0]=5; x2[0]=5; y1[0]=9; y2[0]=3;
            x1[1]=5; x2[1]=5; y1[1]=8; y2[1]=1;
            x1[2]=3; x2[2]=3; y1[2]=13; y2[2]=12;
            x1[3]=2; x2[3]=2; y1[3]=7; y2[3]=5;
            x1[4]=10; x2[4]=2; y1[4]=1; y2[4]=1;
            x1[5]=8; x2[5]=2; y1[5]=1; y2[5]=1;
            x1[6]=2; x2[6]=0; y1[6]=11; y2[6]=11;
            x1[7]=9; x2[7]=1; y1[7]=7; y2[7]=7;
            x1[8]=1; x2[8]=1; y1[8]=6; y2[8]=1;
            x1[9]=12; x2[9]=12; y1[9]=2; y2[9]=1;
            x1[10]=4; x2[10]=4; y1[10]=2; y2[10]=1;
            x1[11]=13; x2[11]=4; y1[11]=4; y2[11]=4;
            x1[12]=12; x2[12]=12; y1[12]=12; y2[12]=5;
        break;
        case 38:
            x1[0]=10; x2[0]=3; y1[0]=10; y2[0]=10;
            x1[1]=10; x2[1]=3; y1[1]=8; y2[1]=8;
            x1[2]=1; x2[2]=1; y1[2]=8; y2[2]=4;
            x1[3]=10; x2[3]=10; y1[3]=11; y2[3]=1;
            x1[4]=6; x2[4]=6; y1[4]=13; y2[4]=4;
            x1[5]=10; x2[5]=10; y1[5]=5; y2[5]=2;
            x1[6]=11; x2[6]=5; y1[6]=1; y2[6]=1;
            x1[7]=14; x2[7]=13; y1[7]=6; y2[7]=6;
            x1[8]=14; x2[8]=14; y1[8]=9; y2[8]=4;
            x1[9]=14; x2[9]=1; y1[9]=0; y2[9]=0;
            x1[10]=7; x2[10]=7; y1[10]=14; y2[10]=11;
            x1[11]=5; x2[11]=3; y1[11]=11; y2[11]=11;
            x1[12]=5; x2[12]=5; y1[12]=10; y2[12]=8;
        break;
        case 39:
            x1[0]=8; x2[0]=8; y1[0]=13; y2[0]=1;
            x1[1]=14; x2[1]=12; y1[1]=6; y2[1]=6;
            x1[2]=0; x2[2]=0; y1[2]=14; y2[2]=11;
            x1[3]=6; x2[3]=6; y1[3]=10; y2[3]=3;
            x1[4]=14; x2[4]=1; y1[4]=7; y2[4]=7;
            x1[5]=6; x2[5]=6; y1[5]=14; y2[5]=1;
            x1[6]=10; x2[6]=10; y1[6]=12; y2[6]=3;
            x1[7]=14; x2[7]=1; y1[7]=10; y2[7]=10;
            x1[8]=10; x2[8]=10; y1[8]=13; y2[8]=10;
            x1[9]=6; x2[9]=6; y1[9]=9; y2[9]=4;
            x1[10]=14; x2[10]=0; y1[10]=10; y2[10]=10;
            x1[11]=14; x2[11]=11; y1[11]=4; y2[11]=4;
            x1[12]=11; x2[12]=11; y1[12]=11; y2[12]=8;
        break;
        case 40:
            x1[0]=1; x2[0]=1; y1[0]=10; y2[0]=3;
            x1[1]=11; x2[1]=11; y1[1]=10; y2[1]=1;
            x1[2]=12; x2[2]=12; y1[2]=8; y2[2]=4;
            x1[3]=1; x2[3]=1; y1[3]=10; y2[3]=8;
            x1[4]=1; x2[4]=1; y1[4]=7; y2[4]=5;
            x1[5]=5; x2[5]=5; y1[5]=5; y2[5]=3;
            x1[6]=1; x2[6]=1; y1[6]=13; y2[6]=12;
            x1[7]=3; x2[7]=3; y1[7]=5; y2[7]=0;
            x1[8]=7; x2[8]=4; y1[8]=7; y2[8]=7;
            x1[9]=10; x2[9]=2; y1[9]=5; y2[9]=5;
            x1[10]=7; x2[10]=3; y1[10]=4; y2[10]=4;
            x1[11]=1; x2[11]=1; y1[11]=4; y2[11]=2;
            x1[12]=5; x2[12]=5; y1[12]=1; y2[12]=0;
        break;
        case 41:
            x1[0]=8; x2[0]=7; y1[0]=7; y2[0]=7;
            x1[1]=2; x2[1]=0; y1[1]=4; y2[1]=4;
            x1[2]=11; x2[2]=4; y1[2]=0; y2[2]=0;
            x1[3]=7; x2[3]=2; y1[3]=12; y2[3]=12;
            x1[4]=10; x2[4]=10; y1[4]=4; y2[4]=1;
            x1[5]=11; x2[5]=8; y1[5]=10; y2[5]=10;
            x1[6]=9; x2[6]=9; y1[6]=10; y2[6]=5;
            x1[7]=1; x2[7]=1; y1[7]=14; y2[7]=12;
            x1[8]=7; x2[8]=3; y1[8]=2; y2[8]=2;
            x1[9]=14; x2[9]=14; y1[9]=12; y2[9]=6;
            x1[10]=7; x2[10]=7; y1[10]=13; y2[10]=7;
            x1[11]=2; x2[11]=0; y1[11]=13; y2[11]=13;
            x1[12]=14; x2[12]=6; y1[12]=3; y2[12]=3;
        break;
        case 42:
            x1[0]=5; x2[0]=3; y1[0]=5; y2[0]=5;
            x1[1]=5; x2[1]=1; y1[1]=4; y2[1]=4;
            x1[2]=4; x2[2]=4; y1[2]=12; y2[2]=1;
            x1[3]=13; x2[3]=13; y1[3]=12; y2[3]=0;
            x1[4]=9; x2[4]=3; y1[4]=3; y2[4]=3;
            x1[5]=10; x2[5]=9; y1[5]=8; y2[5]=8;
            x1[6]=10; x2[6]=4; y1[6]=11; y2[6]=11;
            x1[7]=7; x2[7]=1; y1[7]=10; y2[7]=10;
            x1[8]=9; x2[8]=4; y1[8]=0; y2[8]=0;
            x1[9]=7; x2[9]=0; y1[9]=10; y2[9]=10;
            x1[10]=5; x2[10]=5; y1[10]=8; y2[10]=3;
            x1[11]=6; x2[11]=3; y1[11]=9; y2[11]=9;
            x1[12]=8; x2[12]=8; y1[12]=7; y2[12]=1;
        break;
        case 43:
            x1[0]=0; x2[0]=0; y1[0]=13; y2[0]=1;
            x1[1]=7; x2[1]=0; y1[1]=1; y2[1]=1;
            x1[2]=6; x2[2]=6; y1[2]=9; y2[2]=3;
            x1[3]=14; x2[3]=7; y1[3]=12; y2[3]=12;
            x1[4]=4; x2[4]=4; y1[4]=13; y2[4]=8;
            x1[5]=11; x2[5]=2; y1[5]=5; y2[5]=5;
            x1[6]=9; x2[6]=6; y1[6]=7; y2[6]=7;
            x1[7]=4; x2[7]=4; y1[7]=14; y2[7]=10;
            x1[8]=2; x2[8]=2; y1[8]=6; y2[8]=5;
            x1[9]=2; x2[9]=2; y1[9]=4; y2[9]=2;
            x1[10]=11; x2[10]=5; y1[10]=7; y2[10]=7;
            x1[11]=13; x2[11]=11; y1[11]=11; y2[11]=11;
            x1[12]=13; x2[12]=3; y1[12]=13; y2[12]=13;
        break;
        case 44:
            x1[0]=10; x2[0]=0; y1[0]=6; y2[0]=6;
            x1[1]=9; x2[1]=5; y1[1]=11; y2[1]=11;
            x1[2]=7; x2[2]=0; y1[2]=4; y2[2]=4;
            x1[3]=13; x2[3]=0; y1[3]=1; y2[3]=1;
            x1[4]=13; x2[4]=13; y1[4]=13; y2[4]=4;
            x1[5]=12; x2[5]=12; y1[5]=9; y2[5]=8;
            x1[6]=14; x2[6]=4; y1[6]=3; y2[6]=3;
            x1[7]=0; x2[7]=0; y1[7]=11; y2[7]=10;
            x1[8]=13; x2[8]=13; y1[8]=9; y2[8]=4;
            x1[9]=1; x2[9]=0; y1[9]=4; y2[9]=4;
            x1[10]=6; x2[10]=3; y1[10]=12; y2[10]=12;
            x1[11]=2; x2[11]=2; y1[11]=8; y2[11]=6;
            x1[12]=14; x2[12]=0; y1[12]=3; y2[12]=3;
        break;
        case 45:
            x1[0]=3; x2[0]=2; y1[0]=9; y2[0]=9;
            x1[1]=7; x2[1]=7; y1[1]=14; y2[1]=1;
            x1[2]=5; x2[2]=2; y1[2]=14; y2[2]=14;
            x1[3]=13; x2[3]=13; y1[3]=10; y2[3]=8;
            x1[4]=7; x2[4]=3; y1[4]=6; y2[4]=6;
            x1[5]=14; x2[5]=14; y1[5]=5; y2[5]=2;
            x1[6]=5; x2[6]=5; y1[6]=14; y2[6]=10;
            x1[7]=13; x2[7]=13; y1[7]=12; y2[7]=8;
            x1[8]=2; x2[8]=2; y1[8]=14; y2[8]=7;
            x1[9]=14; x2[9]=14; y1[9]=13; y2[9]=3;
            x1[10]=9; x2[10]=1; y1[10]=0; y2[10]=0;
            x1[11]=9; x2[11]=9; y1[11]=14; y2[11]=2;
            x1[12]=4; x2[12]=1; y1[12]=8; y2[12]=8;
        break;
        case 46:
            x1[0]=6; x2[0]=6; y1[0]=8; y2[0]=6;
            x1[1]=14; x2[1]=10; y1[1]=10; y2[1]=10;
            x1[2]=7; x2[2]=3; y1[2]=7; y2[2]=7;
            x1[3]=14; x2[3]=14; y1[3]=9; y2[3]=6;
            x1[4]=12; x2[4]=5; y1[4]=0; y2[4]=0;
            x1[5]=7; x2[5]=6; y1[5]=13; y2[5]=13;
            x1[6]=13; x2[6]=13; y1[6]=6; y2[6]=4;
            x1[7]=11; x2[7]=11; y1[7]=13; y2[7]=10;
            x1[8]=2; x2[8]=2; y1[8]=12; y2[8]=5;
            x1[9]=8; x2[9]=1; y1[9]=6; y2[9]=6;
            x1[10]=12; x2[10]=6; y1[10]=11; y2[10]=11;
            x1[11]=14; x2[11]=14; y1[11]=12; y2[11]=2;
            x1[12]=10; x2[12]=1; y1[12]=0; y2[12]=0;
        break;
        case 47:
            x1[0]=12; x2[0]=12; y1[0]=13; y2[0]=6;
            x1[1]=1; x2[1]=1; y1[1]=3; y2[1]=1;
            x1[2]=6; x2[2]=6; y1[2]=12; y2[2]=3;
            x1[3]=10; x2[3]=9; y1[3]=1; y2[3]=1;
            x1[4]=12; x2[4]=10; y1[4]=9; y2[4]=9;
            x1[5]=14; x2[5]=14; y1[5]=11; y2[5]=8;
            x1[6]=9; x2[6]=2; y1[6]=7; y2[6]=7;
            x1[7]=12; x2[7]=12; y1[7]=6; y2[7]=3;
            x1[8]=7; x2[8]=6; y1[8]=11; y2[8]=11;
            x1[9]=8; x2[9]=8; y1[9]=11; y2[9]=5;
            x1[10]=2; x2[10]=2; y1[10]=14; y2[10]=1;
            x1[11]=3; x2[11]=3; y1[11]=10; y2[11]=4;
            x1[12]=7; x2[12]=7; y1[12]=13; y2[12]=10;
        break;
        case 48:
            x1[0]=13; x2[0]=6; y1[0]=14; y2[0]=14;
            x1[1]=12; x2[1]=12; y1[1]=7; y2[1]=1;
            x1[2]=6; x2[2]=6; y1[2]=10; y2[2]=5;
            x1[3]=4; x2[3]=1; y1[3]=10; y2[3]=10;
            x1[4]=2; x2[4]=2; y1[4]=6; y2[4]=1;
            x1[5]=5; x2[5]=5; y1[5]=9; y2[5]=7;
            x1[6]=10; x2[6]=8; y1[6]=8; y2[6]=8;
            x1[7]=13; x2[7]=1; y1[7]=12; y2[7]=12;
            x1[8]=7; x2[8]=6; y1[8]=2; y2[8]=2;
            x1[9]=9; x2[9]=9; y1[9]=13; y2[9]=12;
            x1[10]=10; x2[10]=10; y1[10]=10; y2[10]=5;
            x1[11]=12; x2[11]=12; y1[11]=8; y2[11]=2;
            x1[12]=9; x2[12]=0; y1[12]=14; y2[12]=14;
        break;
        case 49:
            x1[0]=10; x2[0]=10; y1[0]=14; y2[0]=9;
            x1[1]=4; x2[1]=4; y1[1]=14; y2[1]=12;
            x1[2]=13; x2[2]=7; y1[2]=14; y2[2]=14;
            x1[3]=13; x2[3]=5; y1[3]=14; y2[3]=14;
            x1[4]=13; x2[4]=13; y1[4]=14; y2[4]=7;
            x1[5]=14; x2[5]=7; y1[5]=5; y2[5]=5;
            x1[6]=11; x2[6]=9; y1[6]=13; y2[6]=13;
            x1[7]=14; x2[7]=10; y1[7]=9; y2[7]=9;
            x1[8]=8; x2[8]=6; y1[8]=8; y2[8]=8;
            x1[9]=9; x2[9]=9; y1[9]=12; y2[9]=6;
            x1[10]=14; x2[10]=14; y1[10]=11; y2[10]=6;
            x1[11]=7; x2[11]=0; y1[11]=3; y2[11]=3;
            x1[12]=2; x2[12]=2; y1[12]=5; y2[12]=3;
        break;
        case 50:
            x1[0]=0; x2[0]=0; y1[0]=4; y2[0]=1;
            x1[1]=11; x2[1]=2; y1[1]=12; y2[1]=12;
            x1[2]=13; x2[2]=0; y1[2]=7; y2[2]=7;
            x1[3]=3; x2[3]=3; y1[3]=14; y2[3]=0;
            x1[4]=9; x2[4]=6; y1[4]=1; y2[4]=1;
            x1[5]=14; x2[5]=14; y1[5]=13; y2[5]=2;
            x1[6]=13; x2[6]=4; y1[6]=6; y2[6]=6;
            x1[7]=13; x2[7]=5; y1[7]=11; y2[7]=11;
            x1[8]=14; x2[8]=12; y1[8]=12; y2[8]=12;
            x1[9]=12; x2[9]=12; y1[9]=4; y2[9]=0;
            x1[10]=13; x2[10]=8; y1[10]=10; y2[10]=10;
            x1[11]=14; x2[11]=4; y1[11]=8; y2[11]=8;
            x1[12]=5; x2[12]=1; y1[12]=7; y2[12]=7;
        break;
        case 51:
            x1[0]=12; x2[0]=12; y1[0]=13; y2[0]=10;
            x1[1]=12; x2[1]=12; y1[1]=11; y2[1]=6;
            x1[2]=12; x2[2]=2; y1[2]=7; y2[2]=7;
            x1[3]=10; x2[3]=10; y1[3]=10; y2[3]=6;
            x1[4]=7; x2[4]=7; y1[4]=13; y2[4]=0;
            x1[5]=13; x2[5]=2; y1[5]=6; y2[5]=6;
            x1[6]=1; x2[6]=1; y1[6]=12; y2[6]=9;
            x1[7]=12; x2[7]=12; y1[7]=5; y2[7]=3;
            x1[8]=14; x2[8]=11; y1[8]=2; y2[8]=2;
            x1[9]=6; x2[9]=0; y1[9]=0; y2[9]=0;
            x1[10]=9; x2[10]=6; y1[10]=12; y2[10]=12;
            x1[11]=10; x2[11]=10; y1[11]=14; y2[11]=3;
            x1[12]=9; x2[12]=2; y1[12]=11; y2[12]=11;
        break;
        case 52:
            x1[0]=8; x2[0]=8; y1[0]=13; y2[0]=5;
            x1[1]=5; x2[1]=0; y1[1]=4; y2[1]=4;
            x1[2]=6; x2[2]=6; y1[2]=14; y2[2]=8;
            x1[3]=13; x2[3]=13; y1[3]=14; y2[3]=12;
            x1[4]=11; x2[4]=11; y1[4]=14; y2[4]=4;
            x1[5]=9; x2[5]=7; y1[5]=10; y2[5]=10;
            x1[6]=1; x2[6]=0; y1[6]=6; y2[6]=6;
            x1[7]=11; x2[7]=8; y1[7]=2; y2[7]=2;
            x1[8]=1; x2[8]=0; y1[8]=2; y2[8]=2;
            x1[9]=12; x2[9]=12; y1[9]=11; y2[9]=4;
            x1[10]=6; x2[10]=0; y1[10]=13; y2[10]=13;
            x1[11]=11; x2[11]=11; y1[11]=9; y2[11]=2;
            x1[12]=9; x2[12]=9; y1[12]=12; y2[12]=10;
        break;
        case 53:
            x1[0]=8; x2[0]=1; y1[0]=3; y2[0]=3;
            x1[1]=5; x2[1]=0; y1[1]=13; y2[1]=13;
            x1[2]=8; x2[2]=8; y1[2]=12; y2[2]=3;
            x1[3]=11; x2[3]=11; y1[3]=11; y2[3]=9;
            x1[4]=14; x2[4]=4; y1[4]=7; y2[4]=7;
            x1[5]=12; x2[5]=9; y1[5]=13; y2[5]=13;
            x1[6]=13; x2[6]=0; y1[6]=2; y2[6]=2;
            x1[7]=13; x2[7]=5; y1[7]=5; y2[7]=5;
            x1[8]=6; x2[8]=6; y1[8]=5; y2[8]=2;
            x1[9]=3; x2[9]=3; y1[9]=8; y2[9]=1;
            x1[10]=12; x2[10]=2; y1[10]=4; y2[10]=4;
            x1[11]=14; x2[11]=1; y1[11]=8; y2[11]=8;
            x1[12]=6; x2[12]=3; y1[12]=7; y2[12]=7;
        break;
        case 54:
            x1[0]=11; x2[0]=11; y1[0]=6; y2[0]=0;
            x1[1]=4; x2[1]=4; y1[1]=9; y2[1]=6;
            x1[2]=2; x2[2]=2; y1[2]=10; y2[2]=0;
            x1[3]=11; x2[3]=4; y1[3]=1; y2[3]=1;
            x1[4]=4; x2[4]=0; y1[4]=13; y2[4]=13;
            x1[5]=12; x2[5]=12; y1[5]=4; y2[5]=1;
            x1[6]=11; x2[6]=7; y1[6]=2; y2[6]=2;
            x1[7]=5; x2[7]=5; y1[7]=12; y2[7]=7;
            x1[8]=5; x2[8]=2; y1[8]=1; y2[8]=1;
            x1[9]=0; x2[9]=0; y1[9]=11; y2[9]=5;
            x1[10]=2; x2[10]=2; y1[10]=11; y2[10]=10;
            x1[11]=12; x2[11]=4; y1[11]=5; y2[11]=5;
            x1[12]=2; x2[12]=0; y1[12]=12; y2[12]=12;
        break;
        case 55:
            x1[0]=12; x2[0]=4; y1[0]=12; y2[0]=12;
            x1[1]=12; x2[1]=11; y1[1]=9; y2[1]=9;
            x1[2]=8; x2[2]=3; y1[2]=13; y2[2]=13;
            x1[3]=11; x2[3]=0; y1[3]=12; y2[3]=12;
            x1[4]=7; x2[4]=2; y1[4]=4; y2[4]=4;
            x1[5]=0; x2[5]=0; y1[5]=11; y2[5]=1;
            x1[6]=11; x2[6]=11; y1[6]=4; y2[6]=3;
            x1[7]=4; x2[7]=3; y1[7]=13; y2[7]=13;
            x1[8]=9; x2[8]=9; y1[8]=14; y2[8]=1;
            x1[9]=14; x2[9]=11; y1[9]=0; y2[9]=0;
            x1[10]=11; x2[10]=11; y1[10]=5; y2[10]=3;
            x1[11]=11; x2[11]=11; y1[11]=10; y2[11]=2;
            x1[12]=9; x2[12]=0; y1[12]=11; y2[12]=11;
        break;
        case 56:
            x1[0]=4; x2[0]=4; y1[0]=14; y2[0]=13;
            x1[1]=9; x2[1]=9; y1[1]=14; y2[1]=12;
            x1[2]=0; x2[2]=0; y1[2]=3; y2[2]=1;
            x1[3]=8; x2[3]=4; y1[3]=2; y2[3]=2;
            x1[4]=4; x2[4]=2; y1[4]=2; y2[4]=2;
            x1[5]=13; x2[5]=11; y1[5]=8; y2[5]=8;
            x1[6]=9; x2[6]=9; y1[6]=11; y2[6]=9;
            x1[7]=2; x2[7]=2; y1[7]=12; y2[7]=9;
            x1[8]=13; x2[8]=13; y1[8]=13; y2[8]=7;
            x1[9]=6; x2[9]=6; y1[9]=2; y2[9]=1;
            x1[10]=9; x2[10]=0; y1[10]=12; y2[10]=12;
            x1[11]=5; x2[11]=5; y1[11]=7; y2[11]=3;
            x1[12]=6; x2[12]=6; y1[12]=4; y2[12]=1;
        break;
        case 57:
            x1[0]=0; x2[0]=0; y1[0]=8; y2[0]=3;
            x1[1]=8; x2[1]=5; y1[1]=1; y2[1]=1;
            x1[2]=13; x2[2]=8; y1[2]=11; y2[2]=11;
            x1[3]=8; x2[3]=0; y1[3]=5; y2[3]=5;
            x1[4]=10; x2[4]=7; y1[4]=13; y2[4]=13;
            x1[5]=6; x2[5]=6; y1[5]=10; y2[5]=7;
            x1[6]=11; x2[6]=9; y1[6]=8; y2[6]=8;
            x1[7]=3; x2[7]=3; y1[7]=14; y2[7]=4;
            x1[8]=9; x2[8]=9; y1[8]=9; y2[8]=7;
            x1[9]=9; x2[9]=8; y1[9]=14; y2[9]=14;
            x1[10]=6; x2[10]=6; y1[10]=14; y2[10]=2;
            x1[11]=9; x2[11]=9; y1[11]=9; y2[11]=2;
            x1[12]=4; x2[12]=4; y1[12]=9; y2[12]=8;
        break;
        case 58:
            x1[0]=5; x2[0]=2; y1[0]=8; y2[0]=8;
            x1[1]=14; x2[1]=14; y1[1]=13; y2[1]=0;
            x1[2]=6; x2[2]=4; y1[2]=14; y2[2]=14;
            x1[3]=7; x2[3]=5; y1[3]=9; y2[3]=9;
            x1[4]=13; x2[4]=9; y1[4]=5; y2[4]=5;
            x1[5]=0; x2[5]=0; y1[5]=12; y2[5]=11;
            x1[6]=0; x2[6]=0; y1[6]=9; y2[6]=8;
            x1[7]=2; x2[7]=2; y1[7]=10; y2[7]=9;
            x1[8]=13; x2[8]=4; y1[8]=9; y2[8]=9;
            x1[9]=13; x2[9]=3; y1[9]=0; y2[9]=0;
            x1[10]=5; x2[10]=5; y1[10]=11; y2[10]=9;
            x1[11]=11; x2[11]=2; y1[11]=8; y2[11]=8;
            x1[12]=10; x2[12]=10; y1[12]=5; y2[12]=0;
        break;
        case 59:
            x1[0]=5; x2[0]=5; y1[0]=10; y2[0]=5;
            x1[1]=1; x2[1]=1; y1[1]=12; y2[1]=10;
            x1[2]=12; x2[2]=12; y1[2]=9; y2[2]=1;
            x1[3]=14; x2[3]=13; y1[3]=14; y2[3]=14;
            x1[4]=0; x2[4]=0; y1[4]=10; y2[4]=4;
            x1[5]=10; x2[5]=0; y1[5]=10; y2[5]=10;
            x1[6]=13; x2[6]=12; y1[6]=13; y2[6]=13;
            x1[7]=14; x2[7]=6; y1[7]=9; y2[7]=9;
            x1[8]=0; x2[8]=0; y1[8]=6; y2[8]=3;
            x1[9]=10; x2[9]=9; y1[9]=0; y2[9]=0;
            x1[10]=0; x2[10]=0; y1[10]=13; y2[10]=9;
            x1[11]=2; x2[11]=2; y1[11]=14; y2[11]=6;
            x1[12]=9; x2[12]=7; y1[12]=1; y2[12]=1;
        break;
        case 60:
            x1[0]=12; x2[0]=12; y1[0]=10; y2[0]=7;
            x1[1]=9; x2[1]=9; y1[1]=6; y2[1]=0;
            x1[2]=12; x2[2]=12; y1[2]=14; y2[2]=2;
            x1[3]=8; x2[3]=1; y1[3]=14; y2[3]=14;
            x1[4]=6; x2[4]=1; y1[4]=1; y2[4]=1;
            x1[5]=11; x2[5]=8; y1[5]=14; y2[5]=14;
            x1[6]=9; x2[6]=9; y1[6]=5; y2[6]=2;
            x1[7]=14; x2[7]=14; y1[7]=9; y2[7]=7;
            x1[8]=5; x2[8]=5; y1[8]=7; y2[8]=4;
            x1[9]=2; x2[9]=2; y1[9]=3; y2[9]=0;
            x1[10]=4; x2[10]=4; y1[10]=7; y2[10]=6;
            x1[11]=11; x2[11]=11; y1[11]=12; y2[11]=7;
            x1[12]=3; x2[12]=3; y1[12]=7; y2[12]=3;
        break;
        case 61:
            x1[0]=14; x2[0]=14; y1[0]=9; y2[0]=0;
            x1[1]=14; x2[1]=7; y1[1]=13; y2[1]=13;
            x1[2]=10; x2[2]=10; y1[2]=9; y2[2]=8;
            x1[3]=14; x2[3]=14; y1[3]=6; y2[3]=2;
            x1[4]=6; x2[4]=6; y1[4]=8; y2[4]=4;
            x1[5]=6; x2[5]=6; y1[5]=11; y2[5]=5;
            x1[6]=8; x2[6]=8; y1[6]=12; y2[6]=9;
            x1[7]=7; x2[7]=0; y1[7]=13; y2[7]=13;
            x1[8]=2; x2[8]=2; y1[8]=5; y2[8]=2;
            x1[9]=14; x2[9]=7; y1[9]=10; y2[9]=10;
            x1[10]=8; x2[10]=8; y1[10]=8; y2[10]=4;
            x1[11]=13; x2[11]=7; y1[11]=5; y2[11]=5;
            x1[12]=11; x2[12]=10; y1[12]=13; y2[12]=13;
        break;
        case 62:
            x1[0]=5; x2[0]=5; y1[0]=5; y2[0]=4;
            x1[1]=11; x2[1]=0; y1[1]=10; y2[1]=10;
            x1[2]=10; x2[2]=3; y1[2]=14; y2[2]=14;
            x1[3]=11; x2[3]=3; y1[3]=10; y2[3]=10;
            x1[4]=2; x2[4]=0; y1[4]=1; y2[4]=1;
            x1[5]=6; x2[5]=6; y1[5]=7; y2[5]=2;
            x1[6]=11; x2[6]=8; y1[6]=1; y2[6]=1;
            x1[7]=10; x2[7]=10; y1[7]=14; y2[7]=12;
            x1[8]=5; x2[8]=5; y1[8]=10; y2[8]=9;
            x1[9]=6; x2[9]=2; y1[9]=12; y2[9]=12;
            x1[10]=10; x2[10]=0; y1[10]=8; y2[10]=8;
            x1[11]=5; x2[11]=1; y1[11]=1; y2[11]=1;
            x1[12]=11; x2[12]=1; y1[12]=8; y2[12]=8;
        break;
        case 63:
            x1[0]=12; x2[0]=8; y1[0]=13; y2[0]=13;
            x1[1]=12; x2[1]=12; y1[1]=9; y2[1]=4;
            x1[2]=4; x2[2]=4; y1[2]=12; y2[2]=2;
            x1[3]=7; x2[3]=7; y1[3]=11; y2[3]=6;
            x1[4]=10; x2[4]=4; y1[4]=10; y2[4]=10;
            x1[5]=0; x2[5]=0; y1[5]=12; y2[5]=4;
            x1[6]=9; x2[6]=7; y1[6]=9; y2[6]=9;
            x1[7]=3; x2[7]=3; y1[7]=10; y2[7]=7;
            x1[8]=9; x2[8]=9; y1[8]=4; y2[8]=2;
            x1[9]=5; x2[9]=5; y1[9]=3; y2[9]=1;
            x1[10]=10; x2[10]=0; y1[10]=9; y2[10]=9;
            x1[11]=5; x2[11]=1; y1[11]=6; y2[11]=6;
            x1[12]=9; x2[12]=9; y1[12]=4; y2[12]=3;
        break;
        case 64:
            x1[0]=11; x2[0]=6; y1[0]=14; y2[0]=14;
            x1[1]=11; x2[1]=10; y1[1]=7; y2[1]=7;
            x1[2]=8; x2[2]=3; y1[2]=6; y2[2]=6;
            x1[3]=7; x2[3]=7; y1[3]=11; y2[3]=8;
            x1[4]=10; x2[4]=6; y1[4]=4; y2[4]=4;
            x1[5]=10; x2[5]=6; y1[5]=11; y2[5]=11;
            x1[6]=14; x2[6]=14; y1[6]=14; y2[6]=10;
            x1[7]=3; x2[7]=3; y1[7]=8; y2[7]=3;
            x1[8]=14; x2[8]=14; y1[8]=11; y2[8]=5;
            x1[9]=9; x2[9]=9; y1[9]=7; y2[9]=5;
            x1[10]=9; x2[10]=5; y1[10]=8; y2[10]=8;
            x1[11]=12; x2[11]=6; y1[11]=1; y2[11]=1;
            x1[12]=14; x2[12]=11; y1[12]=8; y2[12]=8;
        break;
        case 65:
            x1[0]=11; x2[0]=5; y1[0]=14; y2[0]=14;
            x1[1]=8; x2[1]=6; y1[1]=9; y2[1]=9;
            x1[2]=1; x2[2]=1; y1[2]=5; y2[2]=0;
            x1[3]=11; x2[3]=11; y1[3]=7; y2[3]=6;
            x1[4]=13; x2[4]=13; y1[4]=7; y2[4]=2;
            x1[5]=4; x2[5]=4; y1[5]=9; y2[5]=4;
            x1[6]=8; x2[6]=7; y1[6]=1; y2[6]=1;
            x1[7]=13; x2[7]=11; y1[7]=4; y2[7]=4;
            x1[8]=3; x2[8]=3; y1[8]=4; y2[8]=3;
            x1[9]=13; x2[9]=13; y1[9]=14; y2[9]=3;
            x1[10]=6; x2[10]=2; y1[10]=1; y2[10]=1;
            x1[11]=10; x2[11]=10; y1[11]=13; y2[11]=0;
            x1[12]=4; x2[12]=1; y1[12]=4; y2[12]=4;
        break;
        case 66:
            x1[0]=1; x2[0]=1; y1[0]=9; y2[0]=2;
            x1[1]=11; x2[1]=11; y1[1]=9; y2[1]=1;
            x1[2]=10; x2[2]=10; y1[2]=8; y2[2]=1;
            x1[3]=13; x2[3]=13; y1[3]=10; y2[3]=2;
            x1[4]=9; x2[4]=9; y1[4]=13; y2[4]=6;
            x1[5]=14; x2[5]=13; y1[5]=8; y2[5]=8;
            x1[6]=13; x2[6]=13; y1[6]=4; y2[6]=3;
            x1[7]=6; x2[7]=4; y1[7]=7; y2[7]=7;
            x1[8]=13; x2[8]=8; y1[8]=1; y2[8]=1;
            x1[9]=13; x2[9]=13; y1[9]=6; y2[9]=0;
            x1[10]=7; x2[10]=0; y1[10]=11; y2[10]=11;
            x1[11]=6; x2[11]=6; y1[11]=6; y2[11]=3;
            x1[12]=8; x2[12]=8; y1[12]=7; y2[12]=6;
        break;
        case 67:
            x1[0]=5; x2[0]=5; y1[0]=13; y2[0]=4;
            x1[1]=12; x2[1]=1; y1[1]=11; y2[1]=11;
            x1[2]=10; x2[2]=5; y1[2]=10; y2[2]=10;
            x1[3]=13; x2[3]=3; y1[3]=12; y2[3]=12;
            x1[4]=6; x2[4]=6; y1[4]=13; y2[4]=11;
            x1[5]=11; x2[5]=7; y1[5]=6; y2[5]=6;
            x1[6]=12; x2[6]=12; y1[6]=8; y2[6]=7;
            x1[7]=11; x2[7]=11; y1[7]=5; y2[7]=4;
            x1[8]=1; x2[8]=1; y1[8]=13; y2[8]=0;
            x1[9]=8; x2[9]=8; y1[9]=10; y2[9]=9;
            x1[10]=2; x2[10]=2; y1[10]=9; y2[10]=3;
            x1[11]=5; x2[11]=1; y1[11]=14; y2[11]=14;
            x1[12]=4; x2[12]=2; y1[12]=10; y2[12]=10;
        break;
        case 68:
            x1[0]=8; x2[0]=8; y1[0]=14; y2[0]=1;
            x1[1]=8; x2[1]=8; y1[1]=5; y2[1]=1;
            x1[2]=1; x2[2]=1; y1[2]=11; y2[2]=6;
            x1[3]=4; x2[3]=0; y1[3]=9; y2[3]=9;
            x1[4]=10; x2[4]=10; y1[4]=10; y2[4]=3;
            x1[5]=13; x2[5]=3; y1[5]=1; y2[5]=1;
            x1[6]=13; x2[6]=13; y1[6]=14; y2[6]=10;
            x1[7]=13; x2[7]=13; y1[7]=4; y2[7]=1;
            x1[8]=7; x2[8]=3; y1[8]=1; y2[8]=1;
            x1[9]=6; x2[9]=1; y1[9]=8; y2[9]=8;
            x1[10]=0; x2[10]=0; y1[10]=5; y2[10]=4;
            x1[11]=1; x2[11]=1; y1[11]=11; y2[11]=4;
            x1[12]=12; x2[12]=9; y1[12]=0; y2[12]=0;
        break;
        case 69:
            x1[0]=0; x2[0]=0; y1[0]=14; y2[0]=1;
            x1[1]=8; x2[1]=1; y1[1]=2; y2[1]=2;
            x1[2]=13; x2[2]=5; y1[2]=9; y2[2]=9;
            x1[3]=4; x2[3]=4; y1[3]=14; y2[3]=9;
            x1[4]=5; x2[4]=0; y1[4]=0; y2[4]=0;
            x1[5]=14; x2[5]=8; y1[5]=1; y2[5]=1;
            x1[6]=1; x2[6]=1; y1[6]=13; y2[6]=3;
            x1[7]=6; x2[7]=6; y1[7]=4; y2[7]=2;
            x1[8]=3; x2[8]=1; y1[8]=2; y2[8]=2;
            x1[9]=6; x2[9]=1; y1[9]=3; y2[9]=3;
            x1[10]=11; x2[10]=3; y1[10]=5; y2[10]=5;
            x1[11]=9; x2[11]=0; y1[11]=8; y2[11]=8;
            x1[12]=13; x2[12]=11; y1[12]=6; y2[12]=6;
        break;
        case 70:
            x1[0]=11; x2[0]=0; y1[0]=2; y2[0]=2;
            x1[1]=6; x2[1]=6; y1[1]=9; y2[1]=7;
            x1[2]=2; x2[2]=2; y1[2]=5; y2[2]=1;
            x1[3]=12; x2[3]=12; y1[3]=13; y2[3]=8;
            x1[4]=2; x2[4]=2; y1[4]=9; y2[4]=4;
            x1[5]=14; x2[5]=9; y1[5]=4; y2[5]=4;
            x1[6]=9; x2[6]=9; y1[6]=4; y2[6]=1;
            x1[7]=4; x2[7]=3; y1[7]=5; y2[7]=5;
            x1[8]=10; x2[8]=5; y1[8]=3; y2[8]=3;
            x1[9]=1; x2[9]=1; y1[9]=13; y2[9]=10;
            x1[10]=12; x2[10]=3; y1[10]=12; y2[10]=12;
            x1[11]=11; x2[11]=1; y1[11]=4; y2[11]=4;
            x1[12]=5; x2[12]=3; y1[12]=3; y2[12]=3;
        break;
        case 71:
            x1[0]=12; x2[0]=8; y1[0]=0; y2[0]=0;
            x1[1]=10; x2[1]=7; y1[1]=3; y2[1]=3;
            x1[2]=3; x2[2]=0; y1[2]=2; y2[2]=2;
            x1[3]=12; x2[3]=12; y1[3]=12; y2[3]=10;
            x1[4]=11; x2[4]=0; y1[4]=7; y2[4]=7;
            x1[5]=12; x2[5]=12; y1[5]=3; y2[5]=0;
            x1[6]=13; x2[6]=13; y1[6]=9; y2[6]=5;
            x1[7]=10; x2[7]=9; y1[7]=6; y2[7]=6;
            x1[8]=4; x2[8]=2; y1[8]=14; y2[8]=14;
            x1[9]=11; x2[9]=11; y1[9]=6; y2[9]=4;
            x1[10]=7; x2[10]=7; y1[10]=9; y2[10]=3;
            x1[11]=7; x2[11]=7; y1[11]=10; y2[11]=8;
            x1[12]=13; x2[12]=0; y1[12]=6; y2[12]=6;
        break;
        case 72:
            x1[0]=10; x2[0]=3; y1[0]=5; y2[0]=5;
            x1[1]=10; x2[1]=1; y1[1]=8; y2[1]=8;
            x1[2]=12; x2[2]=10; y1[2]=7; y2[2]=7;
            x1[3]=1; x2[3]=1; y1[3]=12; y2[3]=4;
            x1[4]=4; x2[4]=4; y1[4]=9; y2[4]=2;
            x1[5]=10; x2[5]=5; y1[5]=14; y2[5]=14;
            x1[6]=14; x2[6]=2; y1[6]=13; y2[6]=13;
            x1[7]=1; x2[7]=1; y1[7]=11; y2[7]=10;
            x1[8]=13; x2[8]=13; y1[8]=9; y2[8]=1;
            x1[9]=13; x2[9]=8; y1[9]=3; y2[9]=3;
            x1[10]=11; x2[10]=7; y1[10]=9; y2[10]=9;
            x1[11]=12; x2[11]=4; y1[11]=3; y2[11]=3;
            x1[12]=4; x2[12]=0; y1[12]=2; y2[12]=2;
        break;
        case 73:
            x1[0]=4; x2[0]=0; y1[0]=12; y2[0]=12;
            x1[1]=2; x2[1]=1; y1[1]=10; y2[1]=10;
            x1[2]=9; x2[2]=8; y1[2]=3; y2[2]=3;
            x1[3]=13; x2[3]=13; y1[3]=12; y2[3]=11;
            x1[4]=9; x2[4]=5; y1[4]=2; y2[4]=2;
            x1[5]=3; x2[5]=3; y1[5]=2; y2[5]=1;
            x1[6]=0; x2[6]=0; y1[6]=12; y2[6]=2;
            x1[7]=14; x2[7]=5; y1[7]=14; y2[7]=14;
            x1[8]=2; x2[8]=2; y1[8]=14; y2[8]=8;
            x1[9]=12; x2[9]=12; y1[9]=10; y2[9]=6;
            x1[10]=10; x2[10]=10; y1[10]=8; y2[10]=4;
            x1[11]=12; x2[11]=12; y1[11]=11; y2[11]=1;
            x1[12]=2; x2[12]=2; y1[12]=14; y2[12]=9;
        break;
        case 74:
            x1[0]=9; x2[0]=9; y1[0]=11; y2[0]=2;
            x1[1]=8; x2[1]=8; y1[1]=14; y2[1]=13;
            x1[2]=7; x2[2]=7; y1[2]=11; y2[2]=10;
            x1[3]=9; x2[3]=9; y1[3]=11; y2[3]=7;
            x1[4]=14; x2[4]=10; y1[4]=3; y2[4]=3;
            x1[5]=9; x2[5]=6; y1[5]=9; y2[5]=9;
            x1[6]=10; x2[6]=10; y1[6]=9; y2[6]=4;
            x1[7]=3; x2[7]=1; y1[7]=1; y2[7]=1;
            x1[8]=13; x2[8]=12; y1[8]=2; y2[8]=2;
            x1[9]=8; x2[9]=8; y1[9]=10; y2[9]=3;
            x1[10]=9; x2[10]=9; y1[10]=2; y2[10]=0;
            x1[11]=8; x2[11]=5; y1[11]=12; y2[11]=12;
            x1[12]=11; x2[12]=11; y1[12]=14; y2[12]=0;
        break;
        case 75:
            x1[0]=12; x2[0]=12; y1[0]=11; y2[0]=2;
            x1[1]=4; x2[1]=4; y1[1]=8; y2[1]=3;
            x1[2]=7; x2[2]=2; y1[2]=14; y2[2]=14;
            x1[3]=14; x2[3]=4; y1[3]=4; y2[3]=4;
            x1[4]=7; x2[4]=7; y1[4]=5; y2[4]=1;
            x1[5]=14; x2[5]=6; y1[5]=10; y2[5]=10;
            x1[6]=13; x2[6]=9; y1[6]=0; y2[6]=0;
            x1[7]=5; x2[7]=5; y1[7]=11; y2[7]=4;
            x1[8]=10; x2[8]=1; y1[8]=10; y2[8]=10;
            x1[9]=0; x2[9]=0; y1[9]=10; y2[9]=7;
            x1[10]=5; x2[10]=4; y1[10]=7; y2[10]=7;
            x1[11]=14; x2[11]=4; y1[11]=14; y2[11]=14;
            x1[12]=9; x2[12]=0; y1[12]=2; y2[12]=2;
        break;
        case 76:
            x1[0]=14; x2[0]=4; y1[0]=6; y2[0]=6;
            x1[1]=14; x2[1]=3; y1[1]=3; y2[1]=3;
            x1[2]=13; x2[2]=7; y1[2]=2; y2[2]=2;
            x1[3]=2; x2[3]=0; y1[3]=10; y2[3]=10;
            x1[4]=4; x2[4]=4; y1[4]=13; y2[4]=4;
            x1[5]=9; x2[5]=3; y1[5]=1; y2[5]=1;
            x1[6]=11; x2[6]=11; y1[6]=13; y2[6]=4;
            x1[7]=13; x2[7]=13; y1[7]=8; y2[7]=1;
            x1[8]=1; x2[8]=0; y1[8]=1; y2[8]=1;
            x1[9]=8; x2[9]=3; y1[9]=14; y2[9]=14;
            x1[10]=12; x2[10]=12; y1[10]=6; y2[10]=0;
            x1[11]=11; x2[11]=11; y1[11]=10; y2[11]=5;
            x1[12]=7; x2[12]=6; y1[12]=9; y2[12]=9;
        break;
        case 77:
            x1[0]=3; x2[0]=3; y1[0]=12; y2[0]=6;
            x1[1]=0; x2[1]=0; y1[1]=7; y2[1]=6;
            x1[2]=3; x2[2]=0; y1[2]=9; y2[2]=9;
            x1[3]=14; x2[3]=3; y1[3]=1; y2[3]=1;
            x1[4]=9; x2[4]=0; y1[4]=1; y2[4]=1;
            x1[5]=1; x2[5]=1; y1[5]=14; y2[5]=6;
            x1[6]=13; x2[6]=6; y1[6]=7; y2[6]=7;
            x1[7]=12; x2[7]=7; y1[7]=0; y2[7]=0;
            x1[8]=14; x2[8]=4; y1[8]=2; y2[8]=2;
            x1[9]=3; x2[9]=3; y1[9]=13; y2[9]=7;
            x1[10]=7; x2[10]=7; y1[10]=10; y2[10]=6;
            x1[11]=4; x2[11]=4; y1[11]=13; y2[11]=2;
            x1[12]=13; x2[12]=13; y1[12]=10; y2[12]=1;
        break;
        case 78:
            x1[0]=13; x2[0]=13; y1[0]=13; y2[0]=12;
            x1[1]=1; x2[1]=1; y1[1]=13; y2[1]=1;
            x1[2]=0; x2[2]=0; y1[2]=5; y2[2]=3;
            x1[3]=14; x2[3]=14; y1[3]=13; y2[3]=10;
            x1[4]=14; x2[4]=14; y1[4]=10; y2[4]=2;
            x1[5]=7; x2[5]=2; y1[5]=1; y2[5]=1;
            x1[6]=2; x2[6]=2; y1[6]=13; y2[6]=4;
            x1[7]=14; x2[7]=9; y1[7]=11; y2[7]=11;
            x1[8]=5; x2[8]=3; y1[8]=4; y2[8]=4;
            x1[9]=12; x2[9]=6; y1[9]=9; y2[9]=9;
            x1[10]=4; x2[10]=4; y1[10]=10; y2[10]=1;
            x1[11]=11; x2[11]=3; y1[11]=4; y2[11]=4;
            x1[12]=1; x2[12]=1; y1[12]=8; y2[12]=1;
        break;
        case 79:
            x1[0]=5; x2[0]=5; y1[0]=11; y2[0]=6;
            x1[1]=2; x2[1]=2; y1[1]=10; y2[1]=5;
            x1[2]=13; x2[2]=0; y1[2]=10; y2[2]=10;
            x1[3]=10; x2[3]=8; y1[3]=7; y2[3]=7;
            x1[4]=11; x2[4]=11; y1[4]=7; y2[4]=2;
            x1[5]=11; x2[5]=1; y1[5]=0; y2[5]=0;
            x1[6]=10; x2[6]=5; y1[6]=0; y2[6]=0;
            x1[7]=10; x2[7]=10; y1[7]=14; y2[7]=13;
            x1[8]=5; x2[8]=5; y1[8]=4; y2[8]=3;
            x1[9]=3; x2[9]=3; y1[9]=5; y2[9]=2;
            x1[10]=12; x2[10]=8; y1[10]=2; y2[10]=2;
            x1[11]=5; x2[11]=5; y1[11]=13; y2[11]=12;
            x1[12]=2; x2[12]=2; y1[12]=8; y2[12]=2;
        break;
        case 80:
            x1[0]=12; x2[0]=12; y1[0]=6; y2[0]=4;
            x1[1]=7; x2[1]=2; y1[1]=9; y2[1]=9;
            x1[2]=7; x2[2]=7; y1[2]=3; y2[2]=2;
            x1[3]=7; x2[3]=2; y1[3]=2; y2[3]=2;
            x1[4]=10; x2[4]=10; y1[4]=11; y2[4]=9;
            x1[5]=4; x2[5]=3; y1[5]=11; y2[5]=11;
            x1[6]=1; x2[6]=1; y1[6]=7; y2[6]=4;
            x1[7]=4; x2[7]=4; y1[7]=14; y2[7]=3;
            x1[8]=9; x2[8]=6; y1[8]=14; y2[8]=14;
            x1[9]=9; x2[9]=9; y1[9]=3; y2[9]=0;
            x1[10]=14; x2[10]=14; y1[10]=1; y2[10]=0;
            x1[11]=11; x2[11]=10; y1[11]=12; y2[11]=12;
            x1[12]=13; x2[12]=12; y1[12]=12; y2[12]=12;
        break;
        case 81:
            x1[0]=8; x2[0]=8; y1[0]=8; y2[0]=0;
            x1[1]=6; x2[1]=5; y1[1]=9; y2[1]=9;
            x1[2]=13; x2[2]=5; y1[2]=12; y2[2]=12;
            x1[3]=12; x2[3]=12; y1[3]=10; y2[3]=3;
            x1[4]=13; x2[4]=13; y1[4]=13; y2[4]=1;
            x1[5]=9; x2[5]=2; y1[5]=0; y2[5]=0;
            x1[6]=12; x2[6]=12; y1[6]=14; y2[6]=9;
            x1[7]=14; x2[7]=14; y1[7]=8; y2[7]=4;
            x1[8]=10; x2[8]=2; y1[8]=7; y2[8]=7;
            x1[9]=13; x2[9]=11; y1[9]=3; y2[9]=3;
            x1[10]=9; x2[10]=3; y1[10]=12; y2[10]=12;
            x1[11]=6; x2[11]=0; y1[11]=6; y2[11]=6;
            x1[12]=8; x2[12]=7; y1[12]=12; y2[12]=12;
        break;
        case 82:
            x1[0]=14; x2[0]=14; y1[0]=12; y2[0]=8;
            x1[1]=3; x2[1]=2; y1[1]=12; y2[1]=12;
            x1[2]=9; x2[2]=7; y1[2]=7; y2[2]=7;
            x1[3]=9; x2[3]=2; y1[3]=3; y2[3]=3;
            x1[4]=6; x2[4]=6; y1[4]=11; y2[4]=10;
            x1[5]=11; x2[5]=11; y1[5]=13; y2[5]=2;
            x1[6]=2; x2[6]=2; y1[6]=12; y2[6]=4;
            x1[7]=14; x2[7]=0; y1[7]=8; y2[7]=8;
            x1[8]=5; x2[8]=5; y1[8]=9; y2[8]=5;
            x1[9]=6; x2[9]=5; y1[9]=3; y2[9]=3;
            x1[10]=9; x2[10]=9; y1[10]=9; y2[10]=0;
            x1[11]=5; x2[11]=1; y1[11]=9; y2[11]=9;
            x1[12]=8; x2[12]=8; y1[12]=14; y2[12]=3;
        break;
        case 83:
            x1[0]=10; x2[0]=10; y1[0]=14; y2[0]=6;
            x1[1]=10; x2[1]=1; y1[1]=3; y2[1]=3;
            x1[2]=10; x2[2]=10; y1[2]=13; y2[2]=2;
            x1[3]=13; x2[3]=1; y1[3]=10; y2[3]=10;
            x1[4]=1; x2[4]=1; y1[4]=14; y2[4]=5;
            x1[5]=8; x2[5]=0; y1[5]=8; y2[5]=8;
            x1[6]=12; x2[6]=7; y1[6]=1; y2[6]=1;
            x1[7]=4; x2[7]=4; y1[7]=12; y2[7]=7;
            x1[8]=10; x2[8]=9; y1[8]=2; y2[8]=2;
            x1[9]=11; x2[9]=5; y1[9]=13; y2[9]=13;
            x1[10]=0; x2[10]=0; y1[10]=6; y2[10]=0;
            x1[11]=2; x2[11]=2; y1[11]=9; y2[11]=6;
            x1[12]=3; x2[12]=3; y1[12]=4; y2[12]=1;
        break;
        case 84:
            x1[0]=4; x2[0]=4; y1[0]=13; y2[0]=6;
            x1[1]=10; x2[1]=10; y1[1]=7; y2[1]=3;
            x1[2]=14; x2[2]=2; y1[2]=4; y2[2]=4;
            x1[3]=10; x2[3]=0; y1[3]=1; y2[3]=1;
            x1[4]=9; x2[4]=8; y1[4]=4; y2[4]=4;
            x1[5]=5; x2[5]=2; y1[5]=2; y2[5]=2;
            x1[6]=10; x2[6]=9; y1[6]=14; y2[6]=14;
            x1[7]=11; x2[7]=11; y1[7]=2; y2[7]=1;
            x1[8]=6; x2[8]=6; y1[8]=11; y2[8]=3;
            x1[9]=13; x2[9]=3; y1[9]=9; y2[9]=9;
            x1[10]=10; x2[10]=0; y1[10]=4; y2[10]=4;
            x1[11]=9; x2[11]=5; y1[11]=12; y2[11]=12;
            x1[12]=3; x2[12]=1; y1[12]=9; y2[12]=9;
        break;
        case 85:
            x1[0]=8; x2[0]=8; y1[0]=12; y2[0]=7;
            x1[1]=10; x2[1]=4; y1[1]=13; y2[1]=13;
            x1[2]=14; x2[2]=1; y1[2]=13; y2[2]=13;
            x1[3]=9; x2[3]=7; y1[3]=11; y2[3]=11;
            x1[4]=5; x2[4]=5; y1[4]=14; y2[4]=9;
            x1[5]=5; x2[5]=5; y1[5]=10; y2[5]=7;
            x1[6]=7; x2[6]=5; y1[6]=4; y2[6]=4;
            x1[7]=8; x2[7]=1; y1[7]=12; y2[7]=12;
            x1[8]=11; x2[8]=4; y1[8]=10; y2[8]=10;
            x1[9]=5; x2[9]=3; y1[9]=9; y2[9]=9;
            x1[10]=11; x2[10]=4; y1[10]=4; y2[10]=4;
            x1[11]=11; x2[11]=11; y1[11]=10; y2[11]=9;
            x1[12]=14; x2[12]=6; y1[12]=0; y2[12]=0;
        break;
        case 86:
            x1[0]=9; x2[0]=9; y1[0]=5; y2[0]=1;
            x1[1]=6; x2[1]=0; y1[1]=3; y2[1]=3;
            x1[2]=2; x2[2]=2; y1[2]=2; y2[2]=1;
            x1[3]=0; x2[3]=0; y1[3]=9; y2[3]=0;
            x1[4]=10; x2[4]=6; y1[4]=2; y2[4]=2;
            x1[5]=8; x2[5]=2; y1[5]=8; y2[5]=8;
            x1[6]=8; x2[6]=8; y1[6]=13; y2[6]=3;
            x1[7]=11; x2[7]=1; y1[7]=7; y2[7]=7;
            x1[8]=12; x2[8]=4; y1[8]=1; y2[8]=1;
            x1[9]=14; x2[9]=14; y1[9]=11; y2[9]=10;
            x1[10]=6; x2[10]=6; y1[10]=13; y2[10]=7;
            x1[11]=14; x2[11]=14; y1[11]=6; y2[11]=5;
            x1[12]=11; x2[12]=5; y1[12]=5; y2[12]=5;
        break;
        case 87:
            x1[0]=2; x2[0]=1; y1[0]=8; y2[0]=8;
            x1[1]=14; x2[1]=14; y1[1]=13; y2[1]=9;
            x1[2]=4; x2[2]=4; y1[2]=13; y2[2]=9;
            x1[3]=11; x2[3]=11; y1[3]=8; y2[3]=0;
            x1[4]=11; x2[4]=7; y1[4]=13; y2[4]=13;
            x1[5]=11; x2[5]=8; y1[5]=3; y2[5]=3;
            x1[6]=8; x2[6]=2; y1[6]=13; y2[6]=13;
            x1[7]=12; x2[7]=0; y1[7]=13; y2[7]=13;
            x1[8]=9; x2[8]=3; y1[8]=14; y2[8]=14;
            x1[9]=13; x2[9]=7; y1[9]=11; y2[9]=11;
            x1[10]=0; x2[10]=0; y1[10]=12; y2[10]=5;
            x1[11]=12; x2[11]=3; y1[11]=5; y2[11]=5;
            x1[12]=4; x2[12]=2; y1[12]=9; y2[12]=9;
        break;
        case 88:
            x1[0]=14; x2[0]=2; y1[0]=11; y2[0]=11;
            x1[1]=12; x2[1]=10; y1[1]=12; y2[1]=12;
            x1[2]=14; x2[2]=7; y1[2]=3; y2[2]=3;
            x1[3]=14; x2[3]=14; y1[3]=13; y2[3]=4;
            x1[4]=0; x2[4]=0; y1[4]=6; y2[4]=4;
            x1[5]=10; x2[5]=2; y1[5]=4; y2[5]=4;
            x1[6]=0; x2[6]=0; y1[6]=10; y2[6]=9;
            x1[7]=9; x2[7]=4; y1[7]=3; y2[7]=3;
            x1[8]=11; x2[8]=2; y1[8]=13; y2[8]=13;
            x1[9]=13; x2[9]=1; y1[9]=2; y2[9]=2;
            x1[10]=10; x2[10]=6; y1[10]=5; y2[10]=5;
            x1[11]=14; x2[11]=10; y1[11]=4; y2[11]=4;
            x1[12]=1; x2[12]=1; y1[12]=12; y2[12]=6;
        break;
        case 89:
            x1[0]=4; x2[0]=2; y1[0]=8; y2[0]=8;
            x1[1]=6; x2[1]=4; y1[1]=8; y2[1]=8;
            x1[2]=12; x2[2]=12; y1[2]=6; y2[2]=2;
            x1[3]=4; x2[3]=4; y1[3]=9; y2[3]=3;
            x1[4]=12; x2[4]=0; y1[4]=0; y2[4]=0;
            x1[5]=9; x2[5]=3; y1[5]=6; y2[5]=6;
            x1[6]=11; x2[6]=0; y1[6]=3; y2[6]=3;
            x1[7]=2; x2[7]=2; y1[7]=13; y2[7]=7;
            x1[8]=12; x2[8]=5; y1[8]=13; y2[8]=13;
            x1[9]=13; x2[9]=13; y1[9]=12; y2[9]=3;
            x1[10]=2; x2[10]=2; y1[10]=12; y2[10]=11;
            x1[11]=4; x2[11]=4; y1[11]=12; y2[11]=5;
            x1[12]=6; x2[12]=6; y1[12]=2; y2[12]=0;
        break;
        case 90:
            x1[0]=8; x2[0]=5; y1[0]=9; y2[0]=9;
            x1[1]=13; x2[1]=10; y1[1]=10; y2[1]=10;
            x1[2]=4; x2[2]=4; y1[2]=7; y2[2]=2;
            x1[3]=12; x2[3]=7; y1[3]=14; y2[3]=14;
            x1[4]=3; x2[4]=3; y1[4]=12; y2[4]=7;
            x1[5]=10; x2[5]=2; y1[5]=12; y2[5]=12;
            x1[6]=13; x2[6]=5; y1[6]=2; y2[6]=2;
            x1[7]=14; x2[7]=10; y1[7]=7; y2[7]=7;
            x1[8]=10; x2[8]=8; y1[8]=14; y2[8]=14;
            x1[9]=10; x2[9]=7; y1[9]=12; y2[9]=12;
            x1[10]=12; x2[10]=6; y1[10]=4; y2[10]=4;
            x1[11]=12; x2[11]=5; y1[11]=12; y2[11]=12;
            x1[12]=11; x2[12]=11; y1[12]=14; y2[12]=13;
        break;
        case 91:
            x1[0]=9; x2[0]=2; y1[0]=2; y2[0]=2;
            x1[1]=3; x2[1]=3; y1[1]=9; y2[1]=7;
            x1[2]=12; x2[2]=11; y1[2]=0; y2[2]=0;
            x1[3]=14; x2[3]=4; y1[3]=5; y2[3]=5;
            x1[4]=2; x2[4]=2; y1[4]=11; y2[4]=0;
            x1[5]=0; x2[5]=0; y1[5]=13; y2[5]=10;
            x1[6]=14; x2[6]=10; y1[6]=2; y2[6]=2;
            x1[7]=10; x2[7]=10; y1[7]=8; y2[7]=2;
            x1[8]=3; x2[8]=3; y1[8]=5; y2[8]=4;
            x1[9]=5; x2[9]=2; y1[9]=4; y2[9]=4;
            x1[10]=14; x2[10]=14; y1[10]=10; y2[10]=7;
            x1[11]=13; x2[11]=10; y1[11]=9; y2[11]=9;
            x1[12]=14; x2[12]=1; y1[12]=11; y2[12]=11;
        break;
        case 92:
            x1[0]=10; x2[0]=1; y1[0]=11; y2[0]=11;
            x1[1]=9; x2[1]=6; y1[1]=4; y2[1]=4;
            x1[2]=9; x2[2]=9; y1[2]=7; y2[2]=4;
            x1[3]=13; x2[3]=12; y1[3]=11; y2[3]=11;
            x1[4]=9; x2[4]=9; y1[4]=11; y2[4]=4;
            x1[5]=14; x2[5]=4; y1[5]=1; y2[5]=1;
            x1[6]=9; x2[6]=3; y1[6]=10; y2[6]=10;
            x1[7]=5; x2[7]=0; y1[7]=6; y2[7]=6;
            x1[8]=2; x2[8]=2; y1[8]=12; y2[8]=8;
            x1[9]=10; x2[9]=10; y1[9]=6; y2[9]=5;
            x1[10]=10; x2[10]=1; y1[10]=4; y2[10]=4;
            x1[11]=12; x2[11]=0; y1[11]=10; y2[11]=10;
            x1[12]=4; x2[12]=4; y1[12]=9; y2[12]=7;
        break;
        case 93:
            x1[0]=10; x2[0]=10; y1[0]=10; y2[0]=8;
            x1[1]=12; x2[1]=8; y1[1]=10; y2[1]=10;
            x1[2]=8; x2[2]=1; y1[2]=10; y2[2]=10;
            x1[3]=14; x2[3]=8; y1[3]=6; y2[3]=6;
            x1[4]=2; x2[4]=2; y1[4]=8; y2[4]=4;
            x1[5]=9; x2[5]=9; y1[5]=10; y2[5]=8;
            x1[6]=13; x2[6]=3; y1[6]=4; y2[6]=4;
            x1[7]=9; x2[7]=8; y1[7]=5; y2[7]=5;
            x1[8]=0; x2[8]=0; y1[8]=11; y2[8]=0;
            x1[9]=9; x2[9]=4; y1[9]=13; y2[9]=13;
            x1[10]=1; x2[10]=1; y1[10]=9; y2[10]=5;
            x1[11]=9; x2[11]=6; y1[11]=3; y2[11]=3;
            x1[12]=0; x2[12]=0; y1[12]=14; y2[12]=0;
        break;
        case 94:
            x1[0]=5; x2[0]=5; y1[0]=5; y2[0]=0;
            x1[1]=9; x2[1]=9; y1[1]=10; y2[1]=9;
            x1[2]=4; x2[2]=4; y1[2]=12; y2[2]=11;
            x1[3]=10; x2[3]=4; y1[3]=1; y2[3]=1;
            x1[4]=13; x2[4]=4; y1[4]=3; y2[4]=3;
            x1[5]=9; x2[5]=9; y1[5]=8; y2[5]=6;
            x1[6]=13; x2[6]=13; y1[6]=13; y2[6]=0;
            x1[7]=0; x2[7]=0; y1[7]=7; y2[7]=4;
            x1[8]=4; x2[8]=1; y1[8]=6; y2[8]=6;
            x1[9]=8; x2[9]=3; y1[9]=5; y2[9]=5;
            x1[10]=11; x2[10]=6; y1[10]=11; y2[10]=11;
            x1[11]=10; x2[11]=10; y1[11]=12; y2[11]=8;
            x1[12]=10; x2[12]=4; y1[12]=9; y2[12]=9;
        break;
        case 95:
            x1[0]=12; x2[0]=12; y1[0]=7; y2[0]=2;
            x1[1]=12; x2[1]=8; y1[1]=5; y2[1]=5;
            x1[2]=9; x2[2]=8; y1[2]=10; y2[2]=10;
            x1[3]=3; x2[3]=3; y1[3]=7; y2[3]=5;
            x1[4]=5; x2[4]=5; y1[4]=12; y2[4]=3;
            x1[5]=14; x2[5]=11; y1[5]=5; y2[5]=5;
            x1[6]=0; x2[6]=0; y1[6]=6; y2[6]=2;
            x1[7]=5; x2[7]=5; y1[7]=6; y2[7]=5;
            x1[8]=11; x2[8]=11; y1[8]=14; y2[8]=6;
            x1[9]=10; x2[9]=7; y1[9]=6; y2[9]=6;
            x1[10]=14; x2[10]=14; y1[10]=14; y2[10]=3;
            x1[11]=4; x2[11]=3; y1[11]=8; y2[11]=8;
            x1[12]=1; x2[12]=1; y1[12]=5; y2[12]=1;
        break;
        case 96:
            x1[0]=9; x2[0]=9; y1[0]=8; y2[0]=5;
            x1[1]=2; x2[1]=2; y1[1]=14; y2[1]=3;
            x1[2]=14; x2[2]=5; y1[2]=11; y2[2]=11;
            x1[3]=11; x2[3]=7; y1[3]=7; y2[3]=7;
            x1[4]=14; x2[4]=12; y1[4]=7; y2[4]=7;
            x1[5]=5; x2[5]=5; y1[5]=13; y2[5]=5;
            x1[6]=8; x2[6]=1; y1[6]=4; y2[6]=4;
            x1[7]=3; x2[7]=0; y1[7]=14; y2[7]=14;
            x1[8]=8; x2[8]=8; y1[8]=14; y2[8]=7;
            x1[9]=9; x2[9]=1; y1[9]=3; y2[9]=3;
            x1[10]=4; x2[10]=4; y1[10]=8; y2[10]=4;
            x1[11]=5; x2[11]=5; y1[11]=6; y2[11]=0;
            x1[12]=11; x2[12]=11; y1[12]=3; y2[12]=0;
        break;
        case 97:
            x1[0]=12; x2[0]=6; y1[0]=6; y2[0]=6;
            x1[1]=10; x2[1]=6; y1[1]=13; y2[1]=13;
            x1[2]=11; x2[2]=8; y1[2]=5; y2[2]=5;
            x1[3]=0; x2[3]=0; y1[3]=9; y2[3]=1;
            x1[4]=13; x2[4]=1; y1[4]=6; y2[4]=6;
            x1[5]=8; x2[5]=0; y1[5]=12; y2[5]=12;
            x1[6]=1; x2[6]=1; y1[6]=6; y2[6]=3;
            x1[7]=1; x2[7]=1; y1[7]=3; y2[7]=0;
            x1[8]=7; x2[8]=4; y1[8]=12; y2[8]=12;
            x1[9]=11; x2[9]=6; y1[9]=1; y2[9]=1;
            x1[10]=10; x2[10]=7; y1[10]=1; y2[10]=1;
            x1[11]=8; x2[11]=5; y1[11]=6; y2[11]=6;
            x1[12]=5; x2[12]=3; y1[12]=6; y2[12]=6;
        break;
        case 98:
            x1[0]=1; x2[0]=1; y1[0]=7; y2[0]=1;
            x1[1]=9; x2[1]=9; y1[1]=14; y2[1]=5;
            x1[2]=9; x2[2]=9; y1[2]=11; y2[2]=6;
            x1[3]=11; x2[3]=11; y1[3]=4; y2[3]=0;
            x1[4]=0; x2[4]=0; y1[4]=11; y2[4]=8;
            x1[5]=12; x2[5]=8; y1[5]=3; y2[5]=3;
            x1[6]=11; x2[6]=7; y1[6]=11; y2[6]=11;
            x1[7]=7; x2[7]=0; y1[7]=8; y2[7]=8;
            x1[8]=12; x2[8]=12; y1[8]=3; y2[8]=2;
            x1[9]=10; x2[9]=4; y1[9]=14; y2[9]=14;
            x1[10]=6; x2[10]=6; y1[10]=8; y2[10]=0;
            x1[11]=6; x2[11]=6; y1[11]=14; y2[11]=12;
            x1[12]=11; x2[12]=9; y1[12]=9; y2[12]=9;
        break;
        case 99:
            x1[0]=8; x2[0]=5; y1[0]=14; y2[0]=14;
            x1[1]=13; x2[1]=6; y1[1]=1; y2[1]=1;
            x1[2]=8; x2[2]=0; y1[2]=13; y2[2]=13;
            x1[3]=5; x2[3]=5; y1[3]=2; y2[3]=0;
            x1[4]=9; x2[4]=1; y1[4]=14; y2[4]=14;
            x1[5]=12; x2[5]=12; y1[5]=11; y2[5]=10;
            x1[6]=7; x2[6]=3; y1[6]=0; y2[6]=0;
            x1[7]=8; x2[7]=8; y1[7]=5; y2[7]=4;
            x1[8]=10; x2[8]=5; y1[8]=9; y2[8]=9;
            x1[9]=14; x2[9]=6; y1[9]=14; y2[9]=14;
            x1[10]=9; x2[10]=9; y1[10]=11; y2[10]=8;
            x1[11]=8; x2[11]=5; y1[11]=13; y2[11]=13;
            x1[12]=12; x2[12]=5; y1[12]=1; y2[12]=1;
        break;
        case 100:
            x1[0]=5; x2[0]=5; y1[0]=14; y2[0]=12;
            x1[1]=8; x2[1]=8; y1[1]=14; y2[1]=12;
            x1[2]=8; x2[2]=8; y1[2]=13; y2[2]=8;
            x1[3]=11; x2[3]=2; y1[3]=7; y2[3]=7;
            x1[4]=5; x2[4]=2; y1[4]=6; y2[4]=6;
            x1[5]=14; x2[5]=14; y1[5]=5; y2[5]=4;
            x1[6]=7; x2[6]=7; y1[6]=10; y2[6]=2;
            x1[7]=5; x2[7]=2; y1[7]=7; y2[7]=7;
            x1[8]=14; x2[8]=11; y1[8]=13; y2[8]=13;
            x1[9]=1; x2[9]=1; y1[9]=13; y2[9]=9;
            x1[10]=10; x2[10]=10; y1[10]=13; y2[10]=5;
            x1[11]=7; x2[11]=1; y1[11]=13; y2[11]=13;
            x1[12]=6; x2[12]=3; y1[12]=13; y2[12]=13;
        break;
        case 101:
            x1[0]=4; x2[0]=1; y1[0]=0; y2[0]=0;
            x1[1]=6; x2[1]=0; y1[1]=14; y2[1]=14;
            x1[2]=13; x2[2]=4; y1[2]=8; y2[2]=8;
            x1[3]=5; x2[3]=4; y1[3]=11; y2[3]=11;
            x1[4]=2; x2[4]=1; y1[4]=14; y2[4]=14;
            x1[5]=4; x2[5]=1; y1[5]=11; y2[5]=11;
            x1[6]=12; x2[6]=12; y1[6]=7; y2[6]=0;
            x1[7]=7; x2[7]=7; y1[7]=10; y2[7]=3;
            x1[8]=4; x2[8]=4; y1[8]=4; y2[8]=3;
            x1[9]=2; x2[9]=2; y1[9]=14; y2[9]=13;
            x1[10]=0; x2[10]=0; y1[10]=9; y2[10]=7;
            x1[11]=12; x2[11]=3; y1[11]=6; y2[11]=6;
            x1[12]=2; x2[12]=2; y1[12]=11; y2[12]=2;
        break;
        case 102:
            x1[0]=13; x2[0]=9; y1[0]=1; y2[0]=1;
            x1[1]=6; x2[1]=6; y1[1]=13; y2[1]=2;
            x1[2]=11; x2[2]=11; y1[2]=13; y2[2]=11;
            x1[3]=11; x2[3]=11; y1[3]=12; y2[3]=11;
            x1[4]=6; x2[4]=6; y1[4]=12; y2[4]=6;
            x1[5]=12; x2[5]=6; y1[5]=3; y2[5]=3;
            x1[6]=12; x2[6]=12; y1[6]=7; y2[6]=5;
            x1[7]=7; x2[7]=7; y1[7]=9; y2[7]=5;
            x1[8]=7; x2[8]=1; y1[8]=6; y2[8]=6;
            x1[9]=9; x2[9]=9; y1[9]=14; y2[9]=3;
            x1[10]=3; x2[10]=3; y1[10]=11; y2[10]=7;
            x1[11]=5; x2[11]=2; y1[11]=9; y2[11]=9;
            x1[12]=14; x2[12]=6; y1[12]=11; y2[12]=11;
        break;
        case 103:
            x1[0]=11; x2[0]=4; y1[0]=12; y2[0]=12;
            x1[1]=7; x2[1]=5; y1[1]=11; y2[1]=11;
            x1[2]=1; x2[2]=1; y1[2]=9; y2[2]=3;
            x1[3]=10; x2[3]=9; y1[3]=4; y2[3]=4;
            x1[4]=6; x2[4]=2; y1[4]=9; y2[4]=9;
            x1[5]=3; x2[5]=3; y1[5]=14; y2[5]=8;
            x1[6]=10; x2[6]=10; y1[6]=12; y2[6]=2;
            x1[7]=10; x2[7]=8; y1[7]=4; y2[7]=4;
            x1[8]=4; x2[8]=4; y1[8]=4; y2[8]=2;
            x1[9]=8; x2[9]=8; y1[9]=9; y2[9]=5;
            x1[10]=5; x2[10]=0; y1[10]=14; y2[10]=14;
            x1[11]=11; x2[11]=7; y1[11]=1; y2[11]=1;
            x1[12]=6; x2[12]=6; y1[12]=14; y2[12]=0;
        break;
        case 104:
            x1[0]=8; x2[0]=4; y1[0]=1; y2[0]=1;
            x1[1]=5; x2[1]=2; y1[1]=3; y2[1]=3;
            x1[2]=7; x2[2]=7; y1[2]=10; y2[2]=4;
            x1[3]=4; x2[3]=4; y1[3]=1; y2[3]=0;
            x1[4]=6; x2[4]=5; y1[4]=13; y2[4]=13;
            x1[5]=12; x2[5]=5; y1[5]=3; y2[5]=3;
            x1[6]=13; x2[6]=13; y1[6]=10; y2[6]=4;
            x1[7]=14; x2[7]=14; y1[7]=8; y2[7]=2;
            x1[8]=1; x2[8]=1; y1[8]=9; y2[8]=8;
            x1[9]=2; x2[9]=2; y1[9]=11; y2[9]=7;
            x1[10]=1; x2[10]=1; y1[10]=2; y2[10]=1;
            x1[11]=2; x2[11]=2; y1[11]=14; y2[11]=10;
            x1[12]=3; x2[12]=3; y1[12]=8; y2[12]=4;
        break;
        case 105:
            x1[0]=13; x2[0]=10; y1[0]=0; y2[0]=0;
            x1[1]=7; x2[1]=5; y1[1]=2; y2[1]=2;
            x1[2]=14; x2[2]=8; y1[2]=8; y2[2]=8;
            x1[3]=10; x2[3]=10; y1[3]=3; y2[3]=1;
            x1[4]=7; x2[4]=7; y1[4]=6; y2[4]=3;
            x1[5]=10; x2[5]=7; y1[5]=8; y2[5]=8;
            x1[6]=8; x2[6]=8; y1[6]=5; y2[6]=0;
            x1[7]=8; x2[7]=5; y1[7]=10; y2[7]=10;
            x1[8]=10; x2[8]=4; y1[8]=6; y2[8]=6;
            x1[9]=12; x2[9]=7; y1[9]=9; y2[9]=9;
            x1[10]=11; x2[10]=0; y1[10]=13; y2[10]=13;
            x1[11]=2; x2[11]=2; y1[11]=13; y2[11]=0;
            x1[12]=4; x2[12]=3; y1[12]=12; y2[12]=12;
        break;
        case 106:
            x1[0]=4; x2[0]=1; y1[0]=5; y2[0]=5;
            x1[1]=12; x2[1]=1; y1[1]=9; y2[1]=9;
            x1[2]=12; x2[2]=12; y1[2]=6; y2[2]=5;
            x1[3]=8; x2[3]=8; y1[3]=9; y2[3]=6;
            x1[4]=8; x2[4]=1; y1[4]=5; y2[4]=5;
            x1[5]=13; x2[5]=13; y1[5]=8; y2[5]=0;
            x1[6]=4; x2[6]=4; y1[6]=12; y2[6]=10;
            x1[7]=3; x2[7]=3; y1[7]=12; y2[7]=2;
            x1[8]=8; x2[8]=8; y1[8]=13; y2[8]=0;
            x1[9]=11; x2[9]=10; y1[9]=6; y2[9]=6;
            x1[10]=13; x2[10]=12; y1[10]=8; y2[10]=8;
            x1[11]=3; x2[11]=3; y1[11]=12; y2[11]=0;
            x1[12]=6; x2[12]=6; y1[12]=5; y2[12]=1;
        break;
        case 107:
            x1[0]=8; x2[0]=8; y1[0]=7; y2[0]=3;
            x1[1]=9; x2[1]=0; y1[1]=0; y2[1]=0;
            x1[2]=8; x2[2]=6; y1[2]=7; y2[2]=7;
            x1[3]=9; x2[3]=0; y1[3]=3; y2[3]=3;
            x1[4]=7; x2[4]=7; y1[4]=6; y2[4]=4;
            x1[5]=11; x2[5]=5; y1[5]=8; y2[5]=8;
            x1[6]=10; x2[6]=4; y1[6]=3; y2[6]=3;
            x1[7]=2; x2[7]=2; y1[7]=10; y2[7]=1;
            x1[8]=10; x2[8]=4; y1[8]=7; y2[8]=7;
            x1[9]=6; x2[9]=2; y1[9]=10; y2[9]=10;
            x1[10]=10; x2[10]=10; y1[10]=14; y2[10]=0;
            x1[11]=3; x2[11]=3; y1[11]=13; y2[11]=2;
            x1[12]=9; x2[12]=7; y1[12]=8; y2[12]=8;
        break;
        case 108:
            x1[0]=13; x2[0]=13; y1[0]=5; y2[0]=1;
            x1[1]=13; x2[1]=7; y1[1]=6; y2[1]=6;
            x1[2]=14; x2[2]=12; y1[2]=9; y2[2]=9;
            x1[3]=3; x2[3]=3; y1[3]=13; y2[3]=11;
            x1[4]=14; x2[4]=14; y1[4]=10; y2[4]=9;
            x1[5]=9; x2[5]=5; y1[5]=4; y2[5]=4;
            x1[6]=12; x2[6]=1; y1[6]=12; y2[6]=12;
            x1[7]=14; x2[7]=14; y1[7]=10; y2[7]=6;
            x1[8]=7; x2[8]=7; y1[8]=13; y2[8]=6;
            x1[9]=0; x2[9]=0; y1[9]=13; y2[9]=5;
            x1[10]=10; x2[10]=10; y1[10]=9; y2[10]=1;
            x1[11]=12; x2[11]=1; y1[11]=3; y2[11]=3;
            x1[12]=5; x2[12]=5; y1[12]=9; y2[12]=0;
        break;
        case 109:
            x1[0]=1; x2[0]=1; y1[0]=2; y2[0]=0;
            x1[1]=6; x2[1]=1; y1[1]=10; y2[1]=10;
            x1[2]=9; x2[2]=9; y1[2]=9; y2[2]=1;
            x1[3]=0; x2[3]=0; y1[3]=13; y2[3]=12;
            x1[4]=0; x2[4]=0; y1[4]=12; y2[4]=8;
            x1[5]=12; x2[5]=9; y1[5]=7; y2[5]=7;
            x1[6]=13; x2[6]=0; y1[6]=14; y2[6]=14;
            x1[7]=4; x2[7]=4; y1[7]=5; y2[7]=2;
            x1[8]=9; x2[8]=9; y1[8]=9; y2[8]=3;
            x1[9]=11; x2[9]=7; y1[9]=5; y2[9]=5;
            x1[10]=10; x2[10]=0; y1[10]=11; y2[10]=11;
            x1[11]=12; x2[11]=12; y1[11]=4; y2[11]=2;
            x1[12]=13; x2[12]=13; y1[12]=3; y2[12]=2;
        break;
        case 110:
            x1[0]=8; x2[0]=8; y1[0]=13; y2[0]=6;
            x1[1]=2; x2[1]=2; y1[1]=3; y2[1]=1;
            x1[2]=13; x2[2]=10; y1[2]=8; y2[2]=8;
            x1[3]=9; x2[3]=2; y1[3]=1; y2[3]=1;
            x1[4]=7; x2[4]=6; y1[4]=12; y2[4]=12;
            x1[5]=6; x2[5]=1; y1[5]=5; y2[5]=5;
            x1[6]=0; x2[6]=0; y1[6]=10; y2[6]=2;
            x1[7]=12; x2[7]=0; y1[7]=7; y2[7]=7;
            x1[8]=11; x2[8]=0; y1[8]=11; y2[8]=11;
            x1[9]=13; x2[9]=1; y1[9]=11; y2[9]=11;
            x1[10]=13; x2[10]=13; y1[10]=7; y2[10]=0;
            x1[11]=0; x2[11]=0; y1[11]=14; y2[11]=8;
            x1[12]=4; x2[12]=4; y1[12]=4; y2[12]=0;
        break;
        case 111:
            x1[0]=4; x2[0]=2; y1[0]=13; y2[0]=13;
            x1[1]=6; x2[1]=0; y1[1]=11; y2[1]=11;
            x1[2]=14; x2[2]=7; y1[2]=11; y2[2]=11;
            x1[3]=3; x2[3]=3; y1[3]=11; y2[3]=2;
            x1[4]=3; x2[4]=0; y1[4]=3; y2[4]=3;
            x1[5]=13; x2[5]=1; y1[5]=13; y2[5]=13;
            x1[6]=5; x2[6]=0; y1[6]=9; y2[6]=9;
            x1[7]=9; x2[7]=2; y1[7]=10; y2[7]=10;
            x1[8]=13; x2[8]=13; y1[8]=11; y2[8]=5;
            x1[9]=7; x2[9]=2; y1[9]=6; y2[9]=6;
            x1[10]=0; x2[10]=0; y1[10]=13; y2[10]=3;
            x1[11]=10; x2[11]=7; y1[11]=0; y2[11]=0;
            x1[12]=1; x2[12]=1; y1[12]=14; y2[12]=1;
        break;
        case 112:
            x1[0]=7; x2[0]=7; y1[0]=12; y2[0]=7;
            x1[1]=7; x2[1]=7; y1[1]=14; y2[1]=2;
            x1[2]=4; x2[2]=4; y1[2]=14; y2[2]=5;
            x1[3]=5; x2[3]=5; y1[3]=9; y2[3]=2;
            x1[4]=2; x2[4]=2; y1[4]=11; y2[4]=9;
            x1[5]=4; x2[5]=4; y1[5]=14; y2[5]=2;
            x1[6]=9; x2[6]=8; y1[6]=12; y2[6]=12;
            x1[7]=12; x2[7]=5; y1[7]=6; y2[7]=6;
            x1[8]=13; x2[8]=9; y1[8]=14; y2[8]=14;
            x1[9]=2; x2[9]=1; y1[9]=6; y2[9]=6;
            x1[10]=4; x2[10]=4; y1[10]=14; y2[10]=11;
            x1[11]=14; x2[11]=14; y1[11]=6; y2[11]=0;
            x1[12]=13; x2[12]=13; y1[12]=11; y2[12]=6;
        break;
        case 113:
            x1[0]=10; x2[0]=0; y1[0]=7; y2[0]=7;
            x1[1]=7; x2[1]=5; y1[1]=7; y2[1]=7;
            x1[2]=13; x2[2]=5; y1[2]=4; y2[2]=4;
            x1[3]=5; x2[3]=5; y1[3]=14; y2[3]=11;
            x1[4]=8; x2[4]=0; y1[4]=0; y2[4]=0;
            x1[5]=11; x2[5]=11; y1[5]=7; y2[5]=1;
            x1[6]=4; x2[6]=4; y1[6]=5; y2[6]=3;
            x1[7]=3; x2[7]=3; y1[7]=12; y2[7]=9;
            x1[8]=4; x2[8]=1; y1[8]=9; y2[8]=9;
            x1[9]=14; x2[9]=0; y1[9]=7; y2[9]=7;
            x1[10]=12; x2[10]=9; y1[10]=2; y2[10]=2;
            x1[11]=13; x2[11]=10; y1[11]=2; y2[11]=2;
            x1[12]=1; x2[12]=0; y1[12]=5; y2[12]=5;
        break;
        case 114:
            x1[0]=3; x2[0]=3; y1[0]=2; y2[0]=0;
            x1[1]=4; x2[1]=4; y1[1]=11; y2[1]=4;
            x1[2]=7; x2[2]=3; y1[2]=11; y2[2]=11;
            x1[3]=4; x2[3]=4; y1[3]=13; y2[3]=12;
            x1[4]=10; x2[4]=10; y1[4]=14; y2[4]=8;
            x1[5]=3; x2[5]=2; y1[5]=6; y2[5]=6;
            x1[6]=5; x2[6]=5; y1[6]=12; y2[6]=8;
            x1[7]=8; x2[7]=3; y1[7]=3; y2[7]=3;
            x1[8]=13; x2[8]=5; y1[8]=1; y2[8]=1;
            x1[9]=14; x2[9]=3; y1[9]=13; y2[9]=13;
            x1[10]=11; x2[10]=11; y1[10]=5; y2[10]=0;
            x1[11]=8; x2[11]=8; y1[11]=11; y2[11]=7;
            x1[12]=7; x2[12]=7; y1[12]=7; y2[12]=6;
        break;
        case 115:
            x1[0]=11; x2[0]=11; y1[0]=11; y2[0]=4;
            x1[1]=7; x2[1]=7; y1[1]=14; y2[1]=0;
            x1[2]=14; x2[2]=10; y1[2]=12; y2[2]=12;
            x1[3]=13; x2[3]=13; y1[3]=10; y2[3]=3;
            x1[4]=6; x2[4]=6; y1[4]=13; y2[4]=1;
            x1[5]=13; x2[5]=13; y1[5]=13; y2[5]=11;
            x1[6]=12; x2[6]=11; y1[6]=12; y2[6]=12;
            x1[7]=10; x2[7]=10; y1[7]=8; y2[7]=3;
            x1[8]=3; x2[8]=1; y1[8]=13; y2[8]=13;
            x1[9]=8; x2[9]=3; y1[9]=9; y2[9]=9;
            x1[10]=13; x2[10]=12; y1[10]=10; y2[10]=10;
            x1[11]=14; x2[11]=14; y1[11]=12; y2[11]=9;
            x1[12]=10; x2[12]=8; y1[12]=13; y2[12]=13;
        break;
        case 116:
            x1[0]=8; x2[0]=8; y1[0]=14; y2[0]=0;
            x1[1]=7; x2[1]=7; y1[1]=4; y2[1]=0;
            x1[2]=12; x2[2]=8; y1[2]=1; y2[2]=1;
            x1[3]=12; x2[3]=10; y1[3]=1; y2[3]=1;
            x1[4]=13; x2[4]=4; y1[4]=14; y2[4]=14;
            x1[5]=6; x2[5]=4; y1[5]=11; y2[5]=11;
            x1[6]=13; x2[6]=10; y1[6]=3; y2[6]=3;
            x1[7]=5; x2[7]=5; y1[7]=3; y2[7]=2;
            x1[8]=14; x2[8]=6; y1[8]=7; y2[8]=7;
            x1[9]=7; x2[9]=7; y1[9]=8; y2[9]=1;
            x1[10]=8; x2[10]=1; y1[10]=9; y2[10]=9;
            x1[11]=13; x2[11]=13; y1[11]=8; y2[11]=4;
            x1[12]=9; x2[12]=6; y1[12]=8; y2[12]=8;
        break;
        case 117:
            x1[0]=11; x2[0]=11; y1[0]=10; y2[0]=6;
            x1[1]=12; x2[1]=12; y1[1]=12; y2[1]=8;
            x1[2]=4; x2[2]=4; y1[2]=10; y2[2]=4;
            x1[3]=7; x2[3]=0; y1[3]=6; y2[3]=6;
            x1[4]=7; x2[4]=1; y1[4]=2; y2[4]=2;
            x1[5]=3; x2[5]=3; y1[5]=9; y2[5]=5;
            x1[6]=12; x2[6]=12; y1[6]=8; y2[6]=5;
            x1[7]=13; x2[7]=13; y1[7]=9; y2[7]=3;
            x1[8]=5; x2[8]=5; y1[8]=13; y2[8]=0;
            x1[9]=11; x2[9]=7; y1[9]=4; y2[9]=4;
            x1[10]=7; x2[10]=3; y1[10]=12; y2[10]=12;
            x1[11]=14; x2[11]=14; y1[11]=11; y2[11]=9;
            x1[12]=2; x2[12]=2; y1[12]=13; y2[12]=12;
        break;
        case 118:
            x1[0]=3; x2[0]=3; y1[0]=12; y2[0]=11;
            x1[1]=5; x2[1]=3; y1[1]=12; y2[1]=12;
            x1[2]=13; x2[2]=0; y1[2]=8; y2[2]=8;
            x1[3]=12; x2[3]=12; y1[3]=10; y2[3]=2;
            x1[4]=9; x2[4]=0; y1[4]=13; y2[4]=13;
            x1[5]=1; x2[5]=1; y1[5]=7; y2[5]=3;
            x1[6]=13; x2[6]=13; y1[6]=11; y2[6]=0;
            x1[7]=4; x2[7]=4; y1[7]=8; y2[7]=7;
            x1[8]=12; x2[8]=12; y1[8]=9; y2[8]=3;
            x1[9]=11; x2[9]=5; y1[9]=2; y2[9]=2;
            x1[10]=6; x2[10]=6; y1[10]=13; y2[10]=3;
            x1[11]=9; x2[11]=9; y1[11]=12; y2[11]=3;
            x1[12]=13; x2[12]=0; y1[12]=13; y2[12]=13;
        break;
        case 119:
            x1[0]=13; x2[0]=10; y1[0]=5; y2[0]=5;
            x1[1]=11; x2[1]=10; y1[1]=11; y2[1]=11;
            x1[2]=12; x2[2]=12; y1[2]=14; y2[2]=12;
            x1[3]=8; x2[3]=2; y1[3]=11; y2[3]=11;
            x1[4]=12; x2[4]=10; y1[4]=8; y2[4]=8;
            x1[5]=13; x2[5]=2; y1[5]=4; y2[5]=4;
            x1[6]=5; x2[6]=5; y1[6]=8; y2[6]=2;
            x1[7]=5; x2[7]=0; y1[7]=2; y2[7]=2;
            x1[8]=7; x2[8]=7; y1[8]=13; y2[8]=11;
            x1[9]=3; x2[9]=3; y1[9]=10; y2[9]=8;
            x1[10]=4; x2[10]=4; y1[10]=5; y2[10]=4;
            x1[11]=5; x2[11]=5; y1[11]=14; y2[11]=1;
            x1[12]=12; x2[12]=2; y1[12]=2; y2[12]=2;
        break;
        case 120:
            x1[0]=8; x2[0]=1; y1[0]=1; y2[0]=1;
            x1[1]=7; x2[1]=2; y1[1]=11; y2[1]=11;
            x1[2]=8; x2[2]=4; y1[2]=8; y2[2]=8;
            x1[3]=6; x2[3]=6; y1[3]=11; y2[3]=4;
            x1[4]=4; x2[4]=4; y1[4]=13; y2[4]=11;
            x1[5]=1; x2[5]=1; y1[5]=11; y2[5]=1;
            x1[6]=8; x2[6]=0; y1[6]=4; y2[6]=4;
            x1[7]=14; x2[7]=0; y1[7]=12; y2[7]=12;
            x1[8]=13; x2[8]=13; y1[8]=10; y2[8]=5;
            x1[9]=6; x2[9]=5; y1[9]=14; y2[9]=14;
            x1[10]=12; x2[10]=3; y1[10]=2; y2[10]=2;
            x1[11]=5; x2[11]=1; y1[11]=13; y2[11]=13;
            x1[12]=0; x2[12]=0; y1[12]=13; y2[12]=11;
        break;
        case 121:
            x1[0]=3; x2[0]=2; y1[0]=7; y2[0]=7;
            x1[1]=13; x2[1]=6; y1[1]=4; y2[1]=4;
            x1[2]=4; x2[2]=4; y1[2]=7; y2[2]=5;
            x1[3]=7; x2[3]=7; y1[3]=10; y2[3]=7;
            x1[4]=8; x2[4]=4; y1[4]=9; y2[4]=9;
            x1[5]=14; x2[5]=10; y1[5]=1; y2[5]=1;
            x1[6]=9; x2[6]=5; y1[6]=1; y2[6]=1;
            x1[7]=10; x2[7]=6; y1[7]=9; y2[7]=9;
            x1[8]=8; x2[8]=4; y1[8]=7; y2[8]=7;
            x1[9]=6; x2[9]=6; y1[9]=5; y2[9]=4;
            x1[10]=7; x2[10]=7; y1[10]=14; y2[10]=9;
            x1[11]=9; x2[11]=9; y1[11]=11; y2[11]=0;
            x1[12]=14; x2[12]=12; y1[12]=2; y2[12]=2;
        break;
        case 122:
            x1[0]=0; x2[0]=0; y1[0]=6; y2[0]=1;
            x1[1]=13; x2[1]=13; y1[1]=5; y2[1]=2;
            x1[2]=9; x2[2]=9; y1[2]=8; y2[2]=1;
            x1[3]=1; x2[3]=1; y1[3]=4; y2[3]=3;
            x1[4]=6; x2[4]=6; y1[4]=10; y2[4]=4;
            x1[5]=6; x2[5]=6; y1[5]=6; y2[5]=4;
            x1[6]=1; x2[6]=1; y1[6]=10; y2[6]=1;
            x1[7]=3; x2[7]=3; y1[7]=10; y2[7]=9;
            x1[8]=13; x2[8]=13; y1[8]=6; y2[8]=1;
            x1[9]=12; x2[9]=6; y1[9]=2; y2[9]=2;
            x1[10]=11; x2[10]=11; y1[10]=11; y2[10]=7;
            x1[11]=8; x2[11]=8; y1[11]=6; y2[11]=1;
            x1[12]=12; x2[12]=12; y1[12]=9; y2[12]=2;
        break;
        case 123:
            x1[0]=12; x2[0]=2; y1[0]=12; y2[0]=12;
            x1[1]=14; x2[1]=14; y1[1]=2; y2[1]=0;
            x1[2]=11; x2[2]=7; y1[2]=0; y2[2]=0;
            x1[3]=7; x2[3]=7; y1[3]=12; y2[3]=2;
            x1[4]=13; x2[4]=5; y1[4]=6; y2[4]=6;
            x1[5]=14; x2[5]=14; y1[5]=10; y2[5]=4;
            x1[6]=13; x2[6]=13; y1[6]=13; y2[6]=6;
            x1[7]=12; x2[7]=12; y1[7]=5; y2[7]=4;
            x1[8]=14; x2[8]=13; y1[8]=1; y2[8]=1;
            x1[9]=14; x2[9]=14; y1[9]=6; y2[9]=1;
            x1[10]=8; x2[10]=8; y1[10]=6; y2[10]=4;
            x1[11]=5; x2[11]=5; y1[11]=3; y2[11]=0;
            x1[12]=9; x2[12]=3; y1[12]=8; y2[12]=8;
        break;
        case 124:
            x1[0]=11; x2[0]=11; y1[0]=4; y2[0]=2;
            x1[1]=7; x2[1]=2; y1[1]=5; y2[1]=5;
            x1[2]=6; x2[2]=5; y1[2]=4; y2[2]=4;
            x1[3]=14; x2[3]=13; y1[3]=5; y2[3]=5;
            x1[4]=10; x2[4]=5; y1[4]=1; y2[4]=1;
            x1[5]=14; x2[5]=14; y1[5]=10; y2[5]=3;
            x1[6]=10; x2[6]=10; y1[6]=12; y2[6]=11;
            x1[7]=13; x2[7]=13; y1[7]=10; y2[7]=6;
            x1[8]=13; x2[8]=11; y1[8]=9; y2[8]=9;
            x1[9]=2; x2[9]=2; y1[9]=6; y2[9]=4;
            x1[10]=2; x2[10]=1; y1[10]=13; y2[10]=13;
            x1[11]=5; x2[11]=5; y1[11]=12; y2[11]=2;
            x1[12]=7; x2[12]=7; y1[12]=12; y2[12]=0;
        break;
        case 125:
            x1[0]=7; x2[0]=0; y1[0]=0; y2[0]=0;
            x1[1]=1; x2[1]=0; y1[1]=0; y2[1]=0;
            x1[2]=2; x2[2]=2; y1[2]=13; y2[2]=6;
            x1[3]=5; x2[3]=5; y1[3]=14; y2[3]=13;
            x1[4]=12; x2[4]=8; y1[4]=14; y2[4]=14;
            x1[5]=9; x2[5]=3; y1[5]=2; y2[5]=2;
            x1[6]=11; x2[6]=4; y1[6]=14; y2[6]=14;
            x1[7]=12; x2[7]=7; y1[7]=7; y2[7]=7;
            x1[8]=7; x2[8]=7; y1[8]=8; y2[8]=4;
            x1[9]=12; x2[9]=9; y1[9]=4; y2[9]=4;
            x1[10]=11; x2[10]=3; y1[10]=3; y2[10]=3;
            x1[11]=14; x2[11]=5; y1[11]=9; y2[11]=9;
            x1[12]=4; x2[12]=1; y1[12]=12; y2[12]=12;
        break;
        case 126:
            x1[0]=8; x2[0]=8; y1[0]=12; y2[0]=5;
            x1[1]=8; x2[1]=5; y1[1]=2; y2[1]=2;
            x1[2]=11; x2[2]=11; y1[2]=13; y2[2]=7;
            x1[3]=1; x2[3]=1; y1[3]=11; y2[3]=2;
            x1[4]=4; x2[4]=4; y1[4]=13; y2[4]=10;
            x1[5]=5; x2[5]=2; y1[5]=11; y2[5]=11;
            x1[6]=11; x2[6]=11; y1[6]=11; y2[6]=6;
            x1[7]=14; x2[7]=7; y1[7]=8; y2[7]=8;
            x1[8]=6; x2[8]=6; y1[8]=13; y2[8]=6;
            x1[9]=7; x2[9]=4; y1[9]=8; y2[9]=8;
            x1[10]=5; x2[10]=5; y1[10]=14; y2[10]=2;
            x1[11]=2; x2[11]=0; y1[11]=2; y2[11]=2;
            x1[12]=7; x2[12]=4; y1[12]=9; y2[12]=9;
        break;
        case 127:
            x1[0]=8; x2[0]=8; y1[0]=12; y2[0]=11;
            x1[1]=4; x2[1]=4; y1[1]=13; y2[1]=0;
            x1[2]=14; x2[2]=14; y1[2]=8; y2[2]=7;
            x1[3]=4; x2[3]=1; y1[3]=2; y2[3]=2;
            x1[4]=5; x2[4]=4; y1[4]=9; y2[4]=9;
            x1[5]=11; x2[5]=5; y1[5]=3; y2[5]=3;
            x1[6]=10; x2[6]=10; y1[6]=9; y2[6]=6;
            x1[7]=3; x2[7]=3; y1[7]=11; y2[7]=3;
            x1[8]=4; x2[8]=4; y1[8]=10; y2[8]=7;
            x1[9]=6; x2[9]=6; y1[9]=8; y2[9]=1;
            x1[10]=11; x2[10]=0; y1[10]=0; y2[10]=0;
            x1[11]=13; x2[11]=2; y1[11]=8; y2[11]=8;
            x1[12]=8; x2[12]=8; y1[12]=10; y2[12]=5;
        break;
        case 128:
            x1[0]=13; x2[0]=1; y1[0]=9; y2[0]=9;
            x1[1]=1; x2[1]=1; y1[1]=8; y2[1]=6;
            x1[2]=12; x2[2]=3; y1[2]=10; y2[2]=10;
            x1[3]=8; x2[3]=2; y1[3]=5; y2[3]=5;
            x1[4]=14; x2[4]=3; y1[4]=12; y2[4]=12;
            x1[5]=1; x2[5]=1; y1[5]=10; y2[5]=7;
            x1[6]=13; x2[6]=13; y1[6]=12; y2[6]=1;
            x1[7]=3; x2[7]=3; y1[7]=11; y2[7]=5;
            x1[8]=12; x2[8]=4; y1[8]=13; y2[8]=13;
            x1[9]=3; x2[9]=3; y1[9]=14; y2[9]=1;
            x1[10]=13; x2[10]=13; y1[10]=11; y2[10]=1;
            x1[11]=5; x2[11]=5; y1[11]=11; y2[11]=3;
            x1[12]=10; x2[12]=10; y1[12]=12; y2[12]=0;
        break;
        case 129:
            x1[0]=13; x2[0]=3; y1[0]=10; y2[0]=10;
            x1[1]=7; x2[1]=7; y1[1]=6; y2[1]=1;
            x1[2]=12; x2[2]=2; y1[2]=0; y2[2]=0;
            x1[3]=10; x2[3]=10; y1[3]=9; y2[3]=5;
            x1[4]=11; x2[4]=11; y1[4]=6; y2[4]=1;
            x1[5]=8; x2[5]=8; y1[5]=6; y2[5]=0;
            x1[6]=14; x2[6]=9; y1[6]=13; y2[6]=13;
            x1[7]=2; x2[7]=2; y1[7]=12; y2[7]=3;
            x1[8]=5; x2[8]=3; y1[8]=8; y2[8]=8;
            x1[9]=14; x2[9]=14; y1[9]=8; y2[9]=3;
            x1[10]=5; x2[10]=0; y1[10]=7; y2[10]=7;
            x1[11]=1; x2[11]=1; y1[11]=11; y2[11]=0;
            x1[12]=3; x2[12]=1; y1[12]=8; y2[12]=8;
        break;
        case 130:
            x1[0]=9; x2[0]=3; y1[0]=5; y2[0]=5;
            x1[1]=9; x2[1]=8; y1[1]=6; y2[1]=6;
            x1[2]=8; x2[2]=8; y1[2]=4; y2[2]=3;
            x1[3]=14; x2[3]=14; y1[3]=14; y2[3]=12;
            x1[4]=12; x2[4]=12; y1[4]=13; y2[4]=3;
            x1[5]=1; x2[5]=1; y1[5]=11; y2[5]=5;
            x1[6]=2; x2[6]=2; y1[6]=4; y2[6]=0;
            x1[7]=0; x2[7]=0; y1[7]=5; y2[7]=1;
            x1[8]=5; x2[8]=4; y1[8]=10; y2[8]=10;
            x1[9]=11; x2[9]=6; y1[9]=3; y2[9]=3;
            x1[10]=13; x2[10]=6; y1[10]=6; y2[10]=6;
            x1[11]=3; x2[11]=0; y1[11]=13; y2[11]=13;
            x1[12]=8; x2[12]=3; y1[12]=0; y2[12]=0;
        break;
        case 131:
            x1[0]=11; x2[0]=5; y1[0]=6; y2[0]=6;
            x1[1]=11; x2[1]=9; y1[1]=12; y2[1]=12;
            x1[2]=7; x2[2]=7; y1[2]=1; y2[2]=0;
            x1[3]=6; x2[3]=2; y1[3]=4; y2[3]=4;
            x1[4]=11; x2[4]=7; y1[4]=8; y2[4]=8;
            x1[5]=11; x2[5]=2; y1[5]=14; y2[5]=14;
            x1[6]=14; x2[6]=14; y1[6]=8; y2[6]=5;
            x1[7]=11; x2[7]=4; y1[7]=6; y2[7]=6;
            x1[8]=12; x2[8]=0; y1[8]=2; y2[8]=2;
            x1[9]=0; x2[9]=0; y1[9]=7; y2[9]=0;
            x1[10]=12; x2[10]=0; y1[10]=5; y2[10]=5;
            x1[11]=13; x2[11]=6; y1[11]=8; y2[11]=8;
            x1[12]=0; x2[12]=0; y1[12]=1; y2[12]=0;
        break;
        case 132:
            x1[0]=7; x2[0]=7; y1[0]=14; y2[0]=4;
            x1[1]=14; x2[1]=1; y1[1]=14; y2[1]=14;
            x1[2]=10; x2[2]=10; y1[2]=12; y2[2]=6;
            x1[3]=6; x2[3]=3; y1[3]=14; y2[3]=14;
            x1[4]=11; x2[4]=11; y1[4]=8; y2[4]=5;
            x1[5]=12; x2[5]=7; y1[5]=8; y2[5]=8;
            x1[6]=6; x2[6]=2; y1[6]=7; y2[6]=7;
            x1[7]=7; x2[7]=1; y1[7]=12; y2[7]=12;
            x1[8]=3; x2[8]=3; y1[8]=13; y2[8]=10;
            x1[9]=8; x2[9]=8; y1[9]=7; y2[9]=0;
            x1[10]=5; x2[10]=5; y1[10]=11; y2[10]=7;
            x1[11]=10; x2[11]=3; y1[11]=9; y2[11]=9;
            x1[12]=14; x2[12]=5; y1[12]=4; y2[12]=4;
        break;
        case 133:
            x1[0]=9; x2[0]=4; y1[0]=6; y2[0]=6;
            x1[1]=5; x2[1]=5; y1[1]=13; y2[1]=6;
            x1[2]=5; x2[2]=5; y1[2]=2; y2[2]=1;
            x1[3]=10; x2[3]=5; y1[3]=4; y2[3]=4;
            x1[4]=7; x2[4]=2; y1[4]=0; y2[4]=0;
            x1[5]=10; x2[5]=10; y1[5]=11; y2[5]=0;
            x1[6]=13; x2[6]=2; y1[6]=1; y2[6]=1;
            x1[7]=4; x2[7]=2; y1[7]=5; y2[7]=5;
            x1[8]=8; x2[8]=8; y1[8]=14; y2[8]=4;
            x1[9]=14; x2[9]=14; y1[9]=14; y2[9]=6;
            x1[10]=8; x2[10]=8; y1[10]=13; y2[10]=9;
            x1[11]=13; x2[11]=2; y1[11]=5; y2[11]=5;
            x1[12]=10; x2[12]=10; y1[12]=12; y2[12]=1;
        break;
        case 134:
            x1[0]=12; x2[0]=3; y1[0]=11; y2[0]=11;
            x1[1]=9; x2[1]=9; y1[1]=12; y2[1]=0;
            x1[2]=8; x2[2]=8; y1[2]=8; y2[2]=7;
            x1[3]=14; x2[3]=12; y1[3]=8; y2[3]=8;
            x1[4]=10; x2[4]=3; y1[4]=7; y2[4]=7;
            x1[5]=9; x2[5]=5; y1[5]=3; y2[5]=3;
            x1[6]=7; x2[6]=7; y1[6]=14; y2[6]=5;
            x1[7]=11; x2[7]=8; y1[7]=12; y2[7]=12;
            x1[8]=8; x2[8]=4; y1[8]=6; y2[8]=6;
            x1[9]=10; x2[9]=10; y1[9]=13; y2[9]=3;
            x1[10]=9; x2[10]=9; y1[10]=3; y2[10]=2;
            x1[11]=2; x2[11]=1; y1[11]=4; y2[11]=4;
            x1[12]=10; x2[12]=5; y1[12]=7; y2[12]=7;
        break;
        case 135:
            x1[0]=4; x2[0]=4; y1[0]=14; y2[0]=7;
            x1[1]=8; x2[1]=8; y1[1]=10; y2[1]=8;
            x1[2]=5; x2[2]=5; y1[2]=6; y2[2]=3;
            x1[3]=12; x2[3]=12; y1[3]=14; y2[3]=13;
            x1[4]=14; x2[4]=14; y1[4]=2; y2[4]=1;
            x1[5]=13; x2[5]=4; y1[5]=11; y2[5]=11;
            x1[6]=5; x2[6]=2; y1[6]=5; y2[6]=5;
            x1[7]=2; x2[7]=2; y1[7]=12; y2[7]=2;
            x1[8]=9; x2[8]=9; y1[8]=10; y2[8]=0;
            x1[9]=12; x2[9]=11; y1[9]=6; y2[9]=6;
            x1[10]=13; x2[10]=3; y1[10]=3; y2[10]=3;
            x1[11]=13; x2[11]=4; y1[11]=13; y2[11]=13;
            x1[12]=5; x2[12]=5; y1[12]=7; y2[12]=5;
        break;
        case 136:
            x1[0]=8; x2[0]=8; y1[0]=14; y2[0]=10;
            x1[1]=11; x2[1]=11; y1[1]=7; y2[1]=4;
            x1[2]=2; x2[2]=1; y1[2]=1; y2[2]=1;
            x1[3]=10; x2[3]=2; y1[3]=2; y2[3]=2;
            x1[4]=7; x2[4]=1; y1[4]=5; y2[4]=5;
            x1[5]=9; x2[5]=6; y1[5]=0; y2[5]=0;
            x1[6]=12; x2[6]=12; y1[6]=10; y2[6]=8;
            x1[7]=13; x2[7]=13; y1[7]=11; y2[7]=8;
            x1[8]=6; x2[8]=6; y1[8]=12; y2[8]=10;
            x1[9]=4; x2[9]=4; y1[9]=10; y2[9]=0;
            x1[10]=14; x2[10]=2; y1[10]=7; y2[10]=7;
            x1[11]=8; x2[11]=8; y1[11]=9; y2[11]=4;
            x1[12]=10; x2[12]=10; y1[12]=13; y2[12]=1;
        break;
        case 137:
            x1[0]=14; x2[0]=14; y1[0]=11; y2[0]=3;
            x1[1]=8; x2[1]=8; y1[1]=10; y2[1]=0;
            x1[2]=9; x2[2]=4; y1[2]=7; y2[2]=7;
            x1[3]=1; x2[3]=1; y1[3]=14; y2[3]=7;
            x1[4]=10; x2[4]=2; y1[4]=6; y2[4]=6;
            x1[5]=10; x2[5]=4; y1[5]=5; y2[5]=5;
            x1[6]=3; x2[6]=3; y1[6]=9; y2[6]=0;
            x1[7]=12; x2[7]=2; y1[7]=1; y2[7]=1;
            x1[8]=7; x2[8]=7; y1[8]=8; y2[8]=5;
            x1[9]=11; x2[9]=11; y1[9]=5; y2[9]=1;
            x1[10]=5; x2[10]=5; y1[10]=5; y2[10]=2;
            x1[11]=7; x2[11]=7; y1[11]=12; y2[11]=10;
            x1[12]=13; x2[12]=13; y1[12]=5; y2[12]=3;
        break;
        case 138:
            x1[0]=3; x2[0]=0; y1[0]=1; y2[0]=1;
            x1[1]=10; x2[1]=6; y1[1]=14; y2[1]=14;
            x1[2]=10; x2[2]=9; y1[2]=5; y2[2]=5;
            x1[3]=10; x2[3]=10; y1[3]=7; y2[3]=0;
            x1[4]=7; x2[4]=7; y1[4]=13; y2[4]=3;
            x1[5]=13; x2[5]=13; y1[5]=7; y2[5]=4;
            x1[6]=4; x2[6]=1; y1[6]=14; y2[6]=14;
            x1[7]=9; x2[7]=1; y1[7]=13; y2[7]=13;
            x1[8]=12; x2[8]=10; y1[8]=3; y2[8]=3;
            x1[9]=14; x2[9]=12; y1[9]=13; y2[9]=13;
            x1[10]=12; x2[10]=12; y1[10]=14; y2[10]=7;
            x1[11]=10; x2[11]=10; y1[11]=5; y2[11]=3;
            x1[12]=11; x2[12]=11; y1[12]=3; y2[12]=2;
        break;
        case 139:
            x1[0]=10; x2[0]=9; y1[0]=10; y2[0]=10;
            x1[1]=7; x2[1]=1; y1[1]=14; y2[1]=14;
            x1[2]=11; x2[2]=3; y1[2]=0; y2[2]=0;
            x1[3]=7; x2[3]=4; y1[3]=4; y2[3]=4;
            x1[4]=3; x2[4]=3; y1[4]=13; y2[4]=8;
            x1[5]=12; x2[5]=12; y1[5]=2; y2[5]=0;
            x1[6]=8; x2[6]=5; y1[6]=8; y2[6]=8;
            x1[7]=13; x2[7]=9; y1[7]=6; y2[7]=6;
            x1[8]=12; x2[8]=2; y1[8]=13; y2[8]=13;
            x1[9]=8; x2[9]=8; y1[9]=11; y2[9]=9;
            x1[10]=8; x2[10]=4; y1[10]=12; y2[10]=12;
            x1[11]=12; x2[11]=12; y1[11]=8; y2[11]=1;
            x1[12]=13; x2[12]=10; y1[12]=13; y2[12]=13;
        break;
        case 140:
            x1[0]=7; x2[0]=0; y1[0]=14; y2[0]=14;
            x1[1]=7; x2[1]=5; y1[1]=1; y2[1]=1;
            x1[2]=0; x2[2]=0; y1[2]=11; y2[2]=6;
            x1[3]=13; x2[3]=13; y1[3]=11; y2[3]=4;
            x1[4]=8; x2[4]=5; y1[4]=5; y2[4]=5;
            x1[5]=8; x2[5]=8; y1[5]=10; y2[5]=4;
            x1[6]=3; x2[6]=2; y1[6]=2; y2[6]=2;
            x1[7]=5; x2[7]=5; y1[7]=11; y2[7]=1;
            x1[8]=14; x2[8]=6; y1[8]=12; y2[8]=12;
            x1[9]=9; x2[9]=9; y1[9]=7; y2[9]=3;
            x1[10]=8; x2[10]=7; y1[10]=5; y2[10]=5;
            x1[11]=3; x2[11]=3; y1[11]=11; y2[11]=9;
            x1[12]=4; x2[12]=0; y1[12]=14; y2[12]=14;
        break;
        case 141:
            x1[0]=6; x2[0]=5; y1[0]=2; y2[0]=2;
            x1[1]=9; x2[1]=1; y1[1]=12; y2[1]=12;
            x1[2]=9; x2[2]=9; y1[2]=10; y2[2]=7;
            x1[3]=13; x2[3]=13; y1[3]=6; y2[3]=2;
            x1[4]=11; x2[4]=10; y1[4]=9; y2[4]=9;
            x1[5]=1; x2[5]=1; y1[5]=12; y2[5]=11;
            x1[6]=14; x2[6]=14; y1[6]=10; y2[6]=5;
            x1[7]=1; x2[7]=1; y1[7]=9; y2[7]=4;
            x1[8]=5; x2[8]=5; y1[8]=10; y2[8]=4;
            x1[9]=9; x2[9]=9; y1[9]=11; y2[9]=3;
            x1[10]=8; x2[10]=8; y1[10]=10; y2[10]=1;
            x1[11]=6; x2[11]=6; y1[11]=9; y2[11]=2;
            x1[12]=8; x2[12]=8; y1[12]=7; y2[12]=2;
        break;
        case 142:
            x1[0]=12; x2[0]=12; y1[0]=13; y2[0]=9;
            x1[1]=13; x2[1]=4; y1[1]=0; y2[1]=0;
            x1[2]=13; x2[2]=10; y1[2]=11; y2[2]=11;
            x1[3]=14; x2[3]=5; y1[3]=7; y2[3]=7;
            x1[4]=14; x2[4]=6; y1[4]=2; y2[4]=2;
            x1[5]=13; x2[5]=12; y1[5]=4; y2[5]=4;
            x1[6]=13; x2[6]=6; y1[6]=0; y2[6]=0;
            x1[7]=3; x2[7]=3; y1[7]=13; y2[7]=5;
            x1[8]=0; x2[8]=0; y1[8]=2; y2[8]=0;
            x1[9]=8; x2[9]=4; y1[9]=13; y2[9]=13;
            x1[10]=14; x2[10]=2; y1[10]=1; y2[10]=1;
            x1[11]=7; x2[11]=7; y1[11]=11; y2[11]=0;
            x1[12]=13; x2[12]=13; y1[12]=14; y2[12]=0;
        break;
        case 143:
            x1[0]=3; x2[0]=2; y1[0]=8; y2[0]=8;
            x1[1]=13; x2[1]=13; y1[1]=14; y2[1]=11;
            x1[2]=1; x2[2]=0; y1[2]=12; y2[2]=12;
            x1[3]=2; x2[3]=2; y1[3]=13; y2[3]=1;
            x1[4]=9; x2[4]=2; y1[4]=9; y2[4]=9;
            x1[5]=8; x2[5]=8; y1[5]=9; y2[5]=2;
            x1[6]=0; x2[6]=0; y1[6]=14; y2[6]=6;
            x1[7]=11; x2[7]=11; y1[7]=10; y2[7]=8;
            x1[8]=6; x2[8]=6; y1[8]=6; y2[8]=2;
            x1[9]=12; x2[9]=3; y1[9]=9; y2[9]=9;
            x1[10]=11; x2[10]=11; y1[10]=6; y2[10]=3;
            x1[11]=8; x2[11]=8; y1[11]=12; y2[11]=8;
            x1[12]=9; x2[12]=9; y1[12]=14; y2[12]=8;
        break;
        case 144:
            x1[0]=8; x2[0]=8; y1[0]=13; y2[0]=10;
            x1[1]=5; x2[1]=5; y1[1]=9; y2[1]=4;
            x1[2]=6; x2[2]=6; y1[2]=10; y2[2]=1;
            x1[3]=1; x2[3]=1; y1[3]=13; y2[3]=7;
            x1[4]=13; x2[4]=11; y1[4]=2; y2[4]=2;
            x1[5]=14; x2[5]=4; y1[5]=11; y2[5]=11;
            x1[6]=11; x2[6]=10; y1[6]=14; y2[6]=14;
            x1[7]=2; x2[7]=2; y1[7]=14; y2[7]=4;
            x1[8]=3; x2[8]=3; y1[8]=12; y2[8]=5;
            x1[9]=9; x2[9]=9; y1[9]=9; y2[9]=4;
            x1[10]=4; x2[10]=4; y1[10]=12; y2[10]=0;
            x1[11]=12; x2[11]=12; y1[11]=13; y2[11]=12;
            x1[12]=4; x2[12]=4; y1[12]=9; y2[12]=1;
        break;
        case 145:
            x1[0]=9; x2[0]=4; y1[0]=8; y2[0]=8;
            x1[1]=11; x2[1]=3; y1[1]=7; y2[1]=7;
            x1[2]=11; x2[2]=0; y1[2]=1; y2[2]=1;
            x1[3]=7; x2[3]=7; y1[3]=5; y2[3]=0;
            x1[4]=6; x2[4]=1; y1[4]=6; y2[4]=6;
            x1[5]=9; x2[5]=7; y1[5]=4; y2[5]=4;
            x1[6]=9; x2[6]=9; y1[6]=11; y2[6]=10;
            x1[7]=7; x2[7]=4; y1[7]=3; y2[7]=3;
            x1[8]=3; x2[8]=3; y1[8]=11; y2[8]=6;
            x1[9]=14; x2[9]=2; y1[9]=12; y2[9]=12;
            x1[10]=8; x2[10]=7; y1[10]=6; y2[10]=6;
            x1[11]=6; x2[11]=4; y1[11]=4; y2[11]=4;
            x1[12]=10; x2[12]=10; y1[12]=10; y2[12]=7;
        break;
        case 146:
            x1[0]=7; x2[0]=0; y1[0]=7; y2[0]=7;
            x1[1]=6; x2[1]=6; y1[1]=5; y2[1]=0;
            x1[2]=12; x2[2]=10; y1[2]=6; y2[2]=6;
            x1[3]=10; x2[3]=10; y1[3]=14; y2[3]=4;
            x1[4]=2; x2[4]=2; y1[4]=7; y2[4]=2;
            x1[5]=10; x2[5]=10; y1[5]=7; y2[5]=2;
            x1[6]=4; x2[6]=4; y1[6]=12; y2[6]=3;
            x1[7]=4; x2[7]=0; y1[7]=6; y2[7]=6;
            x1[8]=7; x2[8]=7; y1[8]=12; y2[8]=4;
            x1[9]=4; x2[9]=3; y1[9]=0; y2[9]=0;
            x1[10]=3; x2[10]=3; y1[10]=9; y2[10]=3;
            x1[11]=9; x2[11]=4; y1[11]=11; y2[11]=11;
            x1[12]=9; x2[12]=9; y1[12]=14; y2[12]=0;
        break;
        case 147:
            x1[0]=14; x2[0]=10; y1[0]=14; y2[0]=14;
            x1[1]=14; x2[1]=3; y1[1]=7; y2[1]=7;
            x1[2]=14; x2[2]=14; y1[2]=8; y2[2]=1;
            x1[3]=6; x2[3]=2; y1[3]=2; y2[3]=2;
            x1[4]=0; x2[4]=0; y1[4]=14; y2[4]=2;
            x1[5]=13; x2[5]=0; y1[5]=9; y2[5]=9;
            x1[6]=0; x2[6]=0; y1[6]=5; y2[6]=2;
            x1[7]=5; x2[7]=5; y1[7]=8; y2[7]=7;
            x1[8]=6; x2[8]=4; y1[8]=0; y2[8]=0;
            x1[9]=11; x2[9]=8; y1[9]=0; y2[9]=0;
            x1[10]=0; x2[10]=0; y1[10]=12; y2[10]=0;
            x1[11]=9; x2[11]=9; y1[11]=13; y2[11]=8;
            x1[12]=9; x2[12]=9; y1[12]=14; y2[12]=4;
        break;
        case 148:
            x1[0]=7; x2[0]=7; y1[0]=9; y2[0]=6;
            x1[1]=8; x2[1]=6; y1[1]=14; y2[1]=14;
            x1[2]=4; x2[2]=4; y1[2]=6; y2[2]=1;
            x1[3]=5; x2[3]=5; y1[3]=4; y2[3]=1;
            x1[4]=4; x2[4]=3; y1[4]=9; y2[4]=9;
            x1[5]=1; x2[5]=1; y1[5]=14; y2[5]=2;
            x1[6]=0; x2[6]=0; y1[6]=14; y2[6]=12;
            x1[7]=8; x2[7]=2; y1[7]=9; y2[7]=9;
            x1[8]=8; x2[8]=8; y1[8]=14; y2[8]=9;
            x1[9]=12; x2[9]=11; y1[9]=3; y2[9]=3;
            x1[10]=13; x2[10]=6; y1[10]=2; y2[10]=2;
            x1[11]=6; x2[11]=6; y1[11]=1; y2[11]=0;
            x1[12]=4; x2[12]=4; y1[12]=8; y2[12]=0;
        break;
        case 149:
            x1[0]=8; x2[0]=8; y1[0]=12; y2[0]=0;
            x1[1]=5; x2[1]=5; y1[1]=10; y2[1]=3;
            x1[2]=8; x2[2]=6; y1[2]=11; y2[2]=11;
            x1[3]=7; x2[3]=1; y1[3]=11; y2[3]=11;
            x1[4]=11; x2[4]=0; y1[4]=9; y2[4]=9;
            x1[5]=9; x2[5]=6; y1[5]=5; y2[5]=5;
            x1[6]=2; x2[6]=2; y1[6]=7; y2[6]=4;
            x1[7]=13; x2[7]=13; y1[7]=13; y2[7]=9;
            x1[8]=10; x2[8]=6; y1[8]=12; y2[8]=12;
            x1[9]=4; x2[9]=4; y1[9]=10; y2[9]=3;
            x1[10]=14; x2[10]=1; y1[10]=1; y2[10]=1;
            x1[11]=9; x2[11]=6; y1[11]=11; y2[11]=11;
            x1[12]=10; x2[12]=3; y1[12]=2; y2[12]=2;
        break;
        case 150:
            x1[0]=10; x2[0]=10; y1[0]=8; y2[0]=7;
            x1[1]=3; x2[1]=3; y1[1]=6; y2[1]=2;
            x1[2]=12; x2[2]=10; y1[2]=11; y2[2]=11;
            x1[3]=7; x2[3]=7; y1[3]=5; y2[3]=4;
            x1[4]=7; x2[4]=2; y1[4]=7; y2[4]=7;
            x1[5]=0; x2[5]=0; y1[5]=7; y2[5]=5;
            x1[6]=9; x2[6]=7; y1[6]=0; y2[6]=0;
            x1[7]=5; x2[7]=5; y1[7]=12; y2[7]=1;
            x1[8]=12; x2[8]=12; y1[8]=14; y2[8]=10;
            x1[9]=1; x2[9]=1; y1[9]=4; y2[9]=0;
            x1[10]=14; x2[10]=10; y1[10]=11; y2[10]=11;
            x1[11]=11; x2[11]=11; y1[11]=11; y2[11]=3;
            x1[12]=2; x2[12]=0; y1[12]=14; y2[12]=14;
        break;
        case 151:
            x1[0]=9; x2[0]=9; y1[0]=7; y2[0]=6;
            x1[1]=13; x2[1]=4; y1[1]=2; y2[1]=2;
            x1[2]=10; x2[2]=4; y1[2]=4; y2[2]=4;
            x1[3]=6; x2[3]=6; y1[3]=10; y2[3]=6;
            x1[4]=10; x2[4]=10; y1[4]=13; y2[4]=7;
            x1[5]=13; x2[5]=2; y1[5]=2; y2[5]=2;
            x1[6]=14; x2[6]=14; y1[6]=14; y2[6]=5;
            x1[7]=10; x2[7]=5; y1[7]=13; y2[7]=13;
            x1[8]=11; x2[8]=11; y1[8]=14; y2[8]=10;
            x1[9]=13; x2[9]=11; y1[9]=0; y2[9]=0;
            x1[10]=14; x2[10]=14; y1[10]=3; y2[10]=1;
            x1[11]=13; x2[11]=9; y1[11]=8; y2[11]=8;
            x1[12]=10; x2[12]=6; y1[12]=1; y2[12]=1;
        break;
        case 152:
            x1[0]=3; x2[0]=3; y1[0]=6; y2[0]=4;
            x1[1]=3; x2[1]=3; y1[1]=11; y2[1]=8;
            x1[2]=9; x2[2]=9; y1[2]=7; y2[2]=1;
            x1[3]=8; x2[3]=4; y1[3]=5; y2[3]=5;
            x1[4]=7; x2[4]=7; y1[4]=9; y2[4]=4;
            x1[5]=11; x2[5]=6; y1[5]=7; y2[5]=7;
            x1[6]=11; x2[6]=1; y1[6]=12; y2[6]=12;
            x1[7]=14; x2[7]=14; y1[7]=12; y2[7]=1;
            x1[8]=14; x2[8]=14; y1[8]=9; y2[8]=2;
            x1[9]=10; x2[9]=3; y1[9]=12; y2[9]=12;
            x1[10]=9; x2[10]=7; y1[10]=5; y2[10]=5;
            x1[11]=5; x2[11]=5; y1[11]=14; y2[11]=0;
            x1[12]=8; x2[12]=8; y1[12]=13; y2[12]=7;
        break;
        case 153:
            x1[0]=10; x2[0]=10; y1[0]=13; y2[0]=8;
            x1[1]=10; x2[1]=3; y1[1]=0; y2[1]=0;
            x1[2]=14; x2[2]=12; y1[2]=11; y2[2]=11;
            x1[3]=3; x2[3]=3; y1[3]=13; y2[3]=3;
            x1[4]=14; x2[4]=8; y1[4]=13; y2[4]=13;
            x1[5]=3; x2[5]=3; y1[5]=13; y2[5]=9;
            x1[6]=0; x2[6]=0; y1[6]=14; y2[6]=5;
            x1[7]=2; x2[7]=2; y1[7]=13; y2[7]=11;
            x1[8]=13; x2[8]=2; y1[8]=14; y2[8]=14;
            x1[9]=11; x2[9]=11; y1[9]=7; y2[9]=3;
            x1[10]=6; x2[10]=6; y1[10]=12; y2[10]=5;
            x1[11]=9; x2[11]=4; y1[11]=2; y2[11]=2;
            x1[12]=14; x2[12]=13; y1[12]=11; y2[12]=11;
        break;
        case 154:
            x1[0]=14; x2[0]=13; y1[0]=0; y2[0]=0;
            x1[1]=14; x2[1]=14; y1[1]=9; y2[1]=5;
            x1[2]=4; x2[2]=3; y1[2]=4; y2[2]=4;
            x1[3]=11; x2[3]=11; y1[3]=13; y2[3]=0;
            x1[4]=10; x2[4]=10; y1[4]=13; y2[4]=6;
            x1[5]=4; x2[5]=4; y1[5]=7; y2[5]=0;
            x1[6]=13; x2[6]=13; y1[6]=12; y2[6]=5;
            x1[7]=1; x2[7]=1; y1[7]=5; y2[7]=3;
            x1[8]=3; x2[8]=2; y1[8]=1; y2[8]=1;
            x1[9]=7; x2[9]=7; y1[9]=12; y2[9]=9;
            x1[10]=3; x2[10]=3; y1[10]=11; y2[10]=1;
            x1[11]=4; x2[11]=4; y1[11]=8; y2[11]=2;
            x1[12]=9; x2[12]=5; y1[12]=10; y2[12]=10;
        break;
        case 155:
            x1[0]=11; x2[0]=11; y1[0]=12; y2[0]=9;
            x1[1]=8; x2[1]=7; y1[1]=4; y2[1]=4;
            x1[2]=11; x2[2]=11; y1[2]=12; y2[2]=3;
            x1[3]=11; x2[3]=6; y1[3]=5; y2[3]=5;
            x1[4]=1; x2[4]=1; y1[4]=9; y2[4]=7;
            x1[5]=12; x2[5]=5; y1[5]=11; y2[5]=11;
            x1[6]=6; x2[6]=5; y1[6]=12; y2[6]=12;
            x1[7]=7; x2[7]=6; y1[7]=7; y2[7]=7;
            x1[8]=7; x2[8]=7; y1[8]=11; y2[8]=9;
            x1[9]=13; x2[9]=13; y1[9]=3; y2[9]=1;
            x1[10]=11; x2[10]=6; y1[10]=9; y2[10]=9;
            x1[11]=13; x2[11]=12; y1[11]=9; y2[11]=9;
            x1[12]=6; x2[12]=6; y1[12]=11; y2[12]=2;
        break;
        case 156:
            x1[0]=4; x2[0]=2; y1[0]=11; y2[0]=11;
            x1[1]=11; x2[1]=11; y1[1]=12; y2[1]=10;
            x1[2]=10; x2[2]=7; y1[2]=2; y2[2]=2;
            x1[3]=14; x2[3]=0; y1[3]=11; y2[3]=11;
            x1[4]=14; x2[4]=2; y1[4]=5; y2[4]=5;
            x1[5]=7; x2[5]=2; y1[5]=8; y2[5]=8;
            x1[6]=4; x2[6]=3; y1[6]=1; y2[6]=1;
            x1[7]=5; x2[7]=1; y1[7]=3; y2[7]=3;
            x1[8]=12; x2[8]=9; y1[8]=10; y2[8]=10;
            x1[9]=6; x2[9]=5; y1[9]=0; y2[9]=0;
            x1[10]=13; x2[10]=1; y1[10]=4; y2[10]=4;
            x1[11]=1; x2[11]=1; y1[11]=12; y2[11]=3;
            x1[12]=10; x2[12]=1; y1[12]=1; y2[12]=1;
        break;
        case 157:
            x1[0]=8; x2[0]=8; y1[0]=3; y2[0]=2;
            x1[1]=3; x2[1]=1; y1[1]=14; y2[1]=14;
            x1[2]=9; x2[2]=2; y1[2]=5; y2[2]=5;
            x1[3]=14; x2[3]=14; y1[3]=14; y2[3]=8;
            x1[4]=6; x2[4]=6; y1[4]=6; y2[4]=0;
            x1[5]=11; x2[5]=5; y1[5]=9; y2[5]=9;
            x1[6]=11; x2[6]=11; y1[6]=14; y2[6]=7;
            x1[7]=5; x2[7]=0; y1[7]=10; y2[7]=10;
            x1[8]=10; x2[8]=10; y1[8]=13; y2[8]=9;
            x1[9]=1; x2[9]=0; y1[9]=13; y2[9]=13;
            x1[10]=0; x2[10]=0; y1[10]=13; y2[10]=0;
            x1[11]=6; x2[11]=6; y1[11]=10; y2[11]=9;
            x1[12]=2; x2[12]=2; y1[12]=8; y2[12]=5;
        break;
        case 158:
            x1[0]=2; x2[0]=1; y1[0]=3; y2[0]=3;
            x1[1]=1; x2[1]=0; y1[1]=10; y2[1]=10;
            x1[2]=1; x2[2]=1; y1[2]=14; y2[2]=4;
            x1[3]=14; x2[3]=7; y1[3]=9; y2[3]=9;
            x1[4]=10; x2[4]=8; y1[4]=9; y2[4]=9;
            x1[5]=9; x2[5]=9; y1[5]=6; y2[5]=1;
            x1[6]=4; x2[6]=4; y1[6]=14; y2[6]=4;
            x1[7]=10; x2[7]=1; y1[7]=13; y2[7]=13;
            x1[8]=1; x2[8]=1; y1[8]=13; y2[8]=5;
            x1[9]=3; x2[9]=1; y1[9]=10; y2[9]=10;
            x1[10]=2; x2[10]=2; y1[10]=5; y2[10]=4;
            x1[11]=3; x2[11]=3; y1[11]=3; y2[11]=0;
            x1[12]=9; x2[12]=9; y1[12]=13; y2[12]=11;
        break;
        case 159:
            x1[0]=8; x2[0]=7; y1[0]=11; y2[0]=11;
            x1[1]=11; x2[1]=11; y1[1]=9; y2[1]=0;
            x1[2]=13; x2[2]=9; y1[2]=12; y2[2]=12;
            x1[3]=8; x2[3]=6; y1[3]=3; y2[3]=3;
            x1[4]=8; x2[4]=8; y1[4]=12; y2[4]=1;
            x1[5]=14; x2[5]=11; y1[5]=6; y2[5]=6;
            x1[6]=2; x2[6]=2; y1[6]=4; y2[6]=3;
            x1[7]=10; x2[7]=10; y1[7]=3; y2[7]=2;
            x1[8]=12; x2[8]=10; y1[8]=2; y2[8]=2;
            x1[9]=6; x2[9]=6; y1[9]=3; y2[9]=2;
            x1[10]=0; x2[10]=0; y1[10]=12; y2[10]=7;
            x1[11]=7; x2[11]=4; y1[11]=1; y2[11]=1;
            x1[12]=11; x2[12]=2; y1[12]=4; y2[12]=4;
        break;
        case 160:
            x1[0]=10; x2[0]=1; y1[0]=9; y2[0]=9;
            x1[1]=4; x2[1]=4; y1[1]=2; y2[1]=0;
            x1[2]=11; x2[2]=10; y1[2]=8; y2[2]=8;
            x1[3]=12; x2[3]=12; y1[3]=1; y2[3]=0;
            x1[4]=13; x2[4]=6; y1[4]=5; y2[4]=5;
            x1[5]=12; x2[5]=12; y1[5]=13; y2[5]=0;
            x1[6]=5; x2[6]=1; y1[6]=10; y2[6]=10;
            x1[7]=14; x2[7]=9; y1[7]=12; y2[7]=12;
            x1[8]=9; x2[8]=1; y1[8]=6; y2[8]=6;
            x1[9]=11; x2[9]=11; y1[9]=11; y2[9]=5;
            x1[10]=12; x2[10]=12; y1[10]=13; y2[10]=11;
            x1[11]=10; x2[11]=10; y1[11]=14; y2[11]=5;
            x1[12]=6; x2[12]=5; y1[12]=6; y2[12]=6;
        break;
        case 161:
            x1[0]=14; x2[0]=13; y1[0]=3; y2[0]=3;
            x1[1]=6; x2[1]=3; y1[1]=0; y2[1]=0;
            x1[2]=5; x2[2]=5; y1[2]=9; y2[2]=6;
            x1[3]=11; x2[3]=11; y1[3]=9; y2[3]=8;
            x1[4]=7; x2[4]=7; y1[4]=11; y2[4]=7;
            x1[5]=0; x2[5]=0; y1[5]=13; y2[5]=8;
            x1[6]=12; x2[6]=7; y1[6]=12; y2[6]=12;
            x1[7]=11; x2[7]=9; y1[7]=1; y2[7]=1;
            x1[8]=14; x2[8]=13; y1[8]=7; y2[8]=7;
            x1[9]=6; x2[9]=4; y1[9]=12; y2[9]=12;
            x1[10]=8; x2[10]=8; y1[10]=11; y2[10]=2;
            x1[11]=13; x2[11]=13; y1[11]=13; y2[11]=2;
            x1[12]=10; x2[12]=10; y1[12]=11; y2[12]=4;
        break;
        case 162:
            x1[0]=11; x2[0]=9; y1[0]=2; y2[0]=2;
            x1[1]=6; x2[1]=6; y1[1]=11; y2[1]=9;
            x1[2]=13; x2[2]=13; y1[2]=12; y2[2]=7;
            x1[3]=0; x2[3]=0; y1[3]=14; y2[3]=9;
            x1[4]=12; x2[4]=9; y1[4]=11; y2[4]=11;
            x1[5]=10; x2[5]=4; y1[5]=2; y2[5]=2;
            x1[6]=10; x2[6]=3; y1[6]=1; y2[6]=1;
            x1[7]=6; x2[7]=6; y1[7]=13; y2[7]=10;
            x1[8]=11; x2[8]=11; y1[8]=14; y2[8]=9;
            x1[9]=13; x2[9]=13; y1[9]=9; y2[9]=8;
            x1[10]=5; x2[10]=2; y1[10]=12; y2[10]=12;
            x1[11]=12; x2[11]=6; y1[11]=14; y2[11]=14;
            x1[12]=5; x2[12]=0; y1[12]=5; y2[12]=5;
        break;
        case 163:
            x1[0]=10; x2[0]=1; y1[0]=7; y2[0]=7;
            x1[1]=12; x2[1]=1; y1[1]=1; y2[1]=1;
            x1[2]=7; x2[2]=7; y1[2]=11; y2[2]=5;
            x1[3]=12; x2[3]=6; y1[3]=10; y2[3]=10;
            x1[4]=5; x2[4]=5; y1[4]=7; y2[4]=0;
            x1[5]=8; x2[5]=5; y1[5]=3; y2[5]=3;
            x1[6]=5; x2[6]=5; y1[6]=6; y2[6]=1;
            x1[7]=6; x2[7]=6; y1[7]=11; y2[7]=7;
            x1[8]=8; x2[8]=8; y1[8]=11; y2[8]=10;
            x1[9]=9; x2[9]=9; y1[9]=10; y2[9]=2;
            x1[10]=11; x2[10]=11; y1[10]=12; y2[10]=4;
            x1[11]=4; x2[11]=4; y1[11]=3; y2[11]=1;
            x1[12]=5; x2[12]=0; y1[12]=12; y2[12]=12;
        break;
        case 164:
            x1[0]=12; x2[0]=0; y1[0]=4; y2[0]=4;
            x1[1]=8; x2[1]=6; y1[1]=12; y2[1]=12;
            x1[2]=14; x2[2]=5; y1[2]=13; y2[2]=13;
            x1[3]=5; x2[3]=5; y1[3]=13; y2[3]=9;
            x1[4]=4; x2[4]=4; y1[4]=11; y2[4]=9;
            x1[5]=14; x2[5]=14; y1[5]=10; y2[5]=1;
            x1[6]=10; x2[6]=5; y1[6]=12; y2[6]=12;
            x1[7]=8; x2[7]=8; y1[7]=4; y2[7]=1;
            x1[8]=1; x2[8]=1; y1[8]=5; y2[8]=2;
            x1[9]=11; x2[9]=8; y1[9]=8; y2[9]=8;
            x1[10]=9; x2[10]=9; y1[10]=13; y2[10]=10;
            x1[11]=4; x2[11]=3; y1[11]=10; y2[11]=10;
            x1[12]=8; x2[12]=8; y1[12]=8; y2[12]=1;
        break;
        case 165:
            x1[0]=11; x2[0]=0; y1[0]=5; y2[0]=5;
            x1[1]=3; x2[1]=3; y1[1]=13; y2[1]=4;
            x1[2]=13; x2[2]=13; y1[2]=12; y2[2]=2;
            x1[3]=9; x2[3]=7; y1[3]=12; y2[3]=12;
            x1[4]=11; x2[4]=9; y1[4]=10; y2[4]=10;
            x1[5]=10; x2[5]=10; y1[5]=7; y2[5]=6;
            x1[6]=11; x2[6]=11; y1[6]=8; y2[6]=2;
            x1[7]=10; x2[7]=0; y1[7]=14; y2[7]=14;
            x1[8]=9; x2[8]=9; y1[8]=14; y2[8]=9;
            x1[9]=13; x2[9]=8; y1[9]=2; y2[9]=2;
            x1[10]=2; x2[10]=1; y1[10]=0; y2[10]=0;
            x1[11]=7; x2[11]=7; y1[11]=13; y2[11]=5;
            x1[12]=7; x2[12]=7; y1[12]=6; y2[12]=5;
        break;
        case 166:
            x1[0]=3; x2[0]=3; y1[0]=14; y2[0]=10;
            x1[1]=12; x2[1]=1; y1[1]=10; y2[1]=10;
            x1[2]=9; x2[2]=9; y1[2]=12; y2[2]=4;
            x1[3]=11; x2[3]=3; y1[3]=1; y2[3]=1;
            x1[4]=2; x2[4]=2; y1[4]=9; y2[4]=5;
            x1[5]=14; x2[5]=8; y1[5]=2; y2[5]=2;
            x1[6]=14; x2[6]=14; y1[6]=7; y2[6]=2;
            x1[7]=8; x2[7]=8; y1[7]=2; y2[7]=1;
            x1[8]=12; x2[8]=10; y1[8]=14; y2[8]=14;
            x1[9]=12; x2[9]=8; y1[9]=7; y2[9]=7;
            x1[10]=9; x2[10]=5; y1[10]=5; y2[10]=5;
            x1[11]=12; x2[11]=11; y1[11]=14; y2[11]=14;
            x1[12]=4; x2[12]=4; y1[12]=3; y2[12]=0;
        break;
        case 167:
            x1[0]=6; x2[0]=0; y1[0]=8; y2[0]=8;
            x1[1]=10; x2[1]=8; y1[1]=6; y2[1]=6;
            x1[2]=9; x2[2]=4; y1[2]=12; y2[2]=12;
            x1[3]=6; x2[3]=6; y1[3]=14; y2[3]=10;
            x1[4]=13; x2[4]=9; y1[4]=10; y2[4]=10;
            x1[5]=3; x2[5]=3; y1[5]=7; y2[5]=6;
            x1[6]=14; x2[6]=11; y1[6]=10; y2[6]=10;
            x1[7]=0; x2[7]=0; y1[7]=14; y2[7]=13;
            x1[8]=3; x2[8]=3; y1[8]=12; y2[8]=8;
            x1[9]=8; x2[9]=6; y1[9]=2; y2[9]=2;
            x1[10]=6; x2[10]=2; y1[10]=5; y2[10]=5;
            x1[11]=10; x2[11]=0; y1[11]=3; y2[11]=3;
            x1[12]=9; x2[12]=9; y1[12]=12; y2[12]=1;
        break;
        case 168:
            x1[0]=4; x2[0]=4; y1[0]=6; y2[0]=4;
            x1[1]=11; x2[1]=11; y1[1]=14; y2[1]=3;
            x1[2]=14; x2[2]=14; y1[2]=12; y2[2]=4;
            x1[3]=8; x2[3]=5; y1[3]=7; y2[3]=7;
            x1[4]=12; x2[4]=9; y1[4]=14; y2[4]=14;
            x1[5]=2; x2[5]=2; y1[5]=11; y2[5]=5;
            x1[6]=13; x2[6]=13; y1[6]=14; y2[6]=1;
            x1[7]=5; x2[7]=5; y1[7]=5; y2[7]=1;
            x1[8]=14; x2[8]=11; y1[8]=12; y2[8]=12;
            x1[9]=6; x2[9]=6; y1[9]=10; y2[9]=0;
            x1[10]=4; x2[10]=4; y1[10]=3; y2[10]=2;
            x1[11]=7; x2[11]=1; y1[11]=8; y2[11]=8;
            x1[12]=7; x2[12]=3; y1[12]=9; y2[12]=9;
        break;
        case 169:
            x1[0]=11; x2[0]=1; y1[0]=11; y2[0]=11;
            x1[1]=6; x2[1]=6; y1[1]=7; y2[1]=0;
            x1[2]=5; x2[2]=5; y1[2]=11; y2[2]=8;
            x1[3]=14; x2[3]=2; y1[3]=2; y2[3]=2;
            x1[4]=7; x2[4]=7; y1[4]=11; y2[4]=4;
            x1[5]=7; x2[5]=7; y1[5]=7; y2[5]=3;
            x1[6]=9; x2[6]=9; y1[6]=10; y2[6]=3;
            x1[7]=2; x2[7]=2; y1[7]=12; y2[7]=7;
            x1[8]=12; x2[8]=2; y1[8]=8; y2[8]=8;
            x1[9]=14; x2[9]=14; y1[9]=12; y2[9]=3;
            x1[10]=9; x2[10]=2; y1[10]=8; y2[10]=8;
            x1[11]=4; x2[11]=4; y1[11]=4; y2[11]=1;
            x1[12]=8; x2[12]=0; y1[12]=1; y2[12]=1;
        break;
        case 170:
            x1[0]=8; x2[0]=7; y1[0]=0; y2[0]=0;
            x1[1]=8; x2[1]=3; y1[1]=8; y2[1]=8;
            x1[2]=13; x2[2]=2; y1[2]=10; y2[2]=10;
            x1[3]=12; x2[3]=5; y1[3]=7; y2[3]=7;
            x1[4]=2; x2[4]=2; y1[4]=11; y2[4]=4;
            x1[5]=6; x2[5]=6; y1[5]=14; y2[5]=4;
            x1[6]=11; x2[6]=5; y1[6]=11; y2[6]=11;
            x1[7]=9; x2[7]=6; y1[7]=2; y2[7]=2;
            x1[8]=1; x2[8]=1; y1[8]=5; y2[8]=4;
            x1[9]=4; x2[9]=4; y1[9]=10; y2[9]=5;
            x1[10]=12; x2[10]=12; y1[10]=9; y2[10]=6;
            x1[11]=8; x2[11]=8; y1[11]=1; y2[11]=0;
            x1[12]=4; x2[12]=4; y1[12]=8; y2[12]=5;
        break;
        case 171:
            x1[0]=12; x2[0]=12; y1[0]=5; y2[0]=2;
            x1[1]=3; x2[1]=3; y1[1]=6; y2[1]=5;
            x1[2]=14; x2[2]=14; y1[2]=13; y2[2]=12;
            x1[3]=10; x2[3]=10; y1[3]=9; y2[3]=7;
            x1[4]=5; x2[4]=3; y1[4]=10; y2[4]=10;
            x1[5]=5; x2[5]=4; y1[5]=0; y2[5]=0;
            x1[6]=8; x2[6]=8; y1[6]=13; y2[6]=12;
            x1[7]=14; x2[7]=11; y1[7]=11; y2[7]=11;
            x1[8]=13; x2[8]=1; y1[8]=7; y2[8]=7;
            x1[9]=6; x2[9]=3; y1[9]=10; y2[9]=10;
            x1[10]=3; x2[10]=3; y1[10]=14; y2[10]=5;
            x1[11]=2; x2[11]=2; y1[11]=7; y2[11]=6;
            x1[12]=7; x2[12]=7; y1[12]=8; y2[12]=0;
        break;
        case 172:
            x1[0]=2; x2[0]=2; y1[0]=10; y2[0]=3;
            x1[1]=9; x2[1]=6; y1[1]=13; y2[1]=13;
            x1[2]=6; x2[2]=0; y1[2]=12; y2[2]=12;
            x1[3]=4; x2[3]=0; y1[3]=4; y2[3]=4;
            x1[4]=13; x2[4]=9; y1[4]=9; y2[4]=9;
            x1[5]=2; x2[5]=0; y1[5]=3; y2[5]=3;
            x1[6]=1; x2[6]=1; y1[6]=7; y2[6]=6;
            x1[7]=13; x2[7]=13; y1[7]=10; y2[7]=9;
            x1[8]=7; x2[8]=7; y1[8]=7; y2[8]=2;
            x1[9]=6; x2[9]=3; y1[9]=1; y2[9]=1;
            x1[10]=12; x2[10]=12; y1[10]=11; y2[10]=7;
            x1[11]=11; x2[11]=3; y1[11]=14; y2[11]=14;
            x1[12]=8; x2[12]=8; y1[12]=6; y2[12]=3;
        break;
        case 173:
            x1[0]=12; x2[0]=12; y1[0]=12; y2[0]=1;
            x1[1]=4; x2[1]=4; y1[1]=14; y2[1]=1;
            x1[2]=1; x2[2]=1; y1[2]=4; y2[2]=1;
            x1[3]=14; x2[3]=14; y1[3]=14; y2[3]=4;
            x1[4]=10; x2[4]=6; y1[4]=0; y2[4]=0;
            x1[5]=11; x2[5]=8; y1[5]=4; y2[5]=4;
            x1[6]=11; x2[6]=11; y1[6]=14; y2[6]=12;
            x1[7]=12; x2[7]=0; y1[7]=1; y2[7]=1;
            x1[8]=3; x2[8]=2; y1[8]=5; y2[8]=5;
            x1[9]=9; x2[9]=9; y1[9]=7; y2[9]=0;
            x1[10]=11; x2[10]=0; y1[10]=6; y2[10]=6;
            x1[11]=11; x2[11]=4; y1[11]=2; y2[11]=2;
            x1[12]=8; x2[12]=8; y1[12]=14; y2[12]=6;
        break;
        case 174:
            x1[0]=9; x2[0]=8; y1[0]=8; y2[0]=8;
            x1[1]=8; x2[1]=5; y1[1]=11; y2[1]=11;
            x1[2]=9; x2[2]=8; y1[2]=7; y2[2]=7;
            x1[3]=5; x2[3]=5; y1[3]=8; y2[3]=6;
            x1[4]=3; x2[4]=0; y1[4]=4; y2[4]=4;
            x1[5]=8; x2[5]=1; y1[5]=13; y2[5]=13;
            x1[6]=9; x2[6]=9; y1[6]=5; y2[6]=4;
            x1[7]=10; x2[7]=10; y1[7]=11; y2[7]=10;
            x1[8]=11; x2[8]=9; y1[8]=4; y2[8]=4;
            x1[9]=11; x2[9]=11; y1[9]=14; y2[9]=2;
            x1[10]=2; x2[10]=0; y1[10]=5; y2[10]=5;
            x1[11]=0; x2[11]=0; y1[11]=7; y2[11]=2;
            x1[12]=8; x2[12]=8; y1[12]=3; y2[12]=1;
        break;
        case 175:
            x1[0]=14; x2[0]=13; y1[0]=9; y2[0]=9;
            x1[1]=4; x2[1]=4; y1[1]=14; y2[1]=6;
            x1[2]=9; x2[2]=9; y1[2]=9; y2[2]=5;
            x1[3]=11; x2[3]=11; y1[3]=8; y2[3]=7;
            x1[4]=0; x2[4]=0; y1[4]=9; y2[4]=4;
            x1[5]=8; x2[5]=8; y1[5]=5; y2[5]=2;
            x1[6]=8; x2[6]=6; y1[6]=10; y2[6]=10;
            x1[7]=13; x2[7]=2; y1[7]=9; y2[7]=9;
            x1[8]=0; x2[8]=0; y1[8]=10; y2[8]=0;
            x1[9]=12; x2[9]=12; y1[9]=14; y2[9]=11;
            x1[10]=5; x2[10]=5; y1[10]=13; y2[10]=7;
            x1[11]=14; x2[11]=14; y1[11]=10; y2[11]=0;
            x1[12]=7; x2[12]=0; y1[12]=5; y2[12]=5;
        break;
        case 176:
            x1[0]=5; x2[0]=5; y1[0]=10; y2[0]=0;
            x1[1]=13; x2[1]=5; y1[1]=0; y2[1]=0;
            x1[2]=14; x2[2]=14; y1[2]=5; y2[2]=0;
            x1[3]=2; x2[3]=2; y1[3]=13; y2[3]=9;
            x1[4]=10; x2[4]=10; y1[4]=7; y2[4]=1;
            x1[5]=11; x2[5]=11; y1[5]=13; y2[5]=8;
            x1[6]=12; x2[6]=11; y1[6]=2; y2[6]=2;
            x1[7]=3; x2[7]=1; y1[7]=0; y2[7]=0;
            x1[8]=8; x2[8]=8; y1[8]=13; y2[8]=2;
            x1[9]=14; x2[9]=6; y1[9]=8; y2[9]=8;
            x1[10]=6; x2[10]=6; y1[10]=14; y2[10]=11;
            x1[11]=7; x2[11]=7; y1[11]=14; y2[11]=3;
            x1[12]=8; x2[12]=3; y1[12]=4; y2[12]=4;
        break;
        case 177:
            x1[0]=2; x2[0]=0; y1[0]=9; y2[0]=9;
            x1[1]=3; x2[1]=3; y1[1]=8; y2[1]=2;
            x1[2]=7; x2[2]=7; y1[2]=4; y2[2]=1;
            x1[3]=9; x2[3]=1; y1[3]=10; y2[3]=10;
            x1[4]=11; x2[4]=3; y1[4]=2; y2[4]=2;
            x1[5]=11; x2[5]=11; y1[5]=6; y2[5]=2;
            x1[6]=4; x2[6]=4; y1[6]=13; y2[6]=7;
            x1[7]=10; x2[7]=10; y1[7]=3; y2[7]=0;
            x1[8]=10; x2[8]=2; y1[8]=3; y2[8]=3;
            x1[9]=5; x2[9]=1; y1[9]=2; y2[9]=2;
            x1[10]=5; x2[10]=5; y1[10]=10; y2[10]=6;
            x1[11]=13; x2[11]=7; y1[11]=8; y2[11]=8;
            x1[12]=12; x2[12]=6; y1[12]=8; y2[12]=8;
        break;
        case 178:
            x1[0]=14; x2[0]=8; y1[0]=11; y2[0]=11;
            x1[1]=10; x2[1]=10; y1[1]=9; y2[1]=3;
            x1[2]=1; x2[2]=1; y1[2]=9; y2[2]=1;
            x1[3]=13; x2[3]=13; y1[3]=14; y2[3]=9;
            x1[4]=0; x2[4]=0; y1[4]=12; y2[4]=9;
            x1[5]=12; x2[5]=12; y1[5]=5; y2[5]=1;
            x1[6]=8; x2[6]=8; y1[6]=8; y2[6]=3;
            x1[7]=0; x2[7]=0; y1[7]=4; y2[7]=0;
            x1[8]=11; x2[8]=10; y1[8]=1; y2[8]=1;
            x1[9]=2; x2[9]=2; y1[9]=13; y2[9]=3;
            x1[10]=14; x2[10]=0; y1[10]=2; y2[10]=2;
            x1[11]=9; x2[11]=3; y1[11]=4; y2[11]=4;
            x1[12]=10; x2[12]=10; y1[12]=2; y2[12]=0;
        break;
        case 179:
            x1[0]=14; x2[0]=14; y1[0]=13; y2[0]=5;
            x1[1]=6; x2[1]=6; y1[1]=3; y2[1]=0;
            x1[2]=6; x2[2]=6; y1[2]=13; y2[2]=5;
            x1[3]=5; x2[3]=5; y1[3]=14; y2[3]=6;
            x1[4]=5; x2[4]=0; y1[4]=8; y2[4]=8;
            x1[5]=12; x2[5]=12; y1[5]=10; y2[5]=4;
            x1[6]=2; x2[6]=2; y1[6]=5; y2[6]=0;
            x1[7]=6; x2[7]=6; y1[7]=4; y2[7]=3;
            x1[8]=12; x2[8]=11; y1[8]=1; y2[8]=1;
            x1[9]=2; x2[9]=2; y1[9]=7; y2[9]=0;
            x1[10]=6; x2[10]=6; y1[10]=9; y2[10]=0;
            x1[11]=14; x2[11]=13; y1[11]=2; y2[11]=2;
            x1[12]=2; x2[12]=1; y1[12]=7; y2[12]=7;
        break;
        case 180:
            x1[0]=13; x2[0]=13; y1[0]=8; y2[0]=3;
            x1[1]=3; x2[1]=3; y1[1]=14; y2[1]=6;
            x1[2]=10; x2[2]=10; y1[2]=5; y2[2]=4;
            x1[3]=13; x2[3]=5; y1[3]=10; y2[3]=10;
            x1[4]=2; x2[4]=2; y1[4]=8; y2[4]=3;
            x1[5]=10; x2[5]=6; y1[5]=10; y2[5]=10;
            x1[6]=12; x2[6]=12; y1[6]=14; y2[6]=8;
            x1[7]=6; x2[7]=6; y1[7]=10; y2[7]=2;
            x1[8]=8; x2[8]=4; y1[8]=0; y2[8]=0;
            x1[9]=10; x2[9]=8; y1[9]=2; y2[9]=2;
            x1[10]=6; x2[10]=5; y1[10]=1; y2[10]=1;
            x1[11]=11; x2[11]=11; y1[11]=11; y2[11]=1;
            x1[12]=7; x2[12]=5; y1[12]=8; y2[12]=8;
        break;
        case 181:
            x1[0]=13; x2[0]=13; y1[0]=11; y2[0]=7;
            x1[1]=13; x2[1]=2; y1[1]=13; y2[1]=13;
            x1[2]=11; x2[2]=11; y1[2]=9; y2[2]=3;
            x1[3]=6; x2[3]=3; y1[3]=2; y2[3]=2;
            x1[4]=9; x2[4]=4; y1[4]=9; y2[4]=9;
            x1[5]=13; x2[5]=7; y1[5]=7; y2[5]=7;
            x1[6]=14; x2[6]=8; y1[6]=9; y2[6]=9;
            x1[7]=9; x2[7]=1; y1[7]=8; y2[7]=8;
            x1[8]=11; x2[8]=11; y1[8]=12; y2[8]=8;
            x1[9]=6; x2[9]=4; y1[9]=1; y2[9]=1;
            x1[10]=14; x2[10]=14; y1[10]=11; y2[10]=7;
            x1[11]=13; x2[11]=4; y1[11]=1; y2[11]=1;
            x1[12]=5; x2[12]=5; y1[12]=12; y2[12]=0;
        break;
        case 182:
            x1[0]=14; x2[0]=6; y1[0]=4; y2[0]=4;
            x1[1]=13; x2[1]=2; y1[1]=12; y2[1]=12;
            x1[2]=13; x2[2]=13; y1[2]=13; y2[2]=3;
            x1[3]=14; x2[3]=0; y1[3]=0; y2[3]=0;
            x1[4]=12; x2[4]=12; y1[4]=12; y2[4]=6;
            x1[5]=10; x2[5]=9; y1[5]=11; y2[5]=11;
            x1[6]=13; x2[6]=13; y1[6]=7; y2[6]=5;
            x1[7]=0; x2[7]=0; y1[7]=8; y2[7]=6;
            x1[8]=13; x2[8]=13; y1[8]=4; y2[8]=2;
            x1[9]=4; x2[9]=4; y1[9]=11; y2[9]=1;
            x1[10]=1; x2[10]=1; y1[10]=11; y2[10]=7;
            x1[11]=13; x2[11]=6; y1[11]=13; y2[11]=13;
            x1[12]=12; x2[12]=10; y1[12]=5; y2[12]=5;
        break;
        case 183:
            x1[0]=13; x2[0]=1; y1[0]=0; y2[0]=0;
            x1[1]=4; x2[1]=4; y1[1]=11; y2[1]=0;
            x1[2]=14; x2[2]=5; y1[2]=3; y2[2]=3;
            x1[3]=9; x2[3]=9; y1[3]=13; y2[3]=9;
            x1[4]=0; x2[4]=0; y1[4]=10; y2[4]=1;
            x1[5]=4; x2[5]=4; y1[5]=13; y2[5]=5;
            x1[6]=12; x2[6]=0; y1[6]=9; y2[6]=9;
            x1[7]=0; x2[7]=0; y1[7]=11; y2[7]=9;
            x1[8]=13; x2[8]=1; y1[8]=5; y2[8]=5;
            x1[9]=0; x2[9]=0; y1[9]=13; y2[9]=2;
            x1[10]=12; x2[10]=10; y1[10]=0; y2[10]=0;
            x1[11]=7; x2[11]=7; y1[11]=7; y2[11]=5;
            x1[12]=4; x2[12]=2; y1[12]=1; y2[12]=1;
        break;
        case 184:
            x1[0]=5; x2[0]=5; y1[0]=14; y2[0]=7;
            x1[1]=6; x2[1]=1; y1[1]=4; y2[1]=4;
            x1[2]=13; x2[2]=6; y1[2]=9; y2[2]=9;
            x1[3]=8; x2[3]=8; y1[3]=9; y2[3]=0;
            x1[4]=5; x2[4]=0; y1[4]=1; y2[4]=1;
            x1[5]=6; x2[5]=5; y1[5]=11; y2[5]=11;
            x1[6]=11; x2[6]=11; y1[6]=13; y2[6]=12;
            x1[7]=3; x2[7]=3; y1[7]=12; y2[7]=3;
            x1[8]=11; x2[8]=0; y1[8]=14; y2[8]=14;
            x1[9]=14; x2[9]=1; y1[9]=2; y2[9]=2;
            x1[10]=13; x2[10]=13; y1[10]=3; y2[10]=0;
            x1[11]=14; x2[11]=3; y1[11]=2; y2[11]=2;
            x1[12]=14; x2[12]=9; y1[12]=9; y2[12]=9;
        break;
        case 185:
            x1[0]=10; x2[0]=5; y1[0]=2; y2[0]=2;
            x1[1]=13; x2[1]=2; y1[1]=3; y2[1]=3;
            x1[2]=7; x2[2]=5; y1[2]=10; y2[2]=10;
            x1[3]=11; x2[3]=1; y1[3]=3; y2[3]=3;
            x1[4]=12; x2[4]=6; y1[4]=5; y2[4]=5;
            x1[5]=6; x2[5]=6; y1[5]=8; y2[5]=7;
            x1[6]=10; x2[6]=6; y1[6]=3; y2[6]=3;
            x1[7]=11; x2[7]=7; y1[7]=10; y2[7]=10;
            x1[8]=3; x2[8]=1; y1[8]=5; y2[8]=5;
            x1[9]=12; x2[9]=12; y1[9]=10; y2[9]=0;
            x1[10]=12; x2[10]=9; y1[10]=12; y2[10]=12;
            x1[11]=10; x2[11]=10; y1[11]=11; y2[11]=3;
            x1[12]=8; x2[12]=8; y1[12]=9; y2[12]=1;
        break;
        case 186:
            x1[0]=12; x2[0]=0; y1[0]=3; y2[0]=3;
            x1[1]=11; x2[1]=11; y1[1]=6; y2[1]=5;
            x1[2]=12; x2[2]=2; y1[2]=6; y2[2]=6;
            x1[3]=5; x2[3]=1; y1[3]=8; y2[3]=8;
            x1[4]=13; x2[4]=6; y1[4]=12; y2[4]=12;
            x1[5]=5; x2[5]=4; y1[5]=12; y2[5]=12;
            x1[6]=8; x2[6]=3; y1[6]=11; y2[6]=11;
            x1[7]=14; x2[7]=7; y1[7]=1; y2[7]=1;
            x1[8]=14; x2[8]=6; y1[8]=13; y2[8]=13;
            x1[9]=10; x2[9]=9; y1[9]=13; y2[9]=13;
            x1[10]=11; x2[10]=4; y1[10]=9; y2[10]=9;
            x1[11]=7; x2[11]=5; y1[11]=14; y2[11]=14;
            x1[12]=3; x2[12]=2; y1[12]=4; y2[12]=4;
        break;
        case 187:
            x1[0]=13; x2[0]=13; y1[0]=11; y2[0]=3;
            x1[1]=8; x2[1]=1; y1[1]=7; y2[1]=7;
            x1[2]=6; x2[2]=0; y1[2]=7; y2[2]=7;
            x1[3]=8; x2[3]=8; y1[3]=11; y2[3]=0;
            x1[4]=7; x2[4]=3; y1[4]=3; y2[4]=3;
            x1[5]=3; x2[5]=3; y1[5]=5; y2[5]=3;
            x1[6]=11; x2[6]=11; y1[6]=14; y2[6]=5;
            x1[7]=11; x2[7]=8; y1[7]=6; y2[7]=6;
            x1[8]=8; x2[8]=7; y1[8]=13; y2[8]=13;
            x1[9]=8; x2[9]=8; y1[9]=11; y2[9]=1;
            x1[10]=8; x2[10]=2; y1[10]=3; y2[10]=3;
            x1[11]=11; x2[11]=4; y1[11]=8; y2[11]=8;
            x1[12]=14; x2[12]=14; y1[12]=13; y2[12]=7;
        break;
        case 188:
            x1[0]=12; x2[0]=5; y1[0]=4; y2[0]=4;
            x1[1]=6; x2[1]=6; y1[1]=11; y2[1]=6;
            x1[2]=6; x2[2]=4; y1[2]=2; y2[2]=2;
            x1[3]=8; x2[3]=3; y1[3]=1; y2[3]=1;
            x1[4]=12; x2[4]=9; y1[4]=6; y2[4]=6;
            x1[5]=13; x2[5]=0; y1[5]=4; y2[5]=4;
            x1[6]=7; x2[6]=7; y1[6]=8; y2[6]=7;
            x1[7]=8; x2[7]=7; y1[7]=8; y2[7]=8;
            x1[8]=14; x2[8]=14; y1[8]=13; y2[8]=6;
            x1[9]=8; x2[9]=8; y1[9]=10; y2[9]=7;
            x1[10]=9; x2[10]=3; y1[10]=7; y2[10]=7;
            x1[11]=11; x2[11]=4; y1[11]=3; y2[11]=3;
            x1[12]=10; x2[12]=10; y1[12]=11; y2[12]=6;
        break;
        case 189:
            x1[0]=7; x2[0]=7; y1[0]=3; y2[0]=1;
            x1[1]=13; x2[1]=12; y1[1]=5; y2[1]=5;
            x1[2]=11; x2[2]=11; y1[2]=8; y2[2]=4;
            x1[3]=1; x2[3]=1; y1[3]=14; y2[3]=0;
            x1[4]=10; x2[4]=0; y1[4]=13; y2[4]=13;
            x1[5]=8; x2[5]=7; y1[5]=10; y2[5]=10;
            x1[6]=11; x2[6]=4; y1[6]=7; y2[6]=7;
            x1[7]=12; x2[7]=1; y1[7]=8; y2[7]=8;
            x1[8]=12; x2[8]=5; y1[8]=10; y2[8]=10;
            x1[9]=9; x2[9]=5; y1[9]=6; y2[9]=6;
            x1[10]=2; x2[10]=0; y1[10]=8; y2[10]=8;
            x1[11]=12; x2[11]=12; y1[11]=13; y2[11]=1;
            x1[12]=6; x2[12]=6; y1[12]=8; y2[12]=5;
        break;
        case 190:
            x1[0]=6; x2[0]=2; y1[0]=6; y2[0]=6;
            x1[1]=5; x2[1]=5; y1[1]=13; y2[1]=11;
            x1[2]=4; x2[2]=4; y1[2]=5; y2[2]=0;
            x1[3]=12; x2[3]=8; y1[3]=4; y2[3]=4;
            x1[4]=4; x2[4]=2; y1[4]=0; y2[4]=0;
            x1[5]=13; x2[5]=12; y1[5]=0; y2[5]=0;
            x1[6]=3; x2[6]=2; y1[6]=3; y2[6]=3;
            x1[7]=3; x2[7]=2; y1[7]=10; y2[7]=10;
            x1[8]=11; x2[8]=9; y1[8]=5; y2[8]=5;
            x1[9]=14; x2[9]=8; y1[9]=5; y2[9]=5;
            x1[10]=14; x2[10]=0; y1[10]=1; y2[10]=1;
            x1[11]=10; x2[11]=10; y1[11]=7; y2[11]=4;
            x1[12]=9; x2[12]=9; y1[12]=14; y2[12]=13;
        break;
        case 191:
            x1[0]=10; x2[0]=5; y1[0]=11; y2[0]=11;
            x1[1]=7; x2[1]=7; y1[1]=6; y2[1]=2;
            x1[2]=1; x2[2]=1; y1[2]=10; y2[2]=6;
            x1[3]=4; x2[3]=1; y1[3]=3; y2[3]=3;
            x1[4]=8; x2[4]=0; y1[4]=7; y2[4]=7;
            x1[5]=11; x2[5]=9; y1[5]=7; y2[5]=7;
            x1[6]=6; x2[6]=6; y1[6]=14; y2[6]=9;
            x1[7]=4; x2[7]=1; y1[7]=1; y2[7]=1;
            x1[8]=0; x2[8]=0; y1[8]=8; y2[8]=1;
            x1[9]=13; x2[9]=8; y1[9]=8; y2[9]=8;
            x1[10]=9; x2[10]=9; y1[10]=6; y2[10]=2;
            x1[11]=7; x2[11]=7; y1[11]=13; y2[11]=2;
            x1[12]=14; x2[12]=2; y1[12]=8; y2[12]=8;
        break;
        case 192:
            x1[0]=14; x2[0]=1; y1[0]=12; y2[0]=12;
            x1[1]=6; x2[1]=0; y1[1]=10; y2[1]=10;
            x1[2]=10; x2[2]=0; y1[2]=5; y2[2]=5;
            x1[3]=14; x2[3]=12; y1[3]=14; y2[3]=14;
            x1[4]=13; x2[4]=0; y1[4]=0; y2[4]=0;
            x1[5]=3; x2[5]=3; y1[5]=11; y2[5]=4;
            x1[6]=12; x2[6]=4; y1[6]=11; y2[6]=11;
            x1[7]=5; x2[7]=5; y1[7]=13; y2[7]=2;
            x1[8]=14; x2[8]=3; y1[8]=5; y2[8]=5;
            x1[9]=12; x2[9]=12; y1[9]=10; y2[9]=9;
            x1[10]=5; x2[10]=2; y1[10]=10; y2[10]=10;
            x1[11]=1; x2[11]=1; y1[11]=6; y2[11]=5;
            x1[12]=8; x2[12]=8; y1[12]=7; y2[12]=4;
        break;
        case 193:
            x1[0]=6; x2[0]=3; y1[0]=4; y2[0]=4;
            x1[1]=6; x2[1]=1; y1[1]=9; y2[1]=9;
            x1[2]=2; x2[2]=2; y1[2]=8; y2[2]=0;
            x1[3]=6; x2[3]=5; y1[3]=8; y2[3]=8;
            x1[4]=2; x2[4]=2; y1[4]=6; y2[4]=3;
            x1[5]=1; x2[5]=0; y1[5]=8; y2[5]=8;
            x1[6]=12; x2[6]=0; y1[6]=11; y2[6]=11;
            x1[7]=12; x2[7]=12; y1[7]=8; y2[7]=3;
            x1[8]=10; x2[8]=10; y1[8]=12; y2[8]=10;
            x1[9]=13; x2[9]=9; y1[9]=11; y2[9]=11;
            x1[10]=4; x2[10]=3; y1[10]=7; y2[10]=7;
            x1[11]=14; x2[11]=14; y1[11]=12; y2[11]=0;
            x1[12]=7; x2[12]=7; y1[12]=12; y2[12]=6;
        break;
        case 194:
            x1[0]=12; x2[0]=12; y1[0]=12; y2[0]=0;
            x1[1]=12; x2[1]=12; y1[1]=14; y2[1]=6;
            x1[2]=4; x2[2]=4; y1[2]=13; y2[2]=1;
            x1[3]=4; x2[3]=4; y1[3]=11; y2[3]=2;
            x1[4]=11; x2[4]=11; y1[4]=1; y2[4]=0;
            x1[5]=6; x2[5]=6; y1[5]=7; y2[5]=1;
            x1[6]=12; x2[6]=6; y1[6]=0; y2[6]=0;
            x1[7]=5; x2[7]=5; y1[7]=7; y2[7]=6;
            x1[8]=2; x2[8]=1; y1[8]=12; y2[8]=12;
            x1[9]=7; x2[9]=5; y1[9]=3; y2[9]=3;
            x1[10]=4; x2[10]=0; y1[10]=8; y2[10]=8;
            x1[11]=10; x2[11]=3; y1[11]=13; y2[11]=13;
            x1[12]=2; x2[12]=2; y1[12]=6; y2[12]=2;
        break;
        case 195:
            x1[0]=14; x2[0]=10; y1[0]=6; y2[0]=6;
            x1[1]=7; x2[1]=6; y1[1]=5; y2[1]=5;
            x1[2]=4; x2[2]=3; y1[2]=3; y2[2]=3;
            x1[3]=14; x2[3]=8; y1[3]=4; y2[3]=4;
            x1[4]=14; x2[4]=1; y1[4]=4; y2[4]=4;
            x1[5]=11; x2[5]=10; y1[5]=2; y2[5]=2;
            x1[6]=7; x2[6]=7; y1[6]=13; y2[6]=8;
            x1[7]=6; x2[7]=6; y1[7]=12; y2[7]=9;
            x1[8]=13; x2[8]=0; y1[8]=5; y2[8]=5;
            x1[9]=12; x2[9]=12; y1[9]=12; y2[9]=11;
            x1[10]=12; x2[10]=12; y1[10]=12; y2[10]=7;
            x1[11]=7; x2[11]=1; y1[11]=3; y2[11]=3;
            x1[12]=9; x2[12]=3; y1[12]=9; y2[12]=9;
        break;
        case 196:
            x1[0]=12; x2[0]=6; y1[0]=13; y2[0]=13;
            x1[1]=13; x2[1]=8; y1[1]=4; y2[1]=4;
            x1[2]=3; x2[2]=0; y1[2]=7; y2[2]=7;
            x1[3]=3; x2[3]=3; y1[3]=3; y2[3]=2;
            x1[4]=7; x2[4]=5; y1[4]=6; y2[4]=6;
            x1[5]=11; x2[5]=6; y1[5]=12; y2[5]=12;
            x1[6]=12; x2[6]=1; y1[6]=13; y2[6]=13;
            x1[7]=13; x2[7]=10; y1[7]=4; y2[7]=4;
            x1[8]=9; x2[8]=1; y1[8]=5; y2[8]=5;
            x1[9]=12; x2[9]=3; y1[9]=1; y2[9]=1;
            x1[10]=0; x2[10]=0; y1[10]=3; y2[10]=0;
            x1[11]=11; x2[11]=11; y1[11]=5; y2[11]=2;
            x1[12]=12; x2[12]=12; y1[12]=13; y2[12]=4;
        break;
        case 197:
            x1[0]=2; x2[0]=0; y1[0]=6; y2[0]=6;
            x1[1]=14; x2[1]=14; y1[1]=11; y2[1]=2;
            x1[2]=6; x2[2]=6; y1[2]=9; y2[2]=5;
            x1[3]=3; x2[3]=2; y1[3]=14; y2[3]=14;
            x1[4]=12; x2[4]=12; y1[4]=14; y2[4]=4;
            x1[5]=4; x2[5]=0; y1[5]=5; y2[5]=5;
            x1[6]=13; x2[6]=13; y1[6]=12; y2[6]=6;
            x1[7]=12; x2[7]=4; y1[7]=4; y2[7]=4;
            x1[8]=0; x2[8]=0; y1[8]=10; y2[8]=5;
            x1[9]=9; x2[9]=6; y1[9]=10; y2[9]=10;
            x1[10]=12; x2[10]=12; y1[10]=13; y2[10]=7;
            x1[11]=7; x2[11]=7; y1[11]=3; y2[11]=0;
            x1[12]=6; x2[12]=0; y1[12]=1; y2[12]=1;
        break;
        case 198:
            x1[0]=10; x2[0]=0; y1[0]=12; y2[0]=12;
            x1[1]=9; x2[1]=5; y1[1]=13; y2[1]=13;
            x1[2]=12; x2[2]=2; y1[2]=3; y2[2]=3;
            x1[3]=12; x2[3]=4; y1[3]=7; y2[3]=7;
            x1[4]=6; x2[4]=4; y1[4]=9; y2[4]=9;
            x1[5]=14; x2[5]=5; y1[5]=2; y2[5]=2;
            x1[6]=14; x2[6]=3; y1[6]=11; y2[6]=11;
            x1[7]=10; x2[7]=10; y1[7]=12; y2[7]=7;
            x1[8]=1; x2[8]=1; y1[8]=6; y2[8]=2;
            x1[9]=0; x2[9]=0; y1[9]=12; y2[9]=1;
            x1[10]=6; x2[10]=6; y1[10]=11; y2[10]=1;
            x1[11]=1; x2[11]=1; y1[11]=13; y2[11]=6;
            x1[12]=11; x2[12]=7; y1[12]=3; y2[12]=3;
        break;
        case 199:
            x1[0]=0; x2[0]=0; y1[0]=10; y2[0]=6;
            x1[1]=7; x2[1]=3; y1[1]=5; y2[1]=5;
            x1[2]=3; x2[2]=0; y1[2]=6; y2[2]=6;
            x1[3]=3; x2[3]=2; y1[3]=0; y2[3]=0;
            x1[4]=0; x2[4]=0; y1[4]=14; y2[4]=3;
            x1[5]=12; x2[5]=2; y1[5]=11; y2[5]=11;
            x1[6]=10; x2[6]=6; y1[6]=6; y2[6]=6;
            x1[7]=14; x2[7]=13; y1[7]=4; y2[7]=4;
            x1[8]=11; x2[8]=1; y1[8]=1; y2[8]=1;
            x1[9]=7; x2[9]=7; y1[9]=6; y2[9]=0;
            x1[10]=13; x2[10]=11; y1[10]=5; y2[10]=5;
            x1[11]=6; x2[11]=6; y1[11]=8; y2[11]=2;
            x1[12]=12; x2[12]=7; y1[12]=6; y2[12]=6;
        break;
        case 200:
            x1[0]=10; x2[0]=10; y1[0]=2; y2[0]=1;
            x1[1]=7; x2[1]=2; y1[1]=10; y2[1]=10;
            x1[2]=13; x2[2]=7; y1[2]=10; y2[2]=10;
            x1[3]=1; x2[3]=1; y1[3]=3; y2[3]=2;
            x1[4]=10; x2[4]=8; y1[4]=11; y2[4]=11;
            x1[5]=13; x2[5]=6; y1[5]=10; y2[5]=10;
            x1[6]=12; x2[6]=12; y1[6]=12; y2[6]=2;
            x1[7]=13; x2[7]=13; y1[7]=8; y2[7]=5;
            x1[8]=13; x2[8]=13; y1[8]=11; y2[8]=2;
            x1[9]=14; x2[9]=11; y1[9]=1; y2[9]=1;
            x1[10]=12; x2[10]=5; y1[10]=9; y2[10]=9;
            x1[11]=14; x2[11]=8; y1[11]=10; y2[11]=10;
            x1[12]=2; x2[12]=2; y1[12]=12; y2[12]=6;
        break;
        case 201:
            x1[0]=13; x2[0]=7; y1[0]=12; y2[0]=12;
            x1[1]=4; x2[1]=2; y1[1]=6; y2[1]=6;
            x1[2]=2; x2[2]=2; y1[2]=9; y2[2]=2;
            x1[3]=11; x2[3]=1; y1[3]=9; y2[3]=9;
            x1[4]=12; x2[4]=12; y1[4]=13; y2[4]=5;
            x1[5]=10; x2[5]=10; y1[5]=4; y2[5]=3;
            x1[6]=11; x2[6]=11; y1[6]=8; y2[6]=1;
            x1[7]=7; x2[7]=6; y1[7]=3; y2[7]=3;
            x1[8]=4; x2[8]=1; y1[8]=13; y2[8]=13;
            x1[9]=7; x2[9]=3; y1[9]=13; y2[9]=13;
            x1[10]=3; x2[10]=3; y1[10]=5; y2[10]=1;
            x1[11]=14; x2[11]=1; y1[11]=9; y2[11]=9;
            x1[12]=7; x2[12]=2; y1[12]=13; y2[12]=13;
        break;
        case 202:
            x1[0]=1; x2[0]=1; y1[0]=8; y2[0]=0;
            x1[1]=12; x2[1]=7; y1[1]=10; y2[1]=10;
            x1[2]=0; x2[2]=0; y1[2]=2; y2[2]=1;
            x1[3]=2; x2[3]=2; y1[3]=14; y2[3]=12;
            x1[4]=10; x2[4]=10; y1[4]=13; y2[4]=11;
            x1[5]=2; x2[5]=2; y1[5]=10; y2[5]=6;
            x1[6]=3; x2[6]=3; y1[6]=4; y2[6]=0;
            x1[7]=13; x2[7]=7; y1[7]=3; y2[7]=3;
            x1[8]=13; x2[8]=8; y1[8]=7; y2[8]=7;
            x1[9]=14; x2[9]=14; y1[9]=7; y2[9]=6;
            x1[10]=14; x2[10]=5; y1[10]=5; y2[10]=5;
            x1[11]=6; x2[11]=1; y1[11]=13; y2[11]=13;
            x1[12]=12; x2[12]=7; y1[12]=2; y2[12]=2;
        break;
        case 203:
            x1[0]=11; x2[0]=7; y1[0]=14; y2[0]=14;
            x1[1]=6; x2[1]=6; y1[1]=9; y2[1]=6;
            x1[2]=12; x2[2]=9; y1[2]=9; y2[2]=9;
            x1[3]=14; x2[3]=8; y1[3]=7; y2[3]=7;
            x1[4]=13; x2[4]=4; y1[4]=5; y2[4]=5;
            x1[5]=9; x2[5]=9; y1[5]=6; y2[5]=4;
            x1[6]=10; x2[6]=7; y1[6]=5; y2[6]=5;
            x1[7]=7; x2[7]=7; y1[7]=7; y2[7]=4;
            x1[8]=12; x2[8]=7; y1[8]=11; y2[8]=11;
            x1[9]=13; x2[9]=3; y1[9]=14; y2[9]=14;
            x1[10]=12; x2[10]=4; y1[10]=2; y2[10]=2;
            x1[11]=13; x2[11]=13; y1[11]=7; y2[11]=3;
            x1[12]=11; x2[12]=11; y1[12]=8; y2[12]=6;
        break;
        case 204:
            x1[0]=12; x2[0]=4; y1[0]=9; y2[0]=9;
            x1[1]=11; x2[1]=11; y1[1]=4; y2[1]=1;
            x1[2]=14; x2[2]=7; y1[2]=2; y2[2]=2;
            x1[3]=14; x2[3]=0; y1[3]=14; y2[3]=14;
            x1[4]=8; x2[4]=8; y1[4]=3; y2[4]=0;
            x1[5]=6; x2[5]=6; y1[5]=12; y2[5]=0;
            x1[6]=6; x2[6]=6; y1[6]=12; y2[6]=11;
            x1[7]=13; x2[7]=9; y1[7]=3; y2[7]=3;
            x1[8]=8; x2[8]=8; y1[8]=5; y2[8]=3;
            x1[9]=1; x2[9]=1; y1[9]=7; y2[9]=2;
            x1[10]=3; x2[10]=3; y1[10]=13; y2[10]=0;
            x1[11]=11; x2[11]=10; y1[11]=10; y2[11]=10;
            x1[12]=9; x2[12]=0; y1[12]=10; y2[12]=10;
        break;
        case 205:
            x1[0]=14; x2[0]=7; y1[0]=6; y2[0]=6;
            x1[1]=3; x2[1]=0; y1[1]=0; y2[1]=0;
            x1[2]=14; x2[2]=6; y1[2]=5; y2[2]=5;
            x1[3]=11; x2[3]=11; y1[3]=10; y2[3]=7;
            x1[4]=12; x2[4]=3; y1[4]=7; y2[4]=7;
            x1[5]=14; x2[5]=8; y1[5]=14; y2[5]=14;
            x1[6]=6; x2[6]=6; y1[6]=12; y2[6]=8;
            x1[7]=12; x2[7]=12; y1[7]=7; y2[7]=6;
            x1[8]=11; x2[8]=3; y1[8]=9; y2[8]=9;
            x1[9]=13; x2[9]=0; y1[9]=12; y2[9]=12;
            x1[10]=3; x2[10]=3; y1[10]=6; y2[10]=0;
            x1[11]=13; x2[11]=1; y1[11]=8; y2[11]=8;
            x1[12]=7; x2[12]=5; y1[12]=0; y2[12]=0;
        break;
        case 206:
            x1[0]=1; x2[0]=1; y1[0]=12; y2[0]=1;
            x1[1]=1; x2[1]=0; y1[1]=7; y2[1]=7;
            x1[2]=11; x2[2]=8; y1[2]=13; y2[2]=13;
            x1[3]=2; x2[3]=1; y1[3]=5; y2[3]=5;
            x1[4]=14; x2[4]=14; y1[4]=12; y2[4]=10;
            x1[5]=14; x2[5]=3; y1[5]=6; y2[5]=6;
            x1[6]=7; x2[6]=7; y1[6]=11; y2[6]=1;
            x1[7]=9; x2[7]=5; y1[7]=14; y2[7]=14;
            x1[8]=14; x2[8]=14; y1[8]=4; y2[8]=1;
            x1[9]=11; x2[9]=11; y1[9]=7; y2[9]=5;
            x1[10]=3; x2[10]=3; y1[10]=6; y2[10]=1;
            x1[11]=0; x2[11]=0; y1[11]=9; y2[11]=6;
            x1[12]=9; x2[12]=9; y1[12]=8; y2[12]=2;
        break;
        case 207:
            x1[0]=8; x2[0]=6; y1[0]=5; y2[0]=5;
            x1[1]=13; x2[1]=13; y1[1]=13; y2[1]=5;
            x1[2]=1; x2[2]=1; y1[2]=12; y2[2]=7;
            x1[3]=13; x2[3]=3; y1[3]=2; y2[3]=2;
            x1[4]=3; x2[4]=3; y1[4]=14; y2[4]=11;
            x1[5]=14; x2[5]=12; y1[5]=0; y2[5]=0;
            x1[6]=2; x2[6]=2; y1[6]=3; y2[6]=2;
            x1[7]=10; x2[7]=2; y1[7]=11; y2[7]=11;
            x1[8]=0; x2[8]=0; y1[8]=13; y2[8]=6;
            x1[9]=9; x2[9]=9; y1[9]=14; y2[9]=7;
            x1[10]=2; x2[10]=2; y1[10]=12; y2[10]=10;
            x1[11]=3; x2[11]=3; y1[11]=7; y2[11]=2;
            x1[12]=9; x2[12]=7; y1[12]=6; y2[12]=6;
        break;
        case 208:
            x1[0]=14; x2[0]=4; y1[0]=0; y2[0]=0;
            x1[1]=14; x2[1]=12; y1[1]=3; y2[1]=3;
            x1[2]=1; x2[2]=1; y1[2]=12; y2[2]=5;
            x1[3]=0; x2[3]=0; y1[3]=5; y2[3]=0;
            x1[4]=13; x2[4]=13; y1[4]=2; y2[4]=1;
            x1[5]=4; x2[5]=4; y1[5]=10; y2[5]=2;
            x1[6]=14; x2[6]=14; y1[6]=4; y2[6]=0;
            x1[7]=13; x2[7]=13; y1[7]=12; y2[7]=4;
            x1[8]=8; x2[8]=8; y1[8]=11; y2[8]=3;
            x1[9]=4; x2[9]=0; y1[9]=1; y2[9]=1;
            x1[10]=10; x2[10]=10; y1[10]=6; y2[10]=4;
            x1[11]=6; x2[11]=4; y1[11]=6; y2[11]=6;
            x1[12]=5; x2[12]=3; y1[12]=1; y2[12]=1;
        break;
        case 209:
            x1[0]=11; x2[0]=4; y1[0]=11; y2[0]=11;
            x1[1]=13; x2[1]=7; y1[1]=9; y2[1]=9;
            x1[2]=3; x2[2]=3; y1[2]=10; y2[2]=5;
            x1[3]=3; x2[3]=3; y1[3]=9; y2[3]=8;
            x1[4]=0; x2[4]=0; y1[4]=9; y2[4]=5;
            x1[5]=13; x2[5]=13; y1[5]=4; y2[5]=0;
            x1[6]=12; x2[6]=8; y1[6]=8; y2[6]=8;
            x1[7]=12; x2[7]=12; y1[7]=11; y2[7]=9;
            x1[8]=1; x2[8]=1; y1[8]=14; y2[8]=13;
            x1[9]=9; x2[9]=8; y1[9]=1; y2[9]=1;
            x1[10]=10; x2[10]=9; y1[10]=7; y2[10]=7;
            x1[11]=5; x2[11]=5; y1[11]=4; y2[11]=0;
            x1[12]=5; x2[12]=4; y1[12]=5; y2[12]=5;
        break;
        case 210:
            x1[0]=11; x2[0]=1; y1[0]=2; y2[0]=2;
            x1[1]=7; x2[1]=7; y1[1]=2; y2[1]=0;
            x1[2]=3; x2[2]=3; y1[2]=10; y2[2]=6;
            x1[3]=7; x2[3]=7; y1[3]=12; y2[3]=3;
            x1[4]=0; x2[4]=0; y1[4]=14; y2[4]=7;
            x1[5]=13; x2[5]=13; y1[5]=14; y2[5]=2;
            x1[6]=7; x2[6]=7; y1[6]=5; y2[6]=2;
            x1[7]=13; x2[7]=3; y1[7]=11; y2[7]=11;
            x1[8]=7; x2[8]=7; y1[8]=14; y2[8]=12;
            x1[9]=12; x2[9]=12; y1[9]=9; y2[9]=7;
            x1[10]=10; x2[10]=10; y1[10]=6; y2[10]=1;
            x1[11]=4; x2[11]=4; y1[11]=12; y2[11]=4;
            x1[12]=9; x2[12]=9; y1[12]=2; y2[12]=1;
        break;
        case 211:
            x1[0]=12; x2[0]=8; y1[0]=12; y2[0]=12;
            x1[1]=13; x2[1]=13; y1[1]=12; y2[1]=10;
            x1[2]=7; x2[2]=3; y1[2]=8; y2[2]=8;
            x1[3]=13; x2[3]=13; y1[3]=6; y2[3]=5;
            x1[4]=9; x2[4]=1; y1[4]=1; y2[4]=1;
            x1[5]=13; x2[5]=13; y1[5]=12; y2[5]=9;
            x1[6]=11; x2[6]=11; y1[6]=9; y2[6]=7;
            x1[7]=11; x2[7]=4; y1[7]=5; y2[7]=5;
            x1[8]=6; x2[8]=6; y1[8]=14; y2[8]=7;
            x1[9]=5; x2[9]=5; y1[9]=13; y2[9]=3;
            x1[10]=6; x2[10]=5; y1[10]=5; y2[10]=5;
            x1[11]=12; x2[11]=12; y1[11]=8; y2[11]=0;
            x1[12]=8; x2[12]=8; y1[12]=8; y2[12]=6;
        break;
        case 212:
            x1[0]=0; x2[0]=0; y1[0]=11; y2[0]=3;
            x1[1]=13; x2[1]=2; y1[1]=7; y2[1]=7;
            x1[2]=14; x2[2]=4; y1[2]=9; y2[2]=9;
            x1[3]=9; x2[3]=2; y1[3]=13; y2[3]=13;
            x1[4]=14; x2[4]=14; y1[4]=8; y2[4]=0;
            x1[5]=11; x2[5]=6; y1[5]=4; y2[5]=4;
            x1[6]=3; x2[6]=3; y1[6]=1; y2[6]=0;
            x1[7]=9; x2[7]=9; y1[7]=11; y2[7]=1;
            x1[8]=3; x2[8]=3; y1[8]=10; y2[8]=1;
            x1[9]=14; x2[9]=1; y1[9]=6; y2[9]=6;
            x1[10]=13; x2[10]=13; y1[10]=14; y2[10]=4;
            x1[11]=11; x2[11]=10; y1[11]=5; y2[11]=5;
            x1[12]=7; x2[12]=7; y1[12]=9; y2[12]=7;
        break;
        case 213:
            x1[0]=2; x2[0]=2; y1[0]=10; y2[0]=8;
            x1[1]=6; x2[1]=3; y1[1]=11; y2[1]=11;
            x1[2]=2; x2[2]=0; y1[2]=7; y2[2]=7;
            x1[3]=6; x2[3]=6; y1[3]=14; y2[3]=5;
            x1[4]=14; x2[4]=10; y1[4]=5; y2[4]=5;
            x1[5]=12; x2[5]=0; y1[5]=12; y2[5]=12;
            x1[6]=6; x2[6]=4; y1[6]=5; y2[6]=5;
            x1[7]=12; x2[7]=0; y1[7]=8; y2[7]=8;
            x1[8]=10; x2[8]=10; y1[8]=11; y2[8]=7;
            x1[9]=10; x2[9]=10; y1[9]=10; y2[9]=9;
            x1[10]=10; x2[10]=6; y1[10]=7; y2[10]=7;
            x1[11]=9; x2[11]=4; y1[11]=4; y2[11]=4;
            x1[12]=5; x2[12]=4; y1[12]=2; y2[12]=2;
        break;
        case 214:
            x1[0]=14; x2[0]=12; y1[0]=5; y2[0]=5;
            x1[1]=4; x2[1]=4; y1[1]=11; y2[1]=5;
            x1[2]=4; x2[2]=4; y1[2]=9; y2[2]=5;
            x1[3]=11; x2[3]=11; y1[3]=7; y2[3]=0;
            x1[4]=8; x2[4]=4; y1[4]=3; y2[4]=3;
            x1[5]=5; x2[5]=5; y1[5]=14; y2[5]=3;
            x1[6]=14; x2[6]=14; y1[6]=7; y2[6]=1;
            x1[7]=7; x2[7]=0; y1[7]=12; y2[7]=12;
            x1[8]=9; x2[8]=0; y1[8]=7; y2[8]=7;
            x1[9]=11; x2[9]=11; y1[9]=8; y2[9]=3;
            x1[10]=9; x2[10]=0; y1[10]=6; y2[10]=6;
            x1[11]=12; x2[11]=1; y1[11]=14; y2[11]=14;
            x1[12]=10; x2[12]=10; y1[12]=12; y2[12]=9;
        break;
        case 215:
            x1[0]=13; x2[0]=13; y1[0]=9; y2[0]=7;
            x1[1]=12; x2[1]=2; y1[1]=5; y2[1]=5;
            x1[2]=6; x2[2]=3; y1[2]=5; y2[2]=5;
            x1[3]=3; x2[3]=3; y1[3]=14; y2[3]=9;
            x1[4]=8; x2[4]=8; y1[4]=11; y2[4]=6;
            x1[5]=7; x2[5]=0; y1[5]=9; y2[5]=9;
            x1[6]=9; x2[6]=9; y1[6]=14; y2[6]=10;
            x1[7]=12; x2[7]=12; y1[7]=11; y2[7]=5;
            x1[8]=10; x2[8]=10; y1[8]=6; y2[8]=3;
            x1[9]=10; x2[9]=10; y1[9]=4; y2[9]=2;
            x1[10]=5; x2[10]=1; y1[10]=0; y2[10]=0;
            x1[11]=4; x2[11]=4; y1[11]=12; y2[11]=9;
            x1[12]=9; x2[12]=9; y1[12]=8; y2[12]=3;
        break;
        case 216:
            x1[0]=14; x2[0]=14; y1[0]=3; y2[0]=0;
            x1[1]=10; x2[1]=2; y1[1]=13; y2[1]=13;
            x1[2]=4; x2[2]=4; y1[2]=7; y2[2]=1;
            x1[3]=8; x2[3]=8; y1[3]=12; y2[3]=6;
            x1[4]=3; x2[4]=3; y1[4]=4; y2[4]=2;
            x1[5]=8; x2[5]=8; y1[5]=8; y2[5]=5;
            x1[6]=6; x2[6]=0; y1[6]=9; y2[6]=9;
            x1[7]=14; x2[7]=9; y1[7]=5; y2[7]=5;
            x1[8]=5; x2[8]=3; y1[8]=14; y2[8]=14;
            x1[9]=6; x2[9]=6; y1[9]=13; y2[9]=9;
            x1[10]=1; x2[10]=1; y1[10]=10; y2[10]=2;
            x1[11]=4; x2[11]=4; y1[11]=11; y2[11]=8;
            x1[12]=10; x2[12]=5; y1[12]=5; y2[12]=5;
        break;
        case 217:
            x1[0]=12; x2[0]=7; y1[0]=5; y2[0]=5;
            x1[1]=4; x2[1]=4; y1[1]=10; y2[1]=8;
            x1[2]=9; x2[2]=9; y1[2]=13; y2[2]=3;
            x1[3]=14; x2[3]=13; y1[3]=13; y2[3]=13;
            x1[4]=0; x2[4]=0; y1[4]=3; y2[4]=2;
            x1[5]=10; x2[5]=8; y1[5]=12; y2[5]=12;
            x1[6]=7; x2[6]=7; y1[6]=14; y2[6]=13;
            x1[7]=13; x2[7]=13; y1[7]=14; y2[7]=8;
            x1[8]=13; x2[8]=4; y1[8]=7; y2[8]=7;
            x1[9]=9; x2[9]=4; y1[9]=5; y2[9]=5;
            x1[10]=6; x2[10]=0; y1[10]=5; y2[10]=5;
            x1[11]=7; x2[11]=1; y1[11]=9; y2[11]=9;
            x1[12]=0; x2[12]=0; y1[12]=13; y2[12]=7;
        break;
        case 218:
            x1[0]=14; x2[0]=14; y1[0]=5; y2[0]=3;
            x1[1]=8; x2[1]=8; y1[1]=11; y2[1]=8;
            x1[2]=6; x2[2]=3; y1[2]=3; y2[2]=3;
            x1[3]=14; x2[3]=13; y1[3]=10; y2[3]=10;
            x1[4]=7; x2[4]=1; y1[4]=7; y2[4]=7;
            x1[5]=6; x2[5]=2; y1[5]=0; y2[5]=0;
            x1[6]=10; x2[6]=4; y1[6]=0; y2[6]=0;
            x1[7]=13; x2[7]=3; y1[7]=8; y2[7]=8;
            x1[8]=12; x2[8]=11; y1[8]=4; y2[8]=4;
            x1[9]=8; x2[9]=0; y1[9]=6; y2[9]=6;
            x1[10]=11; x2[10]=0; y1[10]=8; y2[10]=8;
            x1[11]=10; x2[11]=10; y1[11]=9; y2[11]=2;
            x1[12]=8; x2[12]=6; y1[12]=6; y2[12]=6;
        break;
        case 219:
            x1[0]=2; x2[0]=2; y1[0]=10; y2[0]=2;
            x1[1]=1; x2[1]=1; y1[1]=6; y2[1]=0;
            x1[2]=5; x2[2]=5; y1[2]=13; y2[2]=1;
            x1[3]=12; x2[3]=5; y1[3]=2; y2[3]=2;
            x1[4]=7; x2[4]=7; y1[4]=14; y2[4]=7;
            x1[5]=13; x2[5]=11; y1[5]=12; y2[5]=12;
            x1[6]=8; x2[6]=5; y1[6]=4; y2[6]=4;
            x1[7]=1; x2[7]=1; y1[7]=11; y2[7]=9;
            x1[8]=7; x2[8]=7; y1[8]=10; y2[8]=0;
            x1[9]=7; x2[9]=4; y1[9]=2; y2[9]=2;
            x1[10]=4; x2[10]=4; y1[10]=11; y2[10]=7;
            x1[11]=12; x2[11]=2; y1[11]=10; y2[11]=10;
            x1[12]=14; x2[12]=14; y1[12]=12; y2[12]=5;
        break;
        case 220:
            x1[0]=14; x2[0]=0; y1[0]=9; y2[0]=9;
            x1[1]=13; x2[1]=10; y1[1]=12; y2[1]=12;
            x1[2]=1; x2[2]=1; y1[2]=1; y2[2]=0;
            x1[3]=3; x2[3]=1; y1[3]=11; y2[3]=11;
            x1[4]=12; x2[4]=12; y1[4]=14; y2[4]=5;
            x1[5]=5; x2[5]=3; y1[5]=0; y2[5]=0;
            x1[6]=7; x2[6]=7; y1[6]=5; y2[6]=3;
            x1[7]=8; x2[7]=8; y1[7]=8; y2[7]=2;
            x1[8]=6; x2[8]=4; y1[8]=10; y2[8]=10;
            x1[9]=11; x2[9]=11; y1[9]=13; y2[9]=3;
            x1[10]=12; x2[10]=11; y1[10]=11; y2[10]=11;
            x1[11]=10; x2[11]=2; y1[11]=8; y2[11]=8;
            x1[12]=11; x2[12]=11; y1[12]=12; y2[12]=2;
        break;
        case 221:
            x1[0]=10; x2[0]=3; y1[0]=3; y2[0]=3;
            x1[1]=3; x2[1]=3; y1[1]=14; y2[1]=13;
            x1[2]=7; x2[2]=6; y1[2]=1; y2[2]=1;
            x1[3]=10; x2[3]=10; y1[3]=14; y2[3]=1;
            x1[4]=10; x2[4]=8; y1[4]=10; y2[4]=10;
            x1[5]=2; x2[5]=2; y1[5]=9; y2[5]=8;
            x1[6]=1; x2[6]=0; y1[6]=3; y2[6]=3;
            x1[7]=4; x2[7]=0; y1[7]=10; y2[7]=10;
            x1[8]=12; x2[8]=4; y1[8]=10; y2[8]=10;
            x1[9]=10; x2[9]=10; y1[9]=11; y2[9]=8;
            x1[10]=9; x2[10]=2; y1[10]=14; y2[10]=14;
            x1[11]=14; x2[11]=2; y1[11]=9; y2[11]=9;
            x1[12]=11; x2[12]=6; y1[12]=0; y2[12]=0;
        break;
        case 222:
            x1[0]=12; x2[0]=12; y1[0]=9; y2[0]=0;
            x1[1]=4; x2[1]=4; y1[1]=6; y2[1]=2;
            x1[2]=11; x2[2]=0; y1[2]=4; y2[2]=4;
            x1[3]=11; x2[3]=11; y1[3]=12; y2[3]=0;
            x1[4]=14; x2[4]=3; y1[4]=8; y2[4]=8;
            x1[5]=5; x2[5]=4; y1[5]=3; y2[5]=3;
            x1[6]=14; x2[6]=14; y1[6]=14; y2[6]=1;
            x1[7]=10; x2[7]=10; y1[7]=6; y2[7]=0;
            x1[8]=9; x2[8]=9; y1[8]=11; y2[8]=5;
            x1[9]=13; x2[9]=1; y1[9]=3; y2[9]=3;
            x1[10]=4; x2[10]=4; y1[10]=11; y2[10]=6;
            x1[11]=12; x2[11]=4; y1[11]=6; y2[11]=6;
            x1[12]=13; x2[12]=13; y1[12]=14; y2[12]=5;
        break;
        case 223:
            x1[0]=10; x2[0]=5; y1[0]=6; y2[0]=6;
            x1[1]=3; x2[1]=3; y1[1]=8; y2[1]=7;
            x1[2]=13; x2[2]=13; y1[2]=10; y2[2]=7;
            x1[3]=9; x2[3]=9; y1[3]=5; y2[3]=3;
            x1[4]=8; x2[4]=2; y1[4]=2; y2[4]=2;
            x1[5]=8; x2[5]=2; y1[5]=7; y2[5]=7;
            x1[6]=10; x2[6]=10; y1[6]=10; y2[6]=1;
            x1[7]=11; x2[7]=2; y1[7]=0; y2[7]=0;
            x1[8]=1; x2[8]=1; y1[8]=14; y2[8]=3;
            x1[9]=7; x2[9]=7; y1[9]=14; y2[9]=8;
            x1[10]=3; x2[10]=3; y1[10]=14; y2[10]=12;
            x1[11]=13; x2[11]=13; y1[11]=7; y2[11]=1;
            x1[12]=11; x2[12]=10; y1[12]=3; y2[12]=3;
        break;
        case 224:
            x1[0]=8; x2[0]=0; y1[0]=9; y2[0]=9;
            x1[1]=3; x2[1]=3; y1[1]=8; y2[1]=0;
            x1[2]=13; x2[2]=6; y1[2]=11; y2[2]=11;
            x1[3]=10; x2[3]=2; y1[3]=9; y2[3]=9;
            x1[4]=10; x2[4]=7; y1[4]=14; y2[4]=14;
            x1[5]=14; x2[5]=5; y1[5]=6; y2[5]=6;
            x1[6]=13; x2[6]=8; y1[6]=14; y2[6]=14;
            x1[7]=0; x2[7]=0; y1[7]=8; y2[7]=0;
            x1[8]=13; x2[8]=9; y1[8]=13; y2[8]=13;
            x1[9]=14; x2[9]=14; y1[9]=14; y2[9]=11;
            x1[10]=12; x2[10]=4; y1[10]=14; y2[10]=14;
            x1[11]=14; x2[11]=3; y1[11]=10; y2[11]=10;
            x1[12]=14; x2[12]=12; y1[12]=10; y2[12]=10;
        break;
        case 225:
            x1[0]=5; x2[0]=5; y1[0]=10; y2[0]=2;
            x1[1]=9; x2[1]=9; y1[1]=4; y2[1]=0;
            x1[2]=12; x2[2]=10; y1[2]=4; y2[2]=4;
            x1[3]=9; x2[3]=9; y1[3]=9; y2[3]=6;
            x1[4]=13; x2[4]=0; y1[4]=3; y2[4]=3;
            x1[5]=8; x2[5]=0; y1[5]=10; y2[5]=10;
            x1[6]=5; x2[6]=4; y1[6]=4; y2[6]=4;
            x1[7]=14; x2[7]=8; y1[7]=0; y2[7]=0;
            x1[8]=3; x2[8]=1; y1[8]=7; y2[8]=7;
            x1[9]=9; x2[9]=9; y1[9]=12; y2[9]=8;
            x1[10]=11; x2[10]=8; y1[10]=7; y2[10]=7;
            x1[11]=9; x2[11]=8; y1[11]=0; y2[11]=0;
            x1[12]=6; x2[12]=5; y1[12]=10; y2[12]=10;
        break;
        case 226:
            x1[0]=14; x2[0]=4; y1[0]=10; y2[0]=10;
            x1[1]=7; x2[1]=7; y1[1]=14; y2[1]=6;
            x1[2]=14; x2[2]=9; y1[2]=8; y2[2]=8;
            x1[3]=1; x2[3]=1; y1[3]=13; y2[3]=11;
            x1[4]=8; x2[4]=8; y1[4]=4; y2[4]=2;
            x1[5]=11; x2[5]=8; y1[5]=9; y2[5]=9;
            x1[6]=4; x2[6]=2; y1[6]=3; y2[6]=3;
            x1[7]=14; x2[7]=6; y1[7]=1; y2[7]=1;
            x1[8]=7; x2[8]=7; y1[8]=7; y2[8]=1;
            x1[9]=10; x2[9]=10; y1[9]=10; y2[9]=4;
            x1[10]=5; x2[10]=4; y1[10]=13; y2[10]=13;
            x1[11]=7; x2[11]=7; y1[11]=13; y2[11]=4;
            x1[12]=13; x2[12]=9; y1[12]=2; y2[12]=2;
        break;
        case 227:
            x1[0]=13; x2[0]=9; y1[0]=4; y2[0]=4;
            x1[1]=4; x2[1]=3; y1[1]=6; y2[1]=6;
            x1[2]=12; x2[2]=12; y1[2]=10; y2[2]=1;
            x1[3]=9; x2[3]=3; y1[3]=13; y2[3]=13;
            x1[4]=10; x2[4]=10; y1[4]=6; y2[4]=2;
            x1[5]=9; x2[5]=9; y1[5]=5; y2[5]=0;
            x1[6]=14; x2[6]=0; y1[6]=5; y2[6]=5;
            x1[7]=14; x2[7]=11; y1[7]=7; y2[7]=7;
            x1[8]=11; x2[8]=11; y1[8]=10; y2[8]=3;
            x1[9]=14; x2[9]=14; y1[9]=5; y2[9]=1;
            x1[10]=7; x2[10]=7; y1[10]=9; y2[10]=1;
            x1[11]=6; x2[11]=4; y1[11]=3; y2[11]=3;
            x1[12]=10; x2[12]=10; y1[12]=14; y2[12]=11;
        break;
        case 228:
            x1[0]=14; x2[0]=1; y1[0]=3; y2[0]=3;
            x1[1]=11; x2[1]=11; y1[1]=11; y2[1]=10;
            x1[2]=8; x2[2]=1; y1[2]=0; y2[2]=0;
            x1[3]=11; x2[3]=7; y1[3]=12; y2[3]=12;
            x1[4]=1; x2[4]=1; y1[4]=13; y2[4]=4;
            x1[5]=5; x2[5]=5; y1[5]=8; y2[5]=0;
            x1[6]=13; x2[6]=5; y1[6]=3; y2[6]=3;
            x1[7]=14; x2[7]=11; y1[7]=3; y2[7]=3;
            x1[8]=4; x2[8]=0; y1[8]=7; y2[8]=7;
            x1[9]=14; x2[9]=14; y1[9]=12; y2[9]=11;
            x1[10]=10; x2[10]=10; y1[10]=8; y2[10]=0;
            x1[11]=13; x2[11]=13; y1[11]=11; y2[11]=10;
            x1[12]=10; x2[12]=10; y1[12]=13; y2[12]=12;
        break;
        case 229:
            x1[0]=11; x2[0]=9; y1[0]=11; y2[0]=11;
            x1[1]=9; x2[1]=3; y1[1]=0; y2[1]=0;
            x1[2]=11; x2[2]=5; y1[2]=12; y2[2]=12;
            x1[3]=8; x2[3]=6; y1[3]=0; y2[3]=0;
            x1[4]=3; x2[4]=3; y1[4]=6; y2[4]=3;
            x1[5]=11; x2[5]=11; y1[5]=9; y2[5]=4;
            x1[6]=8; x2[6]=6; y1[6]=13; y2[6]=13;
            x1[7]=14; x2[7]=2; y1[7]=10; y2[7]=10;
            x1[8]=6; x2[8]=3; y1[8]=6; y2[8]=6;
            x1[9]=14; x2[9]=11; y1[9]=14; y2[9]=14;
            x1[10]=2; x2[10]=2; y1[10]=11; y2[10]=8;
            x1[11]=1; x2[11]=1; y1[11]=14; y2[11]=10;
            x1[12]=9; x2[12]=9; y1[12]=12; y2[12]=2;
        break;
        case 230:
            x1[0]=12; x2[0]=0; y1[0]=6; y2[0]=6;
            x1[1]=11; x2[1]=10; y1[1]=0; y2[1]=0;
            x1[2]=10; x2[2]=10; y1[2]=8; y2[2]=6;
            x1[3]=2; x2[3]=1; y1[3]=2; y2[3]=2;
            x1[4]=3; x2[4]=3; y1[4]=14; y2[4]=7;
            x1[5]=14; x2[5]=2; y1[5]=0; y2[5]=0;
            x1[6]=11; x2[6]=3; y1[6]=12; y2[6]=12;
            x1[7]=5; x2[7]=5; y1[7]=14; y2[7]=5;
            x1[8]=10; x2[8]=10; y1[8]=9; y2[8]=0;
            x1[9]=11; x2[9]=11; y1[9]=13; y2[9]=1;
            x1[10]=1; x2[10]=1; y1[10]=12; y2[10]=0;
            x1[11]=5; x2[11]=4; y1[11]=14; y2[11]=14;
            x1[12]=2; x2[12]=2; y1[12]=14; y2[12]=11;
        break;
        case 231:
            x1[0]=9; x2[0]=9; y1[0]=14; y2[0]=6;
            x1[1]=6; x2[1]=6; y1[1]=10; y2[1]=8;
            x1[2]=6; x2[2]=2; y1[2]=8; y2[2]=8;
            x1[3]=7; x2[3]=5; y1[3]=13; y2[3]=13;
            x1[4]=13; x2[4]=3; y1[4]=6; y2[4]=6;
            x1[5]=7; x2[5]=7; y1[5]=2; y2[5]=1;
            x1[6]=8; x2[6]=8; y1[6]=14; y2[6]=11;
            x1[7]=11; x2[7]=11; y1[7]=11; y2[7]=0;
            x1[8]=8; x2[8]=7; y1[8]=2; y2[8]=2;
            x1[9]=9; x2[9]=1; y1[9]=4; y2[9]=4;
            x1[10]=2; x2[10]=2; y1[10]=13; y2[10]=8;
            x1[11]=10; x2[11]=0; y1[11]=0; y2[11]=0;
            x1[12]=3; x2[12]=3; y1[12]=10; y2[12]=3;
        break;
        case 232:
            x1[0]=13; x2[0]=4; y1[0]=12; y2[0]=12;
            x1[1]=4; x2[1]=0; y1[1]=0; y2[1]=0;
            x1[2]=0; x2[2]=0; y1[2]=12; y2[2]=6;
            x1[3]=7; x2[3]=5; y1[3]=12; y2[3]=12;
            x1[4]=4; x2[4]=4; y1[4]=10; y2[4]=6;
            x1[5]=14; x2[5]=14; y1[5]=4; y2[5]=2;
            x1[6]=10; x2[6]=2; y1[6]=10; y2[6]=10;
            x1[7]=6; x2[7]=6; y1[7]=7; y2[7]=3;
            x1[8]=13; x2[8]=13; y1[8]=9; y2[8]=6;
            x1[9]=5; x2[9]=3; y1[9]=2; y2[9]=2;
            x1[10]=13; x2[10]=13; y1[10]=10; y2[10]=0;
            x1[11]=10; x2[11]=6; y1[11]=8; y2[11]=8;
            x1[12]=10; x2[12]=3; y1[12]=11; y2[12]=11;
        break;
        case 233:
            x1[0]=14; x2[0]=5; y1[0]=0; y2[0]=0;
            x1[1]=2; x2[1]=2; y1[1]=14; y2[1]=0;
            x1[2]=6; x2[2]=6; y1[2]=12; y2[2]=2;
            x1[3]=11; x2[3]=9; y1[3]=0; y2[3]=0;
            x1[4]=3; x2[4]=0; y1[4]=10; y2[4]=10;
            x1[5]=10; x2[5]=10; y1[5]=10; y2[5]=0;
            x1[6]=12; x2[6]=12; y1[6]=7; y2[6]=3;
            x1[7]=9; x2[7]=9; y1[7]=13; y2[7]=4;
            x1[8]=5; x2[8]=5; y1[8]=11; y2[8]=2;
            x1[9]=0; x2[9]=0; y1[9]=12; y2[9]=3;
            x1[10]=9; x2[10]=2; y1[10]=12; y2[10]=12;
            x1[11]=1; x2[11]=1; y1[11]=9; y2[11]=0;
            x1[12]=1; x2[12]=1; y1[12]=14; y2[12]=9;
        break;
        case 234:
            x1[0]=10; x2[0]=10; y1[0]=14; y2[0]=10;
            x1[1]=5; x2[1]=5; y1[1]=14; y2[1]=8;
            x1[2]=4; x2[2]=4; y1[2]=11; y2[2]=10;
            x1[3]=7; x2[3]=7; y1[3]=4; y2[3]=2;
            x1[4]=12; x2[4]=11; y1[4]=13; y2[4]=13;
            x1[5]=13; x2[5]=9; y1[5]=7; y2[5]=7;
            x1[6]=1; x2[6]=1; y1[6]=10; y2[6]=9;
            x1[7]=6; x2[7]=5; y1[7]=7; y2[7]=7;
            x1[8]=5; x2[8]=5; y1[8]=8; y2[8]=4;
            x1[9]=11; x2[9]=5; y1[9]=4; y2[9]=4;
            x1[10]=13; x2[10]=13; y1[10]=2; y2[10]=0;
            x1[11]=7; x2[11]=1; y1[11]=4; y2[11]=4;
            x1[12]=10; x2[12]=1; y1[12]=5; y2[12]=5;
        break;
        case 235:
            x1[0]=3; x2[0]=3; y1[0]=7; y2[0]=1;
            x1[1]=12; x2[1]=8; y1[1]=6; y2[1]=6;
            x1[2]=11; x2[2]=8; y1[2]=11; y2[2]=11;
            x1[3]=10; x2[3]=9; y1[3]=12; y2[3]=12;
            x1[4]=9; x2[4]=9; y1[4]=12; y2[4]=5;
            x1[5]=14; x2[5]=6; y1[5]=6; y2[5]=6;
            x1[6]=4; x2[6]=4; y1[6]=6; y2[6]=3;
            x1[7]=5; x2[7]=5; y1[7]=12; y2[7]=5;
            x1[8]=14; x2[8]=14; y1[8]=8; y2[8]=6;
            x1[9]=10; x2[9]=7; y1[9]=9; y2[9]=9;
            x1[10]=3; x2[10]=3; y1[10]=11; y2[10]=10;
            x1[11]=14; x2[11]=9; y1[11]=0; y2[11]=0;
            x1[12]=1; x2[12]=1; y1[12]=11; y2[12]=3;
        break;
        case 236:
            x1[0]=13; x2[0]=11; y1[0]=14; y2[0]=14;
            x1[1]=3; x2[1]=1; y1[1]=12; y2[1]=12;
            x1[2]=14; x2[2]=2; y1[2]=14; y2[2]=14;
            x1[3]=3; x2[3]=3; y1[3]=8; y2[3]=6;
            x1[4]=12; x2[4]=6; y1[4]=12; y2[4]=12;
            x1[5]=14; x2[5]=0; y1[5]=6; y2[5]=6;
            x1[6]=14; x2[6]=9; y1[6]=3; y2[6]=3;
            x1[7]=2; x2[7]=0; y1[7]=0; y2[7]=0;
            x1[8]=8; x2[8]=3; y1[8]=7; y2[8]=7;
            x1[9]=3; x2[9]=3; y1[9]=14; y2[9]=3;
            x1[10]=11; x2[10]=11; y1[10]=14; y2[10]=1;
            x1[11]=7; x2[11]=7; y1[11]=9; y2[11]=8;
            x1[12]=7; x2[12]=7; y1[12]=13; y2[12]=12;
        break;
        case 237:
            x1[0]=14; x2[0]=3; y1[0]=14; y2[0]=14;
            x1[1]=3; x2[1]=3; y1[1]=9; y2[1]=6;
            x1[2]=14; x2[2]=9; y1[2]=7; y2[2]=7;
            x1[3]=4; x2[3]=3; y1[3]=2; y2[3]=2;
            x1[4]=10; x2[4]=10; y1[4]=11; y2[4]=2;
            x1[5]=14; x2[5]=4; y1[5]=13; y2[5]=13;
            x1[6]=3; x2[6]=3; y1[6]=14; y2[6]=2;
            x1[7]=4; x2[7]=4; y1[7]=8; y2[7]=1;
            x1[8]=14; x2[8]=2; y1[8]=6; y2[8]=6;
            x1[9]=14; x2[9]=10; y1[9]=13; y2[9]=13;
            x1[10]=5; x2[10]=5; y1[10]=6; y2[10]=2;
            x1[11]=6; x2[11]=1; y1[11]=11; y2[11]=11;
            x1[12]=12; x2[12]=0; y1[12]=14; y2[12]=14;
        break;
        case 238:
            x1[0]=14; x2[0]=4; y1[0]=12; y2[0]=12;
            x1[1]=6; x2[1]=6; y1[1]=14; y2[1]=13;
            x1[2]=11; x2[2]=3; y1[2]=8; y2[2]=8;
            x1[3]=5; x2[3]=5; y1[3]=10; y2[3]=1;
            x1[4]=11; x2[4]=1; y1[4]=5; y2[4]=5;
            x1[5]=7; x2[5]=4; y1[5]=0; y2[5]=0;
            x1[6]=10; x2[6]=9; y1[6]=3; y2[6]=3;
            x1[7]=12; x2[7]=12; y1[7]=8; y2[7]=6;
            x1[8]=11; x2[8]=1; y1[8]=6; y2[8]=6;
            x1[9]=13; x2[9]=5; y1[9]=8; y2[9]=8;
            x1[10]=1; x2[10]=1; y1[10]=12; y2[10]=8;
            x1[11]=0; x2[11]=0; y1[11]=8; y2[11]=4;
            x1[12]=8; x2[12]=8; y1[12]=9; y2[12]=8;
        break;
        case 239:
            x1[0]=8; x2[0]=4; y1[0]=14; y2[0]=14;
            x1[1]=5; x2[1]=5; y1[1]=13; y2[1]=10;
            x1[2]=9; x2[2]=0; y1[2]=4; y2[2]=4;
            x1[3]=10; x2[3]=7; y1[3]=11; y2[3]=11;
            x1[4]=11; x2[4]=11; y1[4]=9; y2[4]=6;
            x1[5]=14; x2[5]=1; y1[5]=5; y2[5]=5;
            x1[6]=12; x2[6]=4; y1[6]=8; y2[6]=8;
            x1[7]=0; x2[7]=0; y1[7]=11; y2[7]=4;
            x1[8]=1; x2[8]=1; y1[8]=10; y2[8]=4;
            x1[9]=12; x2[9]=7; y1[9]=4; y2[9]=4;
            x1[10]=10; x2[10]=9; y1[10]=9; y2[10]=9;
            x1[11]=12; x2[11]=7; y1[11]=3; y2[11]=3;
            x1[12]=2; x2[12]=2; y1[12]=10; y2[12]=7;
        break;
        case 240:
            x1[0]=6; x2[0]=6; y1[0]=13; y2[0]=8;
            x1[1]=2; x2[1]=2; y1[1]=6; y2[1]=0;
            x1[2]=6; x2[2]=6; y1[2]=12; y2[2]=4;
            x1[3]=0; x2[3]=0; y1[3]=11; y2[3]=7;
            x1[4]=4; x2[4]=4; y1[4]=6; y2[4]=0;
            x1[5]=3; x2[5]=2; y1[5]=11; y2[5]=11;
            x1[6]=8; x2[6]=0; y1[6]=11; y2[6]=11;
            x1[7]=7; x2[7]=7; y1[7]=14; y2[7]=10;
            x1[8]=12; x2[8]=12; y1[8]=5; y2[8]=0;
            x1[9]=14; x2[9]=14; y1[9]=14; y2[9]=2;
            x1[10]=2; x2[10]=2; y1[10]=13; y2[10]=5;
            x1[11]=12; x2[11]=12; y1[11]=14; y2[11]=1;
            x1[12]=14; x2[12]=0; y1[12]=13; y2[12]=13;
        break;
        case 241:
            x1[0]=11; x2[0]=6; y1[0]=8; y2[0]=8;
            x1[1]=12; x2[1]=12; y1[1]=12; y2[1]=3;
            x1[2]=11; x2[2]=6; y1[2]=6; y2[2]=6;
            x1[3]=14; x2[3]=7; y1[3]=0; y2[3]=0;
            x1[4]=7; x2[4]=7; y1[4]=11; y2[4]=2;
            x1[5]=6; x2[5]=6; y1[5]=11; y2[5]=0;
            x1[6]=12; x2[6]=1; y1[6]=4; y2[6]=4;
            x1[7]=11; x2[7]=1; y1[7]=13; y2[7]=13;
            x1[8]=5; x2[8]=3; y1[8]=7; y2[8]=7;
            x1[9]=14; x2[9]=14; y1[9]=9; y2[9]=8;
            x1[10]=14; x2[10]=12; y1[10]=1; y2[10]=1;
            x1[11]=8; x2[11]=2; y1[11]=6; y2[11]=6;
            x1[12]=6; x2[12]=6; y1[12]=12; y2[12]=7;
        break;
        case 242:
            x1[0]=7; x2[0]=7; y1[0]=10; y2[0]=5;
            x1[1]=13; x2[1]=13; y1[1]=8; y2[1]=2;
            x1[2]=9; x2[2]=8; y1[2]=11; y2[2]=11;
            x1[3]=8; x2[3]=8; y1[3]=7; y2[3]=5;
            x1[4]=2; x2[4]=2; y1[4]=9; y2[4]=0;
            x1[5]=1; x2[5]=0; y1[5]=9; y2[5]=9;
            x1[6]=11; x2[6]=2; y1[6]=6; y2[6]=6;
            x1[7]=3; x2[7]=0; y1[7]=12; y2[7]=12;
            x1[8]=13; x2[8]=7; y1[8]=4; y2[8]=4;
            x1[9]=13; x2[9]=13; y1[9]=6; y2[9]=3;
            x1[10]=11; x2[10]=1; y1[10]=10; y2[10]=10;
            x1[11]=13; x2[11]=13; y1[11]=9; y2[11]=0;
            x1[12]=3; x2[12]=3; y1[12]=10; y2[12]=0;
        break;
    }
}}}
